/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_ls3zVMaZ);
  numBytes += sLine_init(&sLine_tyPOY8jl);
  numBytes += sLine_init(&sLine_B6TjHgV2);
  numBytes += sLine_init(&sLine_i4uXFHFW);
  numBytes += sLine_init(&sLine_Lcv5nsDe);
  numBytes += sBiquad_init(&sBiquad_s_HdPr8Cpg);
  numBytes += sLine_init(&sLine_y6l8UlfR);
  numBytes += sLine_init(&sLine_6BWcx5SW);
  numBytes += sLine_init(&sLine_Sfc8rYUU);
  numBytes += sLine_init(&sLine_hFtZtHmg);
  numBytes += sLine_init(&sLine_h75433Zi);
  numBytes += sBiquad_init(&sBiquad_s_22kFkspQ);
  numBytes += sLine_init(&sLine_N1HEYoZg);
  numBytes += sLine_init(&sLine_PcpMyUme);
  numBytes += sLine_init(&sLine_Y5VkiSj2);
  numBytes += sLine_init(&sLine_j5Z0amXb);
  numBytes += sLine_init(&sLine_6dlpI8ph);
  numBytes += sLine_init(&sLine_mwumiwFa);
  numBytes += sBiquad_init(&sBiquad_s_qHsXqxp4);
  numBytes += sLine_init(&sLine_txsD6EeR);
  numBytes += sLine_init(&sLine_4rLK7XGJ);
  numBytes += sLine_init(&sLine_yrG5ktlC);
  numBytes += sLine_init(&sLine_iSPeRxCP);
  numBytes += sLine_init(&sLine_EN2iN87h);
  numBytes += sLine_init(&sLine_9AAS3iXz);
  numBytes += sBiquad_init(&sBiquad_s_ydtM7Cgu);
  numBytes += sLine_init(&sLine_PUOFB1vg);
  numBytes += sLine_init(&sLine_MaXv4SxD);
  numBytes += sLine_init(&sLine_VVK0HmYH);
  numBytes += sLine_init(&sLine_8sCC2hRv);
  numBytes += sLine_init(&sLine_YfE5aBfe);
  numBytes += sBiquad_init(&sBiquad_s_MnTCpGmD);
  numBytes += sLine_init(&sLine_DaHgsqsj);
  numBytes += sLine_init(&sLine_xRiNz62G);
  numBytes += sLine_init(&sLine_GZKU3kID);
  numBytes += sLine_init(&sLine_JuLQM7KX);
  numBytes += sLine_init(&sLine_KMsCG2LC);
  numBytes += sLine_init(&sLine_8DpWbtvh);
  numBytes += sBiquad_init(&sBiquad_s_9tWeP6QM);
  numBytes += sLine_init(&sLine_qQim1IUF);
  numBytes += sLine_init(&sLine_CyXvA8Mx);
  numBytes += sLine_init(&sLine_bPnlXqcp);
  numBytes += sLine_init(&sLine_6vfEETPE);
  numBytes += sLine_init(&sLine_Rw4mulnn);
  numBytes += sLine_init(&sLine_GfXR4hIf);
  numBytes += sLine_init(&sLine_vNE3QZJH);
  numBytes += sLine_init(&sLine_256qT47G);
  numBytes += sLine_init(&sLine_2inoeW26);
  numBytes += sLine_init(&sLine_aMON9LG3);
  numBytes += sLine_init(&sLine_YnoSVIam);
  numBytes += sLine_init(&sLine_DUKoiewp);
  numBytes += sLine_init(&sLine_Fs1AWxeO);
  numBytes += sLine_init(&sLine_XmaoFNtT);
  numBytes += sLine_init(&sLine_QzjP7cQW);
  numBytes += sEnv_init(&sEnv_fgWNHB81, 512, 256);
  numBytes += sEnv_init(&sEnv_WsuIkwS7, 512, 256);
  numBytes += sLine_init(&sLine_9s2tQg2Y);
  numBytes += sLine_init(&sLine_VxhE2ooY);
  numBytes += sLine_init(&sLine_X5u1aQvI);
  numBytes += sLine_init(&sLine_tjLwAOIw);
  numBytes += sLine_init(&sLine_hsx0uE8X);
  numBytes += sLine_init(&sLine_uS3zURof);
  numBytes += sLine_init(&sLine_gto6S6hS);
  numBytes += sLine_init(&sLine_k7RB61gw);
  numBytes += sLine_init(&sLine_BnNO98XY);
  numBytes += sLine_init(&sLine_vtsE8tsm);
  numBytes += sLine_init(&sLine_CUI8eRb4);
  numBytes += sLine_init(&sLine_fOusu7GI);
  numBytes += sLine_init(&sLine_As54ef65);
  numBytes += sLine_init(&sLine_XuX0rN2r);
  numBytes += sLine_init(&sLine_2A6QYP2C);
  numBytes += sLine_init(&sLine_3wrWAOTG);
  numBytes += sLine_init(&sLine_SKi6hEJ1);
  numBytes += sLine_init(&sLine_vXqssMoo);
  numBytes += sEnv_init(&sEnv_U66skpCM, 512, 256);
  numBytes += sEnv_init(&sEnv_L63ZQJAj, 512, 256);
  numBytes += sLine_init(&sLine_zkDeWrpp);
  numBytes += sLine_init(&sLine_lDIbYlSg);
  numBytes += sLine_init(&sLine_18vswGyo);
  numBytes += sLine_init(&sLine_OWbLAUAP);
  numBytes += sLine_init(&sLine_JV9pTreA);
  numBytes += sLine_init(&sLine_oInOwpc3);
  numBytes += sLine_init(&sLine_Kwy0iyFE);
  numBytes += sLine_init(&sLine_UJoP6xVs);
  numBytes += sLine_init(&sLine_kR7cEzRL);
  numBytes += sLine_init(&sLine_tcl8ymhp);
  numBytes += sLine_init(&sLine_J2AyRPvT);
  numBytes += sLine_init(&sLine_ZNAlzfhk);
  numBytes += sLine_init(&sLine_k260QzrI);
  numBytes += sLine_init(&sLine_LHNfNZf4);
  numBytes += sLine_init(&sLine_11B5flyN);
  numBytes += sLine_init(&sLine_FI43mGGk);
  numBytes += sLine_init(&sLine_yuk4zdRh);
  numBytes += sLine_init(&sLine_1CGMk273);
  numBytes += sLine_init(&sLine_Vx9ygqWT);
  numBytes += sLine_init(&sLine_asRQe9Q2);
  numBytes += sEnv_init(&sEnv_SjIBOi8Q, 512, 256);
  numBytes += sEnv_init(&sEnv_RSZCApoZ, 512, 256);
  numBytes += sLine_init(&sLine_s3cD0sXt);
  numBytes += sLine_init(&sLine_nm0MD97k);
  numBytes += sLine_init(&sLine_qIxwRMKh);
  numBytes += sLine_init(&sLine_oYdHT1Pm);
  numBytes += sLine_init(&sLine_eBTa6ZvN);
  numBytes += sLine_init(&sLine_NfbWX0kJ);
  numBytes += sLine_init(&sLine_pL6OjPqA);
  numBytes += sLine_init(&sLine_bHAZ78gt);
  numBytes += sLine_init(&sLine_gZ5akssZ);
  numBytes += sLine_init(&sLine_LBy1YJne);
  numBytes += sLine_init(&sLine_cH1VQwhi);
  numBytes += sLine_init(&sLine_0aHfvFtH);
  numBytes += sLine_init(&sLine_mZcu5W0W);
  numBytes += sLine_init(&sLine_0k24U2Vo);
  numBytes += sLine_init(&sLine_1R7IS8uU);
  numBytes += sLine_init(&sLine_j8GtFFRj);
  numBytes += sLine_init(&sLine_oQeq7PRC);
  numBytes += sLine_init(&sLine_yVhJqV7F);
  numBytes += sEnv_init(&sEnv_KdHzar7f, 512, 256);
  numBytes += sEnv_init(&sEnv_qCcdMQme, 512, 256);
  numBytes += sLine_init(&sLine_NSPyJCkB);
  numBytes += sLine_init(&sLine_TYl9Dpe7);
  numBytes += sLine_init(&sLine_wReHpmYT);
  numBytes += sLine_init(&sLine_uj7PpiI3);
  numBytes += sLine_init(&sLine_T9P7hUFj);
  numBytes += sLine_init(&sLine_zY6ZiOVM);
  numBytes += sLine_init(&sLine_2TemKAgS);
  numBytes += sLine_init(&sLine_SaxTBT3T);
  numBytes += sLine_init(&sLine_Cts52OSJ);
  numBytes += sLine_init(&sLine_HePc5V1s);
  numBytes += sLine_init(&sLine_HBpd95Qe);
  numBytes += sLine_init(&sLine_LcMIiAzn);
  numBytes += sLine_init(&sLine_mSBYEmw3);
  numBytes += sLine_init(&sLine_RtmdM5Nc);
  numBytes += sLine_init(&sLine_gkChQB5s);
  numBytes += sLine_init(&sLine_0TgqFOs3);
  numBytes += sLine_init(&sLine_JtpNIZUT);
  numBytes += sLine_init(&sLine_GasgLAlY);
  numBytes += sLine_init(&sLine_tSuCCcSw);
  numBytes += sLine_init(&sLine_zZZ6kyv9);
  numBytes += sEnv_init(&sEnv_vI5Kdkjy, 512, 256);
  numBytes += sEnv_init(&sEnv_g9hXzi6C, 512, 256);
  numBytes += sLine_init(&sLine_kgxVtBhb);
  numBytes += sLine_init(&sLine_v5azaCYI);
  numBytes += sLine_init(&sLine_EpAbRijP);
  numBytes += sLine_init(&sLine_7wvrV4WA);
  numBytes += sLine_init(&sLine_R72tx8r2);
  numBytes += sLine_init(&sLine_91ad99HK);
  numBytes += sLine_init(&sLine_SFJfChUo);
  numBytes += sLine_init(&sLine_9yGVvmAa);
  numBytes += sLine_init(&sLine_cRrwW713);
  numBytes += sLine_init(&sLine_mGQpREuF);
  numBytes += sLine_init(&sLine_9z91Rey4);
  numBytes += sLine_init(&sLine_0wIJyN0t);
  numBytes += sLine_init(&sLine_ALuGIWKi);
  numBytes += sLine_init(&sLine_pVQfqxPH);
  numBytes += sLine_init(&sLine_fXneVWm5);
  numBytes += sLine_init(&sLine_W25dSaM3);
  numBytes += sLine_init(&sLine_Wnx5bKwX);
  numBytes += sLine_init(&sLine_dAwdQ3yN);
  numBytes += sEnv_init(&sEnv_KYwy1NVO, 512, 256);
  numBytes += sEnv_init(&sEnv_VORzBCkF, 512, 256);
  numBytes += sLine_init(&sLine_HPNi69Um);
  numBytes += sLine_init(&sLine_pNpC8UZ6);
  numBytes += sLine_init(&sLine_jXolqGRd);
  numBytes += sLine_init(&sLine_OjzrcFGv);
  numBytes += sLine_init(&sLine_suR05BAf);
  numBytes += sLine_init(&sLine_cABiJb3o);
  numBytes += cVar_init_f(&cVar_A3DpyPSp, 0.0f);
  numBytes += cVar_init_f(&cVar_3Vnt0YXJ, 0.0f);
  numBytes += cVar_init_f(&cVar_nUZEePEt, 0.0f);
  numBytes += cVar_init_f(&cVar_bxoMx4Ea, 0.0f);
  numBytes += cVar_init_f(&cVar_GgMJeAYt, 0.0f);
  numBytes += cVar_init_f(&cVar_6rncuoHc, 1.0f);
  numBytes += cVar_init_f(&cVar_9SjHdA7p, 0.0f);
  numBytes += cVar_init_f(&cVar_KsPrAKUj, 0.0f);
  numBytes += cVar_init_f(&cVar_7xSZlgMd, 0.0f);
  numBytes += cVar_init_f(&cVar_9v4oL3mx, 0.0f);
  numBytes += cSlice_init(&cSlice_63VvxXza, 1, -1);
  numBytes += cVar_init_f(&cVar_rsXocbM1, 1337.0f);
  numBytes += cVar_init_f(&cVar_RjqlEO9D, 0.0f);
  numBytes += cIf_init(&cIf_PetnRNa1, false);
  numBytes += cIf_init(&cIf_Aa9tCrEa, false);
  numBytes += cBinop_init(&cBinop_FfdMupfv, 0.0f); // __pow
  numBytes += cIf_init(&cIf_KRAJUk2U, false);
  numBytes += cBinop_init(&cBinop_J8G2cDJQ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_LwIRacl9, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ut8DoDQ2, 0.0f);
  numBytes += cIf_init(&cIf_Aejqulzo, false);
  numBytes += cIf_init(&cIf_1PSrTYoj, false);
  numBytes += cBinop_init(&cBinop_r7mdCBbe, 0.0f); // __pow
  numBytes += cIf_init(&cIf_bH2nMnpE, false);
  numBytes += cBinop_init(&cBinop_kxqDcm9E, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_CoiOxovs, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_vCfPpDMI, 0.0f);
  numBytes += cIf_init(&cIf_AlttwDI1, false);
  numBytes += cIf_init(&cIf_h6V9H1Mc, false);
  numBytes += cBinop_init(&cBinop_XbtLr4JH, 0.0f); // __pow
  numBytes += cIf_init(&cIf_sXKeEQWc, false);
  numBytes += cBinop_init(&cBinop_xAse6ZRw, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_KGqwlOcQ, -15.0f); // __eq
  numBytes += cIf_init(&cIf_L0LHvtgI, false);
  numBytes += cSlice_init(&cSlice_P9SuJ7Sw, 1, -1);
  numBytes += cVar_init_f(&cVar_YZioZjYU, 0.0f);
  numBytes += cSlice_init(&cSlice_gs12FOZ7, 1, -1);
  numBytes += cVar_init_f(&cVar_9gIO857E, 0.0f);
  numBytes += cSlice_init(&cSlice_jACMVzZW, 1, -1);
  numBytes += cVar_init_f(&cVar_OlVuuVD7, 0.0f);
  numBytes += cSlice_init(&cSlice_j4EEcbKz, 1, -1);
  numBytes += cVar_init_f(&cVar_TENoGe3Q, 0.313f);
  numBytes += cBinop_init(&cBinop_gWJUlEzZ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_JQUPpsXk, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_IsVbxfI8, 0.0f);
  numBytes += cVar_init_f(&cVar_F3m46Eek, 1337.0f);
  numBytes += cVar_init_f(&cVar_H4iEMOqb, 0.3f);
  numBytes += cBinop_init(&cBinop_Pe0vxtaK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RcY0ezAj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PG5Zo70q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ugh7nq6P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rtVPOZEv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_davLmB5f, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iRXE3UpN, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_U6MxrSQ1, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ZlMeH5FJ, 0.0f);
  numBytes += cVar_init_f(&cVar_9bAxG93b, 1337.0f);
  numBytes += cVar_init_f(&cVar_GSmMJyz5, 0.313f);
  numBytes += cBinop_init(&cBinop_o4jzlu8y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9q7W6Zce, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XPf0kag2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Mr3pFIW8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ipfMToPo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PrnSjtDM, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_P4MDY0ZD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_aYPdIv4k, 0.0f);
  numBytes += cVar_init_f(&cVar_Pp5qqHEx, 1037.0f);
  numBytes += cVar_init_f(&cVar_rZHY2mJ6, 0.4f);
  numBytes += cBinop_init(&cBinop_hz5koRqe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WPUPYfTT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_opi2SxkS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pGNIZBdZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QIPemjeZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hMMcpJnm, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_xOyuDpKs, 1, -1);
  numBytes += cVar_init_f(&cVar_sRSOQQJi, 1337.0f);
  numBytes += cVar_init_f(&cVar_S2Dea1NV, 0.0f);
  numBytes += cIf_init(&cIf_H20ddYqD, false);
  numBytes += cIf_init(&cIf_R1hGWKlq, false);
  numBytes += cBinop_init(&cBinop_CpaH3CbJ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_AHhpuMSq, false);
  numBytes += cBinop_init(&cBinop_oGB1rPdd, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_bIHrNbg5, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ivqaJ7P9, 0.0f);
  numBytes += cIf_init(&cIf_eKmd8xS0, false);
  numBytes += cIf_init(&cIf_riyp3xP3, false);
  numBytes += cBinop_init(&cBinop_b0Dea7ak, 0.0f); // __pow
  numBytes += cIf_init(&cIf_TQ3FqSyG, false);
  numBytes += cBinop_init(&cBinop_nKzslviM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_XYhA7e85, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_RFh6itNZ, 0.0f);
  numBytes += cIf_init(&cIf_hefUIUgF, false);
  numBytes += cIf_init(&cIf_iBHWyqH0, false);
  numBytes += cBinop_init(&cBinop_WOvmoFBm, 0.0f); // __pow
  numBytes += cIf_init(&cIf_rZ0xkH77, false);
  numBytes += cBinop_init(&cBinop_9aVlgmIT, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_4SgNggvr, -15.0f); // __eq
  numBytes += cIf_init(&cIf_v7Dq9iBK, false);
  numBytes += cSlice_init(&cSlice_ZoQjtjsx, 1, -1);
  numBytes += cVar_init_f(&cVar_8oEldjf2, 0.0f);
  numBytes += cSlice_init(&cSlice_ma5Lyrng, 1, -1);
  numBytes += cVar_init_f(&cVar_71grRNZR, 0.0f);
  numBytes += cSlice_init(&cSlice_91jNACVE, 1, -1);
  numBytes += cVar_init_f(&cVar_dacxVYmO, 0.0f);
  numBytes += cSlice_init(&cSlice_jxKwbiQN, 1, -1);
  numBytes += cVar_init_f(&cVar_7VBZxqeH, 0.313f);
  numBytes += cBinop_init(&cBinop_EZSsaagq, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_hIgVzjKA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_gY5Nb62J, 0.0f);
  numBytes += cVar_init_f(&cVar_z8jzKTRE, 1337.0f);
  numBytes += cVar_init_f(&cVar_sVRbx11d, 0.3f);
  numBytes += cBinop_init(&cBinop_7tfNDEKO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_A9N2q7fN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_atVxzqEM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jO30Q9RI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_80TTpTtk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1LrljI6T, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wf3CDKFq, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_JPItuRhs, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WTKRRGke, 0.0f);
  numBytes += cVar_init_f(&cVar_KceWzcgz, 1337.0f);
  numBytes += cVar_init_f(&cVar_XJnCYJzK, 0.313f);
  numBytes += cBinop_init(&cBinop_YkBIKE9D, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_knhBFpXJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XyyjpvIg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wmBWbC2D, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Q019Ley0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W42Y7S6r, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Su4HQRAq, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_pL3Nxtj6, 0.0f);
  numBytes += cVar_init_f(&cVar_vZhNy5sh, 1037.0f);
  numBytes += cVar_init_f(&cVar_XIdlH0tt, 0.4f);
  numBytes += cBinop_init(&cBinop_yOJmY5PD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QUBhqDqW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dHlNdhyF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W45f108V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lIjlCzW5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cR5jodA9, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_GIGVDfP1, 5705.6f);
  numBytes += cVar_init_f(&cVar_5GsqLGbw, 313.3f);
  numBytes += cBinop_init(&cBinop_BtpL7WIa, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_imeJJWE2, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_veAIlZtW, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_3hX6lDQo, 1, -1);
  numBytes += cVar_init_f(&cVar_DQ77anMM, 0.5f);
  numBytes += cVar_init_f(&cVar_A6VIXy7X, 0.0f);
  numBytes += cVar_init_f(&cVar_CuD9QXU5, 0.0f);
  numBytes += cIf_init(&cIf_tIqJSt9T, false);
  numBytes += cIf_init(&cIf_Sv0uxjuH, false);
  numBytes += cDelay_init(this, &cDelay_TS9ooPIE, 10.0f);
  numBytes += cIf_init(&cIf_MhrrSbPz, false);
  numBytes += cIf_init(&cIf_d7iryq56, false);
  numBytes += cDelay_init(this, &cDelay_XzcIUM43, 10.0f);
  numBytes += cIf_init(&cIf_VUGY4OTZ, false);
  numBytes += cIf_init(&cIf_0pzOMtj9, false);
  numBytes += cDelay_init(this, &cDelay_AxsUPu3R, 10.0f);
  numBytes += cIf_init(&cIf_mu5wz8Yh, false);
  numBytes += cIf_init(&cIf_Jyd8ccvY, false);
  numBytes += cDelay_init(this, &cDelay_4k9zupd5, 10.0f);
  numBytes += cIf_init(&cIf_AFPyn1mT, false);
  numBytes += cIf_init(&cIf_DvNW5DWA, false);
  numBytes += cDelay_init(this, &cDelay_TMM9K1Ox, 10.0f);
  numBytes += cIf_init(&cIf_ZkvcIxti, false);
  numBytes += cIf_init(&cIf_dz0fCKYw, false);
  numBytes += cDelay_init(this, &cDelay_HM7aEVvG, 10.0f);
  numBytes += cIf_init(&cIf_KlmGbYtn, false);
  numBytes += cIf_init(&cIf_qQgICDt7, false);
  numBytes += cDelay_init(this, &cDelay_JlcdpAGL, 10.0f);
  numBytes += cIf_init(&cIf_o07Aguon, false);
  numBytes += cIf_init(&cIf_bILyxhkI, false);
  numBytes += cDelay_init(this, &cDelay_T18qyOTi, 10.0f);
  numBytes += cIf_init(&cIf_PAscQM39, false);
  numBytes += cIf_init(&cIf_pde2iNBO, false);
  numBytes += cDelay_init(this, &cDelay_zIz7pL0O, 10.0f);
  numBytes += cIf_init(&cIf_lDR5cxpr, false);
  numBytes += cIf_init(&cIf_HNjhEgFe, false);
  numBytes += cDelay_init(this, &cDelay_XYGbGd5j, 10.0f);
  numBytes += cIf_init(&cIf_Z8RrOj3s, false);
  numBytes += cIf_init(&cIf_tnQdZ7Af, false);
  numBytes += cDelay_init(this, &cDelay_tS55ZF91, 10.0f);
  numBytes += cIf_init(&cIf_wKg9gpRJ, false);
  numBytes += cIf_init(&cIf_rDl7wccj, false);
  numBytes += cDelay_init(this, &cDelay_nW28Qft7, 10.0f);
  numBytes += sVarf_init(&sVarf_zviOCAXP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ePZHKStk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lJinVpqY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ehnVyYNP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eJmK9hNu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ASZwqgAq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OTiY6Oer, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pnkF4y0z, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HgS0IXPy, 0.0f);
  numBytes += cSlice_init(&cSlice_bmxRCto5, 1, -1);
  numBytes += cVar_init_f(&cVar_rYQRyUgn, 1.0f);
  numBytes += cSlice_init(&cSlice_0c8eu0Go, 1, -1);
  numBytes += cVar_init_f(&cVar_KlwjFCSS, 0.0f);
  numBytes += cSlice_init(&cSlice_ulzU1Vd8, 1, -1);
  numBytes += cVar_init_f(&cVar_QSyVexH4, 512.0f);
  numBytes += cSlice_init(&cSlice_xBotLxRE, 1, -1);
  numBytes += cVar_init_f(&cVar_5s9mhcvO, 1.0f);
  numBytes += cSlice_init(&cSlice_5H1FAG7H, 1, -1);
  numBytes += cVar_init_f(&cVar_yEkP6gUz, 1.0f);
  numBytes += cDelay_init(this, &cDelay_yDV9W4Xl, 20.0f);
  numBytes += cVar_init_f(&cVar_qCox37tI, 0.0f);
  numBytes += cIf_init(&cIf_T2IcEhkF, false);
  numBytes += cIf_init(&cIf_gHI23hND, false);
  numBytes += cBinop_init(&cBinop_2Tbst3OC, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_hc6xjqUT, 1, -1);
  numBytes += cVar_init_f(&cVar_WsgnR5XF, 0.0f);
  numBytes += sVarf_init(&sVarf_NRAQ1Uxn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_asM2lVwM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uV3D1fz6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CVqNIwmV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XZEsniA3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RhgeYgkQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KPkA8TaT, 0.0f);
  numBytes += cVar_init_f(&cVar_ZTlWhS6g, 0.0f);
  numBytes += cIf_init(&cIf_KpnXZQgN, false);
  numBytes += cIf_init(&cIf_8qJXD1FN, false);
  numBytes += cDelay_init(this, &cDelay_ToAfZIBC, 10.0f);
  numBytes += cIf_init(&cIf_ItA0XDr8, false);
  numBytes += cIf_init(&cIf_480cdCtx, false);
  numBytes += cDelay_init(this, &cDelay_9jadWsK8, 10.0f);
  numBytes += cIf_init(&cIf_7X5zGXOS, false);
  numBytes += cIf_init(&cIf_fajfSFLH, false);
  numBytes += cDelay_init(this, &cDelay_a2kIf8mA, 10.0f);
  numBytes += cIf_init(&cIf_7nKs1MGN, false);
  numBytes += cIf_init(&cIf_NUwkvgll, false);
  numBytes += cDelay_init(this, &cDelay_FSJmH487, 10.0f);
  numBytes += cIf_init(&cIf_8RMxhZMh, false);
  numBytes += cIf_init(&cIf_UMLjnP9B, false);
  numBytes += cDelay_init(this, &cDelay_wiOADaGl, 10.0f);
  numBytes += cIf_init(&cIf_2fCYmsBX, false);
  numBytes += cIf_init(&cIf_1apFu4TD, false);
  numBytes += cDelay_init(this, &cDelay_m747xTDa, 10.0f);
  numBytes += cIf_init(&cIf_ZK34fOPd, false);
  numBytes += cIf_init(&cIf_ficsVDaz, false);
  numBytes += cDelay_init(this, &cDelay_4P4guGWo, 10.0f);
  numBytes += cIf_init(&cIf_TaOempUB, false);
  numBytes += cIf_init(&cIf_FuiLB84a, false);
  numBytes += cDelay_init(this, &cDelay_isFAMPFI, 10.0f);
  numBytes += cIf_init(&cIf_FIpUokJi, false);
  numBytes += cIf_init(&cIf_S1ixs9j7, false);
  numBytes += cDelay_init(this, &cDelay_BxgcxVwp, 10.0f);
  numBytes += cIf_init(&cIf_njPnhC9m, false);
  numBytes += cIf_init(&cIf_ZCIyLLua, false);
  numBytes += cDelay_init(this, &cDelay_xTRJKsd9, 10.0f);
  numBytes += cIf_init(&cIf_C9gb2LmT, false);
  numBytes += cIf_init(&cIf_sPORQSm7, false);
  numBytes += cDelay_init(this, &cDelay_SlA0G9Bk, 10.0f);
  numBytes += cIf_init(&cIf_Dn6dPVNd, false);
  numBytes += cIf_init(&cIf_Hy155ZPb, false);
  numBytes += cDelay_init(this, &cDelay_cfGoJXHw, 10.0f);
  numBytes += sVarf_init(&sVarf_7hO7fyrK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bk2mwFPZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_65L5aKas, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Acr3h0lG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BgGA4ByB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_805tU1aJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PT3O9GSG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0srJicmv, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2tGwmuco, 0.0f);
  numBytes += cSlice_init(&cSlice_eY3ANIEG, 1, -1);
  numBytes += cVar_init_f(&cVar_YpYSVsit, 1.0f);
  numBytes += cSlice_init(&cSlice_MbQMgkNU, 1, -1);
  numBytes += cVar_init_f(&cVar_Os69WWP5, 0.0f);
  numBytes += cSlice_init(&cSlice_ckbOdrut, 1, -1);
  numBytes += cVar_init_f(&cVar_CwTjUmg4, 512.0f);
  numBytes += cSlice_init(&cSlice_S7zZS8EI, 1, -1);
  numBytes += cVar_init_f(&cVar_fihYr1XF, 1.0f);
  numBytes += cSlice_init(&cSlice_orYrkCEZ, 1, -1);
  numBytes += cVar_init_f(&cVar_Qwf1yA2F, 1.0f);
  numBytes += cDelay_init(this, &cDelay_9BQJld2N, 20.0f);
  numBytes += cVar_init_f(&cVar_H9ow7ytc, 0.0f);
  numBytes += cIf_init(&cIf_0OnmJmQ1, false);
  numBytes += cIf_init(&cIf_oPvTpXla, false);
  numBytes += cBinop_init(&cBinop_5xUjTkyi, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Rl3piSN5, 1, -1);
  numBytes += cVar_init_f(&cVar_PxrHZag2, 0.0f);
  numBytes += sVarf_init(&sVarf_UjlcsNJo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rmLHSFIK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nkdg5DvM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ND7GlQQY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mBDDwFQj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3dvShwE0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gOwEEs7F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E4yaGoaK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HV8g3EmD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SLIHomht, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Au8MHXRx, 0.0f);
  numBytes += cVar_init_f(&cVar_YkiJiprp, 0.0f);
  numBytes += cVar_init_f(&cVar_b8RY6tIV, 0.0f);
  numBytes += cVar_init_f(&cVar_YvsKdw8T, 0.0f);
  numBytes += cVar_init_f(&cVar_R3j1exbR, 0.0f);
  numBytes += cVar_init_f(&cVar_pRCGs2NA, 1.0f);
  numBytes += cSlice_init(&cSlice_h8a0dRd3, 1, -1);
  numBytes += cVar_init_f(&cVar_gIlFwekD, 0.5f);
  numBytes += cVar_init_f(&cVar_7yLCYjgD, 0.0f);
  numBytes += cVar_init_f(&cVar_QzAjBMFA, 0.0f);
  numBytes += cIf_init(&cIf_9cV4O9DZ, false);
  numBytes += cIf_init(&cIf_h6vlmpnP, false);
  numBytes += cDelay_init(this, &cDelay_1FyWZMfJ, 10.0f);
  numBytes += cIf_init(&cIf_8vEkew8r, false);
  numBytes += cIf_init(&cIf_4PkoDPTj, false);
  numBytes += cDelay_init(this, &cDelay_G1XpZs8l, 10.0f);
  numBytes += cIf_init(&cIf_ni5V7yTa, false);
  numBytes += cIf_init(&cIf_3cFwTujv, false);
  numBytes += cDelay_init(this, &cDelay_dCNOa7Xq, 10.0f);
  numBytes += cIf_init(&cIf_H7hIMWFL, false);
  numBytes += cIf_init(&cIf_1pzsphbs, false);
  numBytes += cDelay_init(this, &cDelay_KV9saawW, 10.0f);
  numBytes += cIf_init(&cIf_QJp7wSYo, false);
  numBytes += cIf_init(&cIf_M55mtmdF, false);
  numBytes += cDelay_init(this, &cDelay_lndL8nmK, 10.0f);
  numBytes += cIf_init(&cIf_mTTO3hWc, false);
  numBytes += cIf_init(&cIf_pF68Ps9i, false);
  numBytes += cDelay_init(this, &cDelay_kim1ebnw, 10.0f);
  numBytes += cIf_init(&cIf_11hPWWaY, false);
  numBytes += cIf_init(&cIf_cAYSurrh, false);
  numBytes += cDelay_init(this, &cDelay_hyijO4Tn, 10.0f);
  numBytes += cIf_init(&cIf_8HknMyZo, false);
  numBytes += cIf_init(&cIf_Uu5jqDWN, false);
  numBytes += cDelay_init(this, &cDelay_51Mt8c74, 10.0f);
  numBytes += cIf_init(&cIf_0rMyKIMI, false);
  numBytes += cIf_init(&cIf_RXeYkXpJ, false);
  numBytes += cDelay_init(this, &cDelay_WPKQv8rj, 10.0f);
  numBytes += cIf_init(&cIf_nQyfsKKn, false);
  numBytes += cIf_init(&cIf_pCDfFiXk, false);
  numBytes += cDelay_init(this, &cDelay_7grlByP8, 10.0f);
  numBytes += cIf_init(&cIf_8xccKKjS, false);
  numBytes += cIf_init(&cIf_Z6mJ8nsi, false);
  numBytes += cDelay_init(this, &cDelay_A1CVnb3B, 10.0f);
  numBytes += cIf_init(&cIf_qMS5cgEf, false);
  numBytes += cIf_init(&cIf_7qO8aCHB, false);
  numBytes += cDelay_init(this, &cDelay_wyJxS8cJ, 10.0f);
  numBytes += sVarf_init(&sVarf_vM4aNVHz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bPCBbIg0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X1zIoxmy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_I7EIHINC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4FWm9vXX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eu3oxkpb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PZgImJ15, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SD1FNwy6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_zYk09tuk, 0.0f);
  numBytes += cSlice_init(&cSlice_bs9WUECD, 1, -1);
  numBytes += cVar_init_f(&cVar_ny9yNo1D, 1.0f);
  numBytes += cSlice_init(&cSlice_3Q189xTY, 1, -1);
  numBytes += cVar_init_f(&cVar_aWKOze0U, 0.0f);
  numBytes += cSlice_init(&cSlice_EVswSp87, 1, -1);
  numBytes += cVar_init_f(&cVar_0wTYKZSF, 512.0f);
  numBytes += cSlice_init(&cSlice_yfhd6GUz, 1, -1);
  numBytes += cVar_init_f(&cVar_T2vwXTxw, 1.0f);
  numBytes += cSlice_init(&cSlice_v0wrAHz7, 1, -1);
  numBytes += cVar_init_f(&cVar_Bp5lSYPb, 1.0f);
  numBytes += cDelay_init(this, &cDelay_eMznzQy1, 20.0f);
  numBytes += cVar_init_f(&cVar_YB47Jn9e, 0.0f);
  numBytes += cIf_init(&cIf_cBcpyMMb, false);
  numBytes += cIf_init(&cIf_gk165h40, false);
  numBytes += cBinop_init(&cBinop_DgTLCtLx, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_58wW0zmC, 1, -1);
  numBytes += cVar_init_f(&cVar_oWHUvzwx, 0.0f);
  numBytes += sVarf_init(&sVarf_llirQcZx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9u9opGp5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uE1RyC2q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ca2pHbyZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eQtx37x2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_89sTGpOR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_qdKpXXVf, 0.0f);
  numBytes += cVar_init_f(&cVar_k38NOFYJ, 0.0f);
  numBytes += cIf_init(&cIf_FwU8u5Wl, false);
  numBytes += cIf_init(&cIf_fzCSj2Nr, false);
  numBytes += cDelay_init(this, &cDelay_D0Aa7UeL, 10.0f);
  numBytes += cIf_init(&cIf_Z219Xkma, false);
  numBytes += cIf_init(&cIf_cy145gPV, false);
  numBytes += cDelay_init(this, &cDelay_yH0zZMb0, 10.0f);
  numBytes += cIf_init(&cIf_6pLP6WwZ, false);
  numBytes += cIf_init(&cIf_hQYqfS47, false);
  numBytes += cDelay_init(this, &cDelay_5hHmKgXv, 10.0f);
  numBytes += cIf_init(&cIf_vWAlrQmU, false);
  numBytes += cIf_init(&cIf_QQLUYEbt, false);
  numBytes += cDelay_init(this, &cDelay_Vc0wELzk, 10.0f);
  numBytes += cIf_init(&cIf_aGo25Mwp, false);
  numBytes += cIf_init(&cIf_N63a2foj, false);
  numBytes += cDelay_init(this, &cDelay_3QiQ7G04, 10.0f);
  numBytes += cIf_init(&cIf_GdyHn7Ur, false);
  numBytes += cIf_init(&cIf_wgb9mMRo, false);
  numBytes += cDelay_init(this, &cDelay_M4IuvHrz, 10.0f);
  numBytes += cIf_init(&cIf_8fJFgJWG, false);
  numBytes += cIf_init(&cIf_9u0QczOw, false);
  numBytes += cDelay_init(this, &cDelay_577AWTv4, 10.0f);
  numBytes += cIf_init(&cIf_ngUP2kWl, false);
  numBytes += cIf_init(&cIf_B1JNnVvs, false);
  numBytes += cDelay_init(this, &cDelay_zS16b9UA, 10.0f);
  numBytes += cIf_init(&cIf_K6YpU0Se, false);
  numBytes += cIf_init(&cIf_EkOCfPJM, false);
  numBytes += cDelay_init(this, &cDelay_sWrvoA0T, 10.0f);
  numBytes += cIf_init(&cIf_7edLrPeE, false);
  numBytes += cIf_init(&cIf_ABuHpwvn, false);
  numBytes += cDelay_init(this, &cDelay_qwegke8d, 10.0f);
  numBytes += cIf_init(&cIf_DqWkpNIQ, false);
  numBytes += cIf_init(&cIf_bPtTdWFW, false);
  numBytes += cDelay_init(this, &cDelay_nrg9U6BQ, 10.0f);
  numBytes += cIf_init(&cIf_rZeQsZzd, false);
  numBytes += cIf_init(&cIf_E69qujU7, false);
  numBytes += cDelay_init(this, &cDelay_DLEGZ2qN, 10.0f);
  numBytes += sVarf_init(&sVarf_DIpCegVV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0geJCC9I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SN0LZCnV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ndeaqwL7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J3usvRQQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_q6tlJwFR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JjKV1lnw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Gt8PsT21, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_z5fEe2R9, 0.0f);
  numBytes += cSlice_init(&cSlice_u7zIVlk3, 1, -1);
  numBytes += cVar_init_f(&cVar_Dikkjcdl, 1.0f);
  numBytes += cSlice_init(&cSlice_VswVlnM9, 1, -1);
  numBytes += cVar_init_f(&cVar_mQ38xka7, 0.0f);
  numBytes += cSlice_init(&cSlice_Ni9st1ev, 1, -1);
  numBytes += cVar_init_f(&cVar_JvN0zXQZ, 512.0f);
  numBytes += cSlice_init(&cSlice_KOrMJsr1, 1, -1);
  numBytes += cVar_init_f(&cVar_1YOuRCXe, 1.0f);
  numBytes += cSlice_init(&cSlice_XKmMsgiS, 1, -1);
  numBytes += cVar_init_f(&cVar_WhH5TsVL, 1.0f);
  numBytes += cDelay_init(this, &cDelay_vaba5I1Z, 20.0f);
  numBytes += cVar_init_f(&cVar_PcUeqdUK, 0.0f);
  numBytes += cIf_init(&cIf_MRQOYbW2, false);
  numBytes += cIf_init(&cIf_ZFnBO7uI, false);
  numBytes += cBinop_init(&cBinop_GQ693Exc, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_CCtkWSFS, 1, -1);
  numBytes += cVar_init_f(&cVar_m06lpDR3, 0.0f);
  numBytes += sVarf_init(&sVarf_vi5Fctct, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SoYWy63a, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Q0PYeMvH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IvEWsdX3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uLkZCd77, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ze8tr5Kk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X5RwLAuJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_U5461xlu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TUD0eONN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_g09XqrKF, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_m4gDjc8w, 0.0f);
  numBytes += cVar_init_f(&cVar_alSEInAs, 0.0f);
  numBytes += cVar_init_f(&cVar_P368oZOy, 0.0f);
  numBytes += cVar_init_f(&cVar_T6UNdd3k, 0.0f);
  numBytes += cVar_init_f(&cVar_wpGeyKr2, 0.0f);
  numBytes += cVar_init_f(&cVar_Lle4C5ci, 1.0f);
  numBytes += cSlice_init(&cSlice_w8B6DEQu, 1, -1);
  numBytes += cVar_init_f(&cVar_lwnbz5JK, 0.5f);
  numBytes += cVar_init_f(&cVar_yHInAj9F, 0.0f);
  numBytes += cVar_init_f(&cVar_fBWkcMe0, 0.0f);
  numBytes += cIf_init(&cIf_5fZVY6hv, false);
  numBytes += cIf_init(&cIf_LjsLIaV9, false);
  numBytes += cDelay_init(this, &cDelay_4yajsfe6, 10.0f);
  numBytes += cIf_init(&cIf_tDRqM5W3, false);
  numBytes += cIf_init(&cIf_8vifUm9m, false);
  numBytes += cDelay_init(this, &cDelay_AKWom8Gz, 10.0f);
  numBytes += cIf_init(&cIf_5Uuku2cu, false);
  numBytes += cIf_init(&cIf_XiDb33OO, false);
  numBytes += cDelay_init(this, &cDelay_CMODb7c4, 10.0f);
  numBytes += cIf_init(&cIf_2fT1JyyR, false);
  numBytes += cIf_init(&cIf_zaFdn6Hx, false);
  numBytes += cDelay_init(this, &cDelay_yJVUuHBA, 10.0f);
  numBytes += cIf_init(&cIf_jn3UsDR6, false);
  numBytes += cIf_init(&cIf_zzUXBITP, false);
  numBytes += cDelay_init(this, &cDelay_drdeuEWE, 10.0f);
  numBytes += cIf_init(&cIf_jsFYIAFA, false);
  numBytes += cIf_init(&cIf_BR852D4E, false);
  numBytes += cDelay_init(this, &cDelay_adT77Y8G, 10.0f);
  numBytes += cIf_init(&cIf_VoUsQXUT, false);
  numBytes += cIf_init(&cIf_mhhw3Of0, false);
  numBytes += cDelay_init(this, &cDelay_NOrmrMSH, 10.0f);
  numBytes += cIf_init(&cIf_V33Qd6HQ, false);
  numBytes += cIf_init(&cIf_3r4Tsk7x, false);
  numBytes += cDelay_init(this, &cDelay_ttB9oDmr, 10.0f);
  numBytes += cIf_init(&cIf_mLVmk7gR, false);
  numBytes += cIf_init(&cIf_ej1fZBxi, false);
  numBytes += cDelay_init(this, &cDelay_yVtvpAen, 10.0f);
  numBytes += cIf_init(&cIf_CChWVnLb, false);
  numBytes += cIf_init(&cIf_POdpPOcx, false);
  numBytes += cDelay_init(this, &cDelay_bbrOJP5T, 10.0f);
  numBytes += cIf_init(&cIf_2sModqoS, false);
  numBytes += cIf_init(&cIf_JXGIlN3j, false);
  numBytes += cDelay_init(this, &cDelay_voeEgMax, 10.0f);
  numBytes += cIf_init(&cIf_J3dORVXs, false);
  numBytes += cIf_init(&cIf_iRhUAFvi, false);
  numBytes += cDelay_init(this, &cDelay_QIgOuYTj, 10.0f);
  numBytes += sVarf_init(&sVarf_oIZcFqL7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iqDXH6C9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NlULym3z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_idNOlVDM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xM0aVr8F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F6ro09Uh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zQJAyqlG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_evynaAQE, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_aMCmrFPN, 0.0f);
  numBytes += cSlice_init(&cSlice_Wb5yDn5h, 1, -1);
  numBytes += cVar_init_f(&cVar_OOmte1Sp, 1.0f);
  numBytes += cSlice_init(&cSlice_4ejBVgnq, 1, -1);
  numBytes += cVar_init_f(&cVar_mVNpyCh8, 0.0f);
  numBytes += cSlice_init(&cSlice_9e3aEqEE, 1, -1);
  numBytes += cVar_init_f(&cVar_wObed07w, 512.0f);
  numBytes += cSlice_init(&cSlice_a0Lnur2S, 1, -1);
  numBytes += cVar_init_f(&cVar_Y4SzEYpl, 1.0f);
  numBytes += cSlice_init(&cSlice_BsZgCCC3, 1, -1);
  numBytes += cVar_init_f(&cVar_MIMCZvOZ, 1.0f);
  numBytes += cDelay_init(this, &cDelay_p4X2hcK2, 20.0f);
  numBytes += cVar_init_f(&cVar_Fobv1t6w, 0.0f);
  numBytes += cIf_init(&cIf_TMYSro8g, false);
  numBytes += cIf_init(&cIf_QKESGZe6, false);
  numBytes += cBinop_init(&cBinop_5tD2wr7x, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_wi9FFQj1, 1, -1);
  numBytes += cVar_init_f(&cVar_Iv55f3Um, 0.0f);
  numBytes += sVarf_init(&sVarf_9lPR4iXT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yII62lxL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cyL0YuGJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LUu7bTD1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yHE0Onv8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VorGpghf, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_nOKFV5rW, 0.0f);
  numBytes += cVar_init_f(&cVar_YznWcLwF, 0.0f);
  numBytes += cIf_init(&cIf_AllYOIbi, false);
  numBytes += cIf_init(&cIf_YYRowGRG, false);
  numBytes += cDelay_init(this, &cDelay_jOOl8c7M, 10.0f);
  numBytes += cIf_init(&cIf_2PkCx5nA, false);
  numBytes += cIf_init(&cIf_ge0cK5p2, false);
  numBytes += cDelay_init(this, &cDelay_sem9tAPi, 10.0f);
  numBytes += cIf_init(&cIf_TMcZYvIc, false);
  numBytes += cIf_init(&cIf_7v8u0Gz9, false);
  numBytes += cDelay_init(this, &cDelay_pt7Tq91P, 10.0f);
  numBytes += cIf_init(&cIf_5a0xqCbe, false);
  numBytes += cIf_init(&cIf_KUnllLfX, false);
  numBytes += cDelay_init(this, &cDelay_qiPxVNP9, 10.0f);
  numBytes += cIf_init(&cIf_hoHL3BK9, false);
  numBytes += cIf_init(&cIf_cBMz84B4, false);
  numBytes += cDelay_init(this, &cDelay_P6bHZ0aU, 10.0f);
  numBytes += cIf_init(&cIf_g3x3jvqv, false);
  numBytes += cIf_init(&cIf_rqjRr7Ea, false);
  numBytes += cDelay_init(this, &cDelay_VOFX6W3G, 10.0f);
  numBytes += cIf_init(&cIf_Wx7aqvjD, false);
  numBytes += cIf_init(&cIf_jp3ORsjP, false);
  numBytes += cDelay_init(this, &cDelay_VyyqS9Ey, 10.0f);
  numBytes += cIf_init(&cIf_6cyd9Nuy, false);
  numBytes += cIf_init(&cIf_KyohM2bQ, false);
  numBytes += cDelay_init(this, &cDelay_Lg3KZr2w, 10.0f);
  numBytes += cIf_init(&cIf_BwAXWfXb, false);
  numBytes += cIf_init(&cIf_9tcANQ8V, false);
  numBytes += cDelay_init(this, &cDelay_cxnJlgfy, 10.0f);
  numBytes += cIf_init(&cIf_np9ODuXe, false);
  numBytes += cIf_init(&cIf_QoH1w0mx, false);
  numBytes += cDelay_init(this, &cDelay_FdW48FWz, 10.0f);
  numBytes += cIf_init(&cIf_zLfn8f0W, false);
  numBytes += cIf_init(&cIf_2VBdsOvk, false);
  numBytes += cDelay_init(this, &cDelay_1N14Ddav, 10.0f);
  numBytes += cIf_init(&cIf_ERj0MIQA, false);
  numBytes += cIf_init(&cIf_fshJE2Bf, false);
  numBytes += cDelay_init(this, &cDelay_0RIvZI8E, 10.0f);
  numBytes += sVarf_init(&sVarf_jgwrvExx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e5KvUU7o, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kDt5ETqJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zu107Sgh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jO6tOgOF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZwEsvpfI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oQwjKOVU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5nTjk5Ji, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TraQQT8l, 0.0f);
  numBytes += cSlice_init(&cSlice_49vs4t6Z, 1, -1);
  numBytes += cVar_init_f(&cVar_jcVHKXZd, 1.0f);
  numBytes += cSlice_init(&cSlice_aBkt3StK, 1, -1);
  numBytes += cVar_init_f(&cVar_tvSaYIkI, 0.0f);
  numBytes += cSlice_init(&cSlice_tGmBjUlc, 1, -1);
  numBytes += cVar_init_f(&cVar_ZqD2XQYh, 512.0f);
  numBytes += cSlice_init(&cSlice_HhmQy4CG, 1, -1);
  numBytes += cVar_init_f(&cVar_Ii8fY64H, 1.0f);
  numBytes += cSlice_init(&cSlice_5YONkeIp, 1, -1);
  numBytes += cVar_init_f(&cVar_cilivHIt, 1.0f);
  numBytes += cDelay_init(this, &cDelay_kmgxwr82, 20.0f);
  numBytes += cVar_init_f(&cVar_1bSMipm4, 0.0f);
  numBytes += cIf_init(&cIf_kBRH4qv1, false);
  numBytes += cIf_init(&cIf_zehosmPY, false);
  numBytes += cBinop_init(&cBinop_yf6sMYSH, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_uEqzJEWl, 1, -1);
  numBytes += cVar_init_f(&cVar_5QPgUGsk, 0.0f);
  numBytes += sVarf_init(&sVarf_QP23FpoF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aNt8XBr2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WRsmfVLw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_89aMo4eO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d1cMZSmW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wC6pWcyl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZUhvqdXk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JSXuxxM0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QrDFe6ja, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3xVTWxpG, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_esqtsJjA, 0.0f);
  numBytes += cVar_init_f(&cVar_s5CRKoTg, 0.0f);
  numBytes += cVar_init_f(&cVar_v9dAYkf6, 0.0f);
  numBytes += sVarf_init(&sVarf_TmPb2GLC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BsPnnL0H, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XZaGhNv5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_acDxGGvT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RIq0KECv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nNSoAJ7V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rewwnkEO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FEAATwXH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qt0S1JKK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JjMWaUzb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QoPQ4NkK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kHGAQH1R, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_fgWNHB81);
  sEnv_free(&sEnv_WsuIkwS7);
  sEnv_free(&sEnv_U66skpCM);
  sEnv_free(&sEnv_L63ZQJAj);
  sEnv_free(&sEnv_SjIBOi8Q);
  sEnv_free(&sEnv_RSZCApoZ);
  sEnv_free(&sEnv_KdHzar7f);
  sEnv_free(&sEnv_qCcdMQme);
  sEnv_free(&sEnv_vI5Kdkjy);
  sEnv_free(&sEnv_g9hXzi6C);
  sEnv_free(&sEnv_KYwy1NVO);
  sEnv_free(&sEnv_VORzBCkF);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iQ7XyQAZ_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rpnPAduh_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5bGH6sZI_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1KPWJHtI_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZPCTP7BB_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BSq83PSa_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8RlWC8uA_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x49M55fL_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eIYFfoHn_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IgnqgPkm_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0WZhwv3i_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4xPnlNkz_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AnfCl9Gl_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aMkqupqz_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WMvSt9gx_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QaJCB7GS_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eGBowazG_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p1F8DLTf_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BKTrDj9c_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZhOS1DLp_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GECtYA5A_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5FlUyDxY_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IwEl6lLB_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DUYE45B8_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AgRCvhtk_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lk2A7xhn_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p4RSFlgi_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rSXBnNZr_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ViJmIDoU_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bEu72nyt_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cM9HXeoS_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5SL2OMfg_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4UCsTNL1_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bv8j2EP0_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MbsdF5mT_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HWDqHQxo_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NgDF83Uu_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1H4CA4ku_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LdF1VQ00_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XUty40Ct_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZM7Glcmv_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZgVdZrcw_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZNAMyH8A_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_N7YWfdVE_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oPHk4544_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G75U7li2_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cx4ol518_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YfZ8jAty_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Cxdwfc2u_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZCA7oyPV_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XCMqiWRr_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_89agFZJx_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uHtqInYe_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RQX1mdKP_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4aMGj1we_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zXWuQM0l_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_azWfKNU6_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UWVEI7Us_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WC4tU9wX_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gnIwIrdI_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DpM1m0Dn_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yU4mQBbK_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_toSbo5bm_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1Pr5UXPo_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ujxxDbKm_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WxBuzXuA_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KfdvfLHn_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DW29e6Qt_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_flI0DG9u_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WlKbBxNe_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6ef7uFFn_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S2ZfbN2T_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hxWWOb38_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wRVNtgC2_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gX7wAPzS_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mtN2W62Z_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nL7S2XAw_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ghoyjacp_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qw1qHZQn_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3mxBpF6Z_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GlexAEpq_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yiXZeg8X_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lg40LJZ9_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1WQI9Xwr_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CQ16QyOB_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4CWd0u4e_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V2b2sYyC_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MJQvTOri_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HkvrjzzF_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fO9DnkbI_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2m2eYW5G_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lIG3enqI_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wzCJNLHS_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_A3DpyPSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rGUYXdPM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_3Vnt0YXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F5RhBnM6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_nUZEePEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fN6uyVYh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_bxoMx4Ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q8FoONg9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_GgMJeAYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qgRr1NVL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_6rncuoHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T39YpU5K_sendMessage);
  cMsg_dmjoxPzP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_T39YpU5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6rncuoHc, 1, m, &cVar_6rncuoHc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PG9uVuBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y0yuC5Sg_sendMessage(_c, 0, m);
  cMsg_otbupuKX_sendMessage(_c, 0, m);
  cMsg_rL8voJya_sendMessage(_c, 0, m);
  cMsg_4YLFe0nu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9SjHdA7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XLkE40zb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_KsPrAKUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hMVCuVii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_7xSZlgMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hWMrQ8oM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9v4oL3mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rFp7pqyC_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2QbDVDGi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JmNTLLip_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OsOZyj77_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cQGR2ve5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_63VvxXza, 0, m, &cSlice_63VvxXza_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Ceww1Rau_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_63VvxXza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_263iomRJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_263iomRJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_rsXocbM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_263iomRJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_263iomRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rSXBnNZr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_RjqlEO9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5wksTA4T_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PetnRNa1, 0, m, &cIf_PetnRNa1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_PetnRNa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_L7Uf141Q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Aa9tCrEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_UnV4POsF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1qN4k8Xh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_PEvpk9Ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FfdMupfv, HV_BINOP_POW, 0, m, &cBinop_FfdMupfv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FfdMupfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KRAJUk2U, 0, m, &cIf_KRAJUk2U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6C0TU1z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_wnOH9Ihs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ntVJgZSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Aa9tCrEa, 0, m, &cIf_Aa9tCrEa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TdJmoOK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0Ajs44bW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0Ajs44bW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Aa9tCrEa, 1, m, &cIf_Aa9tCrEa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1qN4k8Xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_6C0TU1z1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UnV4POsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_KRAJUk2U, 0, m, &cIf_KRAJUk2U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wnOH9Ihs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FfdMupfv, HV_BINOP_POW, 1, m, &cBinop_FfdMupfv_sendMessage);
  cMsg_PEvpk9Ce_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_KRAJUk2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FyprVgjK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_5wksTA4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PetnRNa1, 1, m, &cIf_PetnRNa1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L7Uf141Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HqypJSyR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vI8pEl1V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6IN6I1km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TdJmoOK7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ntVJgZSC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J8G2cDJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KRAJUk2U, 1, m, &cIf_KRAJUk2U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LwIRacl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jye8Sh0n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jye8Sh0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_FyprVgjK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Mcl5nl7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_6IN6I1km_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vI8pEl1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J8G2cDJQ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_J8G2cDJQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HqypJSyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LwIRacl9, HV_BINOP_EQ, 1, m, &cBinop_LwIRacl9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aT82hVMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J8G2cDJQ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_J8G2cDJQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ASlZqXbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LwIRacl9, HV_BINOP_EQ, 0, m, &cBinop_LwIRacl9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bILGdZdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mcl5nl7h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8C6nCjmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RjqlEO9D, 0, m, &cVar_RjqlEO9D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ut8DoDQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pipYSISd_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Aejqulzo, 0, m, &cIf_Aejqulzo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Aejqulzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_RuAY8nvT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1PSrTYoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_64wJU8Zd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WF3FV0AJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_fJDBFA8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r7mdCBbe, HV_BINOP_POW, 0, m, &cBinop_r7mdCBbe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r7mdCBbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bH2nMnpE, 0, m, &cIf_bH2nMnpE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jLMkEngK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_PMSlZO4H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dELmi7Lp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1PSrTYoj, 0, m, &cIf_1PSrTYoj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eY7XuEQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aZIeBS7D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aZIeBS7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1PSrTYoj, 1, m, &cIf_1PSrTYoj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WF3FV0AJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_jLMkEngK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_64wJU8Zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_bH2nMnpE, 0, m, &cIf_bH2nMnpE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PMSlZO4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r7mdCBbe, HV_BINOP_POW, 1, m, &cBinop_r7mdCBbe_sendMessage);
  cMsg_fJDBFA8M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_bH2nMnpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vwMn5lfY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n0JYvMKG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_pipYSISd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Aejqulzo, 1, m, &cIf_Aejqulzo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RuAY8nvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vj3ZshKa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WlESTaMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V0shTQEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eY7XuEQQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dELmi7Lp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kxqDcm9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bH2nMnpE, 1, m, &cIf_bH2nMnpE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CoiOxovs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ggRvRoXS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ggRvRoXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vwMn5lfY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n0JYvMKG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gnaiFOtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_V0shTQEo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WlESTaMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxqDcm9E, HV_BINOP_GREATER_THAN, 1, m, &cBinop_kxqDcm9E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vj3ZshKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CoiOxovs, HV_BINOP_EQ, 1, m, &cBinop_CoiOxovs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I27QHvO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CoiOxovs, HV_BINOP_EQ, 0, m, &cBinop_CoiOxovs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7qQ5a7Er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gnaiFOtj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BFn4P0bJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ut8DoDQ2, 0, m, &cVar_ut8DoDQ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_scpeh0IA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxqDcm9E, HV_BINOP_GREATER_THAN, 0, m, &cBinop_kxqDcm9E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_vCfPpDMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_coCg3Klb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_AlttwDI1, 0, m, &cIf_AlttwDI1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_AlttwDI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_oJzHfeTc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_h6V9H1Mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_tKJs2Bcz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_xgdelurm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_wiWRIb7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XbtLr4JH, HV_BINOP_POW, 0, m, &cBinop_XbtLr4JH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XbtLr4JH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sXKeEQWc, 0, m, &cIf_sXKeEQWc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F3P55VLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_u1TL9s0y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MXIgMpSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h6V9H1Mc, 0, m, &cIf_h6V9H1Mc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dr5wKLlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gwNroGiL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gwNroGiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h6V9H1Mc, 1, m, &cIf_h6V9H1Mc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xgdelurm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_F3P55VLl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tKJs2Bcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_sXKeEQWc, 0, m, &cIf_sXKeEQWc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u1TL9s0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XbtLr4JH, HV_BINOP_POW, 1, m, &cBinop_XbtLr4JH_sendMessage);
  cMsg_wiWRIb7M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_sXKeEQWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0KiE5vzr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_coCg3Klb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AlttwDI1, 1, m, &cIf_AlttwDI1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oJzHfeTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9tTSnp5r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fGD8BYFP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sS9jCGYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dr5wKLlr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MXIgMpSe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xAse6ZRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sXKeEQWc, 1, m, &cIf_sXKeEQWc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KGqwlOcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AMRe5SHQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AMRe5SHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_0KiE5vzr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xNhDUq3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_sS9jCGYC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fGD8BYFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAse6ZRw, HV_BINOP_GREATER_THAN, 1, m, &cBinop_xAse6ZRw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9tTSnp5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KGqwlOcQ, HV_BINOP_EQ, 1, m, &cBinop_KGqwlOcQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5mQ7IhlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KGqwlOcQ, HV_BINOP_EQ, 0, m, &cBinop_KGqwlOcQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HpcSMH2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xNhDUq3G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_H3chIFDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vCfPpDMI, 0, m, &cVar_vCfPpDMI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xvGhIwCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAse6ZRw, HV_BINOP_GREATER_THAN, 0, m, &cBinop_xAse6ZRw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_L0LHvtgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VnZmSkj6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zOkyc0Fm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_P9SuJ7Sw, 0, m, &cSlice_P9SuJ7Sw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vrSKYJN0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_P9SuJ7Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WtAsbjtr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WtAsbjtr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YZioZjYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WtAsbjtr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WtAsbjtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lk2A7xhn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vrSKYJN0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gs12FOZ7, 0, m, &cSlice_gs12FOZ7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cQGR2ve5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gs12FOZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cn8CEKvS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cn8CEKvS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_9gIO857E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cn8CEKvS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_cn8CEKvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bEu72nyt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ceww1Rau_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jACMVzZW, 0, m, &cSlice_jACMVzZW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6kKnckpF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_jACMVzZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bT5XrLyR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bT5XrLyR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_OlVuuVD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bT5XrLyR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_bT5XrLyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_p4RSFlgi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6kKnckpF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_j4EEcbKz, 0, m, &cSlice_j4EEcbKz_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_j4EEcbKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eLBrcQRv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eLBrcQRv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TENoGe3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eLBrcQRv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_eLBrcQRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ViJmIDoU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oQRiSZ9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ls3zVMaZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7dmXe5qD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tyPOY8jl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tKf8wjFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B6TjHgV2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4jwKwcsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i4uXFHFW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_puLJYUu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Lcv5nsDe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yAhRbdPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2saHmFOd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_2saHmFOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gWJUlEzZ, HV_BINOP_DIVIDE, 1, m, &cBinop_gWJUlEzZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DsGd8Va3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_6PghZqOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_zDzuDvgS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OeThycol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_6PghZqOc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zDzuDvgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gWJUlEzZ, HV_BINOP_DIVIDE, 0, m, &cBinop_gWJUlEzZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DsGd8Va3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OeThycol_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_gWJUlEzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JQUPpsXk, HV_BINOP_MULTIPLY, 1, m, &cBinop_JQUPpsXk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JQUPpsXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h6RvaWxL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gMOcT6iA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_If8iglVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eW2uoK4R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_an3bxQbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SipGkokL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_R0vrOJL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6sTL5aXU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6sTL5aXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JQUPpsXk, HV_BINOP_MULTIPLY, 0, m, &cBinop_JQUPpsXk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KwwZz6T8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_1iZfY8vW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1iZfY8vW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PGGnD53Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_VRl00IoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IsVbxfI8, 1, m, &cVar_IsVbxfI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_IsVbxfI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PN0zRUkL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GNuM0sNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RcY0ezAj, HV_BINOP_MULTIPLY, 1, m, &cBinop_RcY0ezAj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nIoabAG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GNuM0sNj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xgzzDbKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1sekTncZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1sekTncZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PG5Zo70q, HV_BINOP_MULTIPLY, 1, m, &cBinop_PG5Zo70q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E3sXkpW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ugh7nq6P, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ugh7nq6P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I0hPCWoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_E3sXkpW2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IbUsh9VK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rtVPOZEv, HV_BINOP_MULTIPLY, 1, m, &cBinop_rtVPOZEv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QfohpCFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mfwsgDFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mfwsgDFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_davLmB5f, HV_BINOP_MULTIPLY, 1, m, &cBinop_davLmB5f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_F3m46Eek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_57UsvCHN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_R0vrOJL1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YOtGQblQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_H4iEMOqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_KwwZz6T8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gMOcT6iA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_an3bxQbA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h6RvaWxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_If8iglVN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_eW2uoK4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4UCsTNL1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_SipGkokL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5SL2OMfg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FkNOAEsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cM9HXeoS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PGGnD53Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SEpiZix8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SEpiZix8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pe0vxtaK, HV_BINOP_MULTIPLY, 1, m, &cBinop_Pe0vxtaK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pe0vxtaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_N2MlrnnS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N2MlrnnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FkNOAEsB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PN0zRUkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pwZubA6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pwZubA6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0UdUzrKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l2BMRDfi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_82V3DLQh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Few98UJu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAG120Es_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOgq0ixF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RcY0ezAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oQRiSZ9a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PG5Zo70q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7dmXe5qD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Ugh7nq6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tKf8wjFV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_rtVPOZEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4jwKwcsd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_davLmB5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_puLJYUu7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_edYW8SW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F3m46Eek, 0, m, &cVar_F3m46Eek_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eXjr5eW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H4iEMOqb, 1, m, &cVar_H4iEMOqb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Few98UJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ugh7nq6P, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ugh7nq6P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0UdUzrKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_mOgq0ixF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RcY0ezAj, HV_BINOP_MULTIPLY, 0, m, &cBinop_RcY0ezAj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_82V3DLQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rtVPOZEv, HV_BINOP_MULTIPLY, 0, m, &cBinop_rtVPOZEv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rAG120Es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PG5Zo70q, HV_BINOP_MULTIPLY, 0, m, &cBinop_PG5Zo70q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l2BMRDfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_davLmB5f, HV_BINOP_MULTIPLY, 0, m, &cBinop_davLmB5f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YOtGQblQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IsVbxfI8, 0, m, &cVar_IsVbxfI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_57UsvCHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H4iEMOqb, 0, m, &cVar_H4iEMOqb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_et9zeWbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6BWcx5SW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FkADnpXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sfc8rYUU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rWwGdgK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hFtZtHmg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8GpZF66k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h75433Zi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_t99Z0z8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xBJLeEjK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_xBJLeEjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iRXE3UpN, HV_BINOP_DIVIDE, 1, m, &cBinop_iRXE3UpN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xfcVNus4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_XIk8vapf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_j5WiBwLI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AphGp6Ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_XIk8vapf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j5WiBwLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iRXE3UpN, HV_BINOP_DIVIDE, 0, m, &cBinop_iRXE3UpN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xfcVNus4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AphGp6Ck_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_iRXE3UpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U6MxrSQ1, HV_BINOP_MULTIPLY, 1, m, &cBinop_U6MxrSQ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U6MxrSQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HmEnlupH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y0lmEdYD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_pS4IHl0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HtvSK7Jf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_9GW5zVOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2VU3sHCu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NxtIqXkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_8WR2RFtv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8WR2RFtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U6MxrSQ1, HV_BINOP_MULTIPLY, 0, m, &cBinop_U6MxrSQ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e5RqBOGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Vt4vnF00_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vt4vnF00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e077Un2q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_uARNc7fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XPf0kag2, HV_BINOP_MULTIPLY, 1, m, &cBinop_XPf0kag2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IhPTQymv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZlMeH5FJ, 1, m, &cVar_ZlMeH5FJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7RYCSkXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mr3pFIW8, HV_BINOP_MULTIPLY, 1, m, &cBinop_Mr3pFIW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_myOFXg0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_d26uCXAI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d26uCXAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ipfMToPo, HV_BINOP_MULTIPLY, 1, m, &cBinop_ipfMToPo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ZlMeH5FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jKUS8UPV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9bAxG93b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zn7BqYfr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_NxtIqXkI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LavxLLOX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_GSmMJyz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_e5RqBOGB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y0lmEdYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9GW5zVOb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HmEnlupH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_pS4IHl0P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_HtvSK7Jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HWDqHQxo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_2VU3sHCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MbsdF5mT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gyIMTGHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bv8j2EP0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_e077Un2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VtqIQgaJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VtqIQgaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o4jzlu8y, HV_BINOP_MULTIPLY, 1, m, &cBinop_o4jzlu8y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_o4jzlu8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qvMEs3Ka_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qvMEs3Ka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gyIMTGHO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jKUS8UPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8MWN2iRz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8MWN2iRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DzsxHllj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nNOZL5l7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OW7VWN0x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0RAxKu7d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9q7W6Zce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_et9zeWbz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_XPf0kag2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FkADnpXt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Mr3pFIW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rWwGdgK6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ipfMToPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8GpZF66k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_aDUIG21V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GSmMJyz5, 1, m, &cVar_GSmMJyz5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mKbsO7Df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9bAxG93b, 0, m, &cVar_9bAxG93b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Zn7BqYfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GSmMJyz5, 0, m, &cVar_GSmMJyz5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LavxLLOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZlMeH5FJ, 0, m, &cVar_ZlMeH5FJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nNOZL5l7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mr3pFIW8, HV_BINOP_MULTIPLY, 0, m, &cBinop_Mr3pFIW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0RAxKu7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9q7W6Zce, HV_BINOP_MULTIPLY, 0, m, &cBinop_9q7W6Zce_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DzsxHllj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ipfMToPo, HV_BINOP_MULTIPLY, 0, m, &cBinop_ipfMToPo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OW7VWN0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XPf0kag2, HV_BINOP_MULTIPLY, 0, m, &cBinop_XPf0kag2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gjVs7qt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PcpMyUme, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ev5zB4vn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y5VkiSj2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KYGLLrGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j5Z0amXb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DdGWjCYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6dlpI8ph, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4WA9gbmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mwumiwFa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bfm03vzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FCb66G3m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_FCb66G3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PrnSjtDM, HV_BINOP_DIVIDE, 1, m, &cBinop_PrnSjtDM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FzPcgeG4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_g8joxqIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_D4a4NEoh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xeAj5lKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_g8joxqIc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D4a4NEoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PrnSjtDM, HV_BINOP_DIVIDE, 0, m, &cBinop_PrnSjtDM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FzPcgeG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xeAj5lKe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PrnSjtDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P4MDY0ZD, HV_BINOP_MULTIPLY, 1, m, &cBinop_P4MDY0ZD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P4MDY0ZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3WZv7ODb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M99lbyLl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_TSNcjZnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nKGp9X7W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_raJsBvCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_va9o0xm9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jWA2LgHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_78uEWEuV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_78uEWEuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P4MDY0ZD, HV_BINOP_MULTIPLY, 0, m, &cBinop_P4MDY0ZD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_84gpA73G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_KJKiSKHv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KJKiSKHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wbX01y8B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_y47Zkpm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WPUPYfTT, HV_BINOP_MULTIPLY, 1, m, &cBinop_WPUPYfTT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lIST7BzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Fqo1bbIB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fqo1bbIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_y47Zkpm9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8LRFqNO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QvVTCXtf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QvVTCXtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_opi2SxkS, HV_BINOP_MULTIPLY, 1, m, &cBinop_opi2SxkS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_72tw3afU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pGNIZBdZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_pGNIZBdZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iwWhCWrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zFlua4ic_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zFlua4ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_72tw3afU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_griRHRgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aYPdIv4k, 1, m, &cVar_aYPdIv4k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0COfom0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QIPemjeZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_QIPemjeZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7DzioeB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qxepuiD4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qxepuiD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hMMcpJnm, HV_BINOP_MULTIPLY, 1, m, &cBinop_hMMcpJnm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_aYPdIv4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lgkNXI6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Pp5qqHEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yBtkZRwr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_jWA2LgHe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9PMVZIio_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_rZHY2mJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_84gpA73G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M99lbyLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_raJsBvCt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3WZv7ODb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_TSNcjZnT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_nKGp9X7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LdF1VQ00_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_va9o0xm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1H4CA4ku_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GobrjY86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NgDF83Uu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wbX01y8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6qUYNaG4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6qUYNaG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hz5koRqe, HV_BINOP_MULTIPLY, 1, m, &cBinop_hz5koRqe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hz5koRqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9BTJ3Zs4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9BTJ3Zs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GobrjY86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lgkNXI6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WVTJ9NRr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WVTJ9NRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8aMMxJvS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VFveQQ3q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gXLL4lVz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vFwSkS55_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yhl7nwYb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hrYfzaCm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WPUPYfTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gjVs7qt5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_opi2SxkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ev5zB4vn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_pGNIZBdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KYGLLrGf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QIPemjeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DdGWjCYi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_hMMcpJnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4WA9gbmB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_fwg6Mc0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Pp5qqHEx, 0, m, &cVar_Pp5qqHEx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MSHl74po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rZHY2mJ6, 1, m, &cVar_rZHY2mJ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vFwSkS55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pGNIZBdZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_pGNIZBdZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8aMMxJvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_hrYfzaCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WPUPYfTT, HV_BINOP_MULTIPLY, 0, m, &cBinop_WPUPYfTT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gXLL4lVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QIPemjeZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_QIPemjeZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Yhl7nwYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_opi2SxkS, HV_BINOP_MULTIPLY, 0, m, &cBinop_opi2SxkS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VFveQQ3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hMMcpJnm, HV_BINOP_MULTIPLY, 0, m, &cBinop_hMMcpJnm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9PMVZIio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aYPdIv4k, 0, m, &cVar_aYPdIv4k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yBtkZRwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rZHY2mJ6, 0, m, &cVar_rZHY2mJ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oZ5a6t1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L0LHvtgI, 1, m, &cIf_L0LHvtgI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jx6F8B7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_VnZmSkj6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WwvmF1WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jx6F8B7B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jOmCWXQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L0LHvtgI, 0, m, &cIf_L0LHvtgI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FyprVgjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y6l8UlfR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VnZmSkj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N1HEYoZg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0KiE5vzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_txsD6EeR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_n0JYvMKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_jOmCWXQP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vwMn5lfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oZ5a6t1U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WwvmF1WU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Wz2a1MZ8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xOyuDpKs, 0, m, &cSlice_xOyuDpKs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1UCqz6RB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xOyuDpKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eJg7rKLJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eJg7rKLJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sRSOQQJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eJg7rKLJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_eJg7rKLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZgVdZrcw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_S2Dea1NV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0Y9dPGdm_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_H20ddYqD, 0, m, &cIf_H20ddYqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_H20ddYqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_b0gpTpkD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_R1hGWKlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_wcWOhVbj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_GTK1D1I4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_mh2DXoSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CpaH3CbJ, HV_BINOP_POW, 0, m, &cBinop_CpaH3CbJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CpaH3CbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AHhpuMSq, 0, m, &cIf_AHhpuMSq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f3xZmSTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JrPLENwQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HQhlRSpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XpOpDXjF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t9coZUbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R1hGWKlq, 0, m, &cIf_R1hGWKlq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XpOpDXjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R1hGWKlq, 1, m, &cIf_R1hGWKlq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GTK1D1I4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_f3xZmSTk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wcWOhVbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AHhpuMSq, 0, m, &cIf_AHhpuMSq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JrPLENwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CpaH3CbJ, HV_BINOP_POW, 1, m, &cBinop_CpaH3CbJ_sendMessage);
  cMsg_mh2DXoSW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_AHhpuMSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gtmh9p3q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_0Y9dPGdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H20ddYqD, 1, m, &cIf_H20ddYqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b0gpTpkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TllqyyuS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UaYrKWKg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YR1LpGBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HQhlRSpd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t9coZUbl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oGB1rPdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AHhpuMSq, 1, m, &cIf_AHhpuMSq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bIHrNbg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V1T1yMRd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_V1T1yMRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_gtmh9p3q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7xvRnAyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_YR1LpGBG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UaYrKWKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oGB1rPdd, HV_BINOP_GREATER_THAN, 1, m, &cBinop_oGB1rPdd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TllqyyuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bIHrNbg5, HV_BINOP_EQ, 1, m, &cBinop_bIHrNbg5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t808Zwqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S2Dea1NV, 0, m, &cVar_S2Dea1NV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZY40slxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oGB1rPdd, HV_BINOP_GREATER_THAN, 0, m, &cBinop_oGB1rPdd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0QoYAfIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bIHrNbg5, HV_BINOP_EQ, 0, m, &cBinop_bIHrNbg5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_edhB4T1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7xvRnAyg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ivqaJ7P9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UfTWIsSu_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_eKmd8xS0, 0, m, &cIf_eKmd8xS0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_eKmd8xS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1TyeE1gi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_riyp3xP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YqVcS9eK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aoSVUlOu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_XEte4WHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b0Dea7ak, HV_BINOP_POW, 0, m, &cBinop_b0Dea7ak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b0Dea7ak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TQ3FqSyG, 0, m, &cIf_TQ3FqSyG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bsx1Ny3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Ih2lxkn4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YFPaJFKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_riyp3xP3, 0, m, &cIf_riyp3xP3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LXxNu1sU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0vqX9q54_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0vqX9q54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_riyp3xP3, 1, m, &cIf_riyp3xP3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aoSVUlOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Bsx1Ny3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YqVcS9eK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_TQ3FqSyG, 0, m, &cIf_TQ3FqSyG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ih2lxkn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b0Dea7ak, HV_BINOP_POW, 1, m, &cBinop_b0Dea7ak_sendMessage);
  cMsg_XEte4WHB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_TQ3FqSyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJszM3H_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V4TqOWDv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_UfTWIsSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eKmd8xS0, 1, m, &cIf_eKmd8xS0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1TyeE1gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LohZfBJl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X3dH8LEF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EBisXKSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LXxNu1sU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YFPaJFKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nKzslviM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TQ3FqSyG, 1, m, &cIf_TQ3FqSyG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XYhA7e85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rDvGQmi0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rDvGQmi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJszM3H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V4TqOWDv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cpJamWG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_EBisXKSp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X3dH8LEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nKzslviM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_nKzslviM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LohZfBJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XYhA7e85, HV_BINOP_EQ, 1, m, &cBinop_XYhA7e85_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XcGSMvEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nKzslviM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_nKzslviM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3RswZ3GX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XYhA7e85, HV_BINOP_EQ, 0, m, &cBinop_XYhA7e85_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4TN86go4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cpJamWG5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9q4WBDtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ivqaJ7P9, 0, m, &cVar_ivqaJ7P9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_RFh6itNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_g5Qrkitb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_hefUIUgF, 0, m, &cIf_hefUIUgF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_hefUIUgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vXRh9DZC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_iBHWyqH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_GaXPyORb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_CmuNnNVC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_U1292Kmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WOvmoFBm, HV_BINOP_POW, 0, m, &cBinop_WOvmoFBm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WOvmoFBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZ0xkH77, 0, m, &cIf_rZ0xkH77_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gfLQzwRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_24alMfi8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p1uLEIgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NkwRrgds_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QdAYNcKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iBHWyqH0, 0, m, &cIf_iBHWyqH0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NkwRrgds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iBHWyqH0, 1, m, &cIf_iBHWyqH0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CmuNnNVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gfLQzwRA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GaXPyORb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_rZ0xkH77, 0, m, &cIf_rZ0xkH77_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_24alMfi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WOvmoFBm, HV_BINOP_POW, 1, m, &cBinop_WOvmoFBm_sendMessage);
  cMsg_U1292Kmi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_rZ0xkH77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mfRj3wEc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_g5Qrkitb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hefUIUgF, 1, m, &cIf_hefUIUgF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vXRh9DZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DYnbSmOP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ljqmftjd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IqTTtAjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p1uLEIgV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QdAYNcKF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9aVlgmIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZ0xkH77, 1, m, &cIf_rZ0xkH77_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4SgNggvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZcqxQQBn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZcqxQQBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_mfRj3wEc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2tbR0Eyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_IqTTtAjh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ljqmftjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9aVlgmIT, HV_BINOP_GREATER_THAN, 1, m, &cBinop_9aVlgmIT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DYnbSmOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4SgNggvr, HV_BINOP_EQ, 1, m, &cBinop_4SgNggvr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N15fyp0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2tbR0Eyf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Mn3TZALG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RFh6itNZ, 0, m, &cVar_RFh6itNZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Nrfk6CBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9aVlgmIT, HV_BINOP_GREATER_THAN, 0, m, &cBinop_9aVlgmIT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M3YHZJw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4SgNggvr, HV_BINOP_EQ, 0, m, &cBinop_4SgNggvr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_v7Dq9iBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_d7UWEwNS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aVuTKByx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZoQjtjsx, 0, m, &cSlice_ZoQjtjsx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PuTCvAHB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ZoQjtjsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dAXbT7ny_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dAXbT7ny_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_8oEldjf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dAXbT7ny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dAXbT7ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XUty40Ct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PuTCvAHB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ma5Lyrng, 0, m, &cSlice_ma5Lyrng_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Wz2a1MZ8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ma5Lyrng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Jmy0YEwn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Jmy0YEwn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_71grRNZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Jmy0YEwn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Jmy0YEwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_N7YWfdVE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1UCqz6RB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_91jNACVE, 0, m, &cSlice_91jNACVE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_m9EWVIjt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_91jNACVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YH5HvhOL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YH5HvhOL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dacxVYmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YH5HvhOL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_YH5HvhOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZM7Glcmv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_m9EWVIjt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jxKwbiQN, 0, m, &cSlice_jxKwbiQN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_jxKwbiQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6PW7RRNI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6PW7RRNI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7VBZxqeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6PW7RRNI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_6PW7RRNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZNAMyH8A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_H3rzqBZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4rLK7XGJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xUiYcOGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yrG5ktlC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6EsjOf1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iSPeRxCP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jWF7ITM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EN2iN87h, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0Ikoawo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9AAS3iXz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0LotlYFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_n11GmavS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_n11GmavS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EZSsaagq, HV_BINOP_DIVIDE, 1, m, &cBinop_EZSsaagq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gPkCZ8Yc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_DJXXueyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_JOs2qqXy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u9gt3zcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_DJXXueyc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JOs2qqXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EZSsaagq, HV_BINOP_DIVIDE, 0, m, &cBinop_EZSsaagq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gPkCZ8Yc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u9gt3zcj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EZSsaagq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hIgVzjKA, HV_BINOP_MULTIPLY, 1, m, &cBinop_hIgVzjKA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hIgVzjKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mUVoBkf4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NKYJptwu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_kgvRqAng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_U3jLMwPh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_TEw92lNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wPH9tVVx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vrYliiEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_H6M5Wk38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_H6M5Wk38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hIgVzjKA, HV_BINOP_MULTIPLY, 0, m, &cBinop_hIgVzjKA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PAzKxBAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_PkE8NQg8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PkE8NQg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_80WkUEKJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0hzVyRZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gY5Nb62J, 1, m, &cVar_gY5Nb62J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_gY5Nb62J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AuSlvKZw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lMKSvc9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A9N2q7fN, HV_BINOP_MULTIPLY, 1, m, &cBinop_A9N2q7fN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sQuoQAyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lMKSvc9e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v5xpAoph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_AoIzgaBV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AoIzgaBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_atVxzqEM, HV_BINOP_MULTIPLY, 1, m, &cBinop_atVxzqEM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xlUvHk4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jO30Q9RI, HV_BINOP_MULTIPLY, 1, m, &cBinop_jO30Q9RI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gUoh5JNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xlUvHk4g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mIzT8dTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_80TTpTtk, HV_BINOP_MULTIPLY, 1, m, &cBinop_80TTpTtk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5bc1LcZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AqTIqPGY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AqTIqPGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1LrljI6T, HV_BINOP_MULTIPLY, 1, m, &cBinop_1LrljI6T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_z8jzKTRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TWKwT66h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_vrYliiEZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gv4FlOca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_sVRbx11d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_PAzKxBAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mUVoBkf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_kgvRqAng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NKYJptwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TEw92lNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_U3jLMwPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cx4ol518_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_wPH9tVVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G75U7li2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_e36cArGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oPHk4544_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_80WkUEKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_I3RwkHjP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I3RwkHjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7tfNDEKO, HV_BINOP_MULTIPLY, 1, m, &cBinop_7tfNDEKO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7tfNDEKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_E2PfRgG7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E2PfRgG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_e36cArGE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AuSlvKZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zwN8kYS1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zwN8kYS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_egD39yUQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RwsJZgwQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HjhX9FIn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rZp438vc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2k84VuxZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_32TrCq01_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A9N2q7fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H3rzqBZZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_atVxzqEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xUiYcOGn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jO30Q9RI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6EsjOf1G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_80TTpTtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jWF7ITM1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1LrljI6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Ikoawo7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_aJY3H0PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z8jzKTRE, 0, m, &cVar_z8jzKTRE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O4KZ6lxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sVRbx11d, 1, m, &cVar_sVRbx11d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rZp438vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jO30Q9RI, HV_BINOP_MULTIPLY, 0, m, &cBinop_jO30Q9RI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_egD39yUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_32TrCq01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A9N2q7fN, HV_BINOP_MULTIPLY, 0, m, &cBinop_A9N2q7fN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HjhX9FIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_80TTpTtk, HV_BINOP_MULTIPLY, 0, m, &cBinop_80TTpTtk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2k84VuxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_atVxzqEM, HV_BINOP_MULTIPLY, 0, m, &cBinop_atVxzqEM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RwsJZgwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1LrljI6T, HV_BINOP_MULTIPLY, 0, m, &cBinop_1LrljI6T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gv4FlOca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gY5Nb62J, 0, m, &cVar_gY5Nb62J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TWKwT66h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sVRbx11d, 0, m, &cVar_sVRbx11d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0fLe6EPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MaXv4SxD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_s96AYv7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VVK0HmYH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ojmvXmWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8sCC2hRv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GSQcQpXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YfE5aBfe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_x1XYyXeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bya6VCdy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_bya6VCdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wf3CDKFq, HV_BINOP_DIVIDE, 1, m, &cBinop_wf3CDKFq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MPu041hv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_eWdlAAwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_l1F1KD7s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b1mArmyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_eWdlAAwC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l1F1KD7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wf3CDKFq, HV_BINOP_DIVIDE, 0, m, &cBinop_wf3CDKFq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MPu041hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b1mArmyA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wf3CDKFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPItuRhs, HV_BINOP_MULTIPLY, 1, m, &cBinop_JPItuRhs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JPItuRhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uA0K6r3H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tTmhD9o5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_hJVGeB5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PR9uW4Ib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_FHuaAEGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MNMpfQXb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0FbBCp5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_u36TZ8Fs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u36TZ8Fs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPItuRhs, HV_BINOP_MULTIPLY, 0, m, &cBinop_JPItuRhs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IrxXCJ4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_p5mGlglQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_p5mGlglQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nuqKp4qG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_M1DvFW3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XyyjpvIg, HV_BINOP_MULTIPLY, 1, m, &cBinop_XyyjpvIg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SFqGaSRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WTKRRGke, 1, m, &cVar_WTKRRGke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0j08Z7lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmBWbC2D, HV_BINOP_MULTIPLY, 1, m, &cBinop_wmBWbC2D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2MIZXb6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YNnkg0Mn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YNnkg0Mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q019Ley0, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q019Ley0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_WTKRRGke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jUOLpIzN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_KceWzcgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5HvZqSgl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_0FbBCp5B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hf683RUD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_XJnCYJzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_IrxXCJ4j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tTmhD9o5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_FHuaAEGf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uA0K6r3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_hJVGeB5O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_PR9uW4Ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZCA7oyPV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_MNMpfQXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Cxdwfc2u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ENx67h3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YfZ8jAty_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nuqKp4qG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pyWlTl0c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pyWlTl0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YkBIKE9D, HV_BINOP_MULTIPLY, 1, m, &cBinop_YkBIKE9D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YkBIKE9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_D6kB0zoU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D6kB0zoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ENx67h3s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jUOLpIzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3MK1KppP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3MK1KppP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sYy8nLMp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GHoo0GKf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rgFUg0vH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kbJvBJQQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_knhBFpXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0fLe6EPG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_XyyjpvIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s96AYv7x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wmBWbC2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ojmvXmWP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Q019Ley0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GSQcQpXD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ESYO0Wtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XJnCYJzK, 1, m, &cVar_XJnCYJzK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7ZaRFoWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KceWzcgz, 0, m, &cVar_KceWzcgz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5HvZqSgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XJnCYJzK, 0, m, &cVar_XJnCYJzK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hf683RUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WTKRRGke, 0, m, &cVar_WTKRRGke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rgFUg0vH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XyyjpvIg, HV_BINOP_MULTIPLY, 0, m, &cBinop_XyyjpvIg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GHoo0GKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmBWbC2D, HV_BINOP_MULTIPLY, 0, m, &cBinop_wmBWbC2D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kbJvBJQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_knhBFpXJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_knhBFpXJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sYy8nLMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q019Ley0, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q019Ley0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qscrMdfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xRiNz62G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4zBBJthM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GZKU3kID, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vKFGSUYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JuLQM7KX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mr5mtsuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KMsCG2LC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f2TqAYUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8DpWbtvh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ba3BE3NW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5ZRZvpfc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_5ZRZvpfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W42Y7S6r, HV_BINOP_DIVIDE, 1, m, &cBinop_W42Y7S6r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v7XuVcU6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_FOxznkl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0DkEoV78_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LYXmltbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FOxznkl7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0DkEoV78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W42Y7S6r, HV_BINOP_DIVIDE, 0, m, &cBinop_W42Y7S6r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v7XuVcU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LYXmltbV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_W42Y7S6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Su4HQRAq, HV_BINOP_MULTIPLY, 1, m, &cBinop_Su4HQRAq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Su4HQRAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DdDahc3h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wxCfdLNQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_xD56i0CV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DpdtRViB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_HINm54eM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_shUMGg5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_43IJH27N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_pkQD2ylG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pkQD2ylG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Su4HQRAq, HV_BINOP_MULTIPLY, 0, m, &cBinop_Su4HQRAq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qDsOvVf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_AAqU86lu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AAqU86lu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MY1UjHtR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_C2IfurYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QUBhqDqW, HV_BINOP_MULTIPLY, 1, m, &cBinop_QUBhqDqW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MZ06ErBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bDIGqk3h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bDIGqk3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_C2IfurYe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oiQ3LUaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eiOQ1ECc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eiOQ1ECc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dHlNdhyF, HV_BINOP_MULTIPLY, 1, m, &cBinop_dHlNdhyF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a441jaZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W45f108V, HV_BINOP_MULTIPLY, 1, m, &cBinop_W45f108V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MUdUZUEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fP2cU9V8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fP2cU9V8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_a441jaZI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hOJmUuaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pL3Nxtj6, 1, m, &cVar_pL3Nxtj6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s1VQnZbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lIjlCzW5, HV_BINOP_MULTIPLY, 1, m, &cBinop_lIjlCzW5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p6x7mJhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VDdJYdam_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VDdJYdam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cR5jodA9, HV_BINOP_MULTIPLY, 1, m, &cBinop_cR5jodA9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_pL3Nxtj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ftVlbGJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_vZhNy5sh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rJ1FLXGQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_43IJH27N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BmgysYrZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_XIdlH0tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qDsOvVf2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wxCfdLNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_HINm54eM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DdDahc3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xD56i0CV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_DpdtRViB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uHtqInYe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_shUMGg5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_89agFZJx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ydE28Aqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XCMqiWRr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MY1UjHtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6hF6z5hF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6hF6z5hF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yOJmY5PD, HV_BINOP_MULTIPLY, 1, m, &cBinop_yOJmY5PD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yOJmY5PD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_umM2QM1g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_umM2QM1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ydE28Aqt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ftVlbGJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rfGPLTdp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rfGPLTdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dGjeFOHh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N1NRLnQD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JNbvvGsR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M90ep1nU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cg19gKCY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ukks6WYs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QUBhqDqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qscrMdfW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dHlNdhyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4zBBJthM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_W45f108V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vKFGSUYM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lIjlCzW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mr5mtsuV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cR5jodA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f2TqAYUz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zGYS1mZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vZhNy5sh, 0, m, &cVar_vZhNy5sh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZM6Usnj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XIdlH0tt, 1, m, &cVar_XIdlH0tt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M90ep1nU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W45f108V, HV_BINOP_MULTIPLY, 0, m, &cBinop_W45f108V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dGjeFOHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_ukks6WYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QUBhqDqW, HV_BINOP_MULTIPLY, 0, m, &cBinop_QUBhqDqW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JNbvvGsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lIjlCzW5, HV_BINOP_MULTIPLY, 0, m, &cBinop_lIjlCzW5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Cg19gKCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dHlNdhyF, HV_BINOP_MULTIPLY, 0, m, &cBinop_dHlNdhyF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N1NRLnQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cR5jodA9, HV_BINOP_MULTIPLY, 0, m, &cBinop_cR5jodA9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BmgysYrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pL3Nxtj6, 0, m, &cVar_pL3Nxtj6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rJ1FLXGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XIdlH0tt, 0, m, &cVar_XIdlH0tt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TxuxvyZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v7Dq9iBK, 1, m, &cIf_v7Dq9iBK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Bcbgjx4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_d7UWEwNS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2u5CdAbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bcbgjx4H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_FRDYTDK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v7Dq9iBK, 0, m, &cIf_v7Dq9iBK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gtmh9p3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PUOFB1vg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_d7UWEwNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DaHgsqsj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mfRj3wEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qQim1IUF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EVJszM3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TxuxvyZJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2u5CdAbm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V4TqOWDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_FRDYTDK5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_GIGVDfP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_imeJJWE2, HV_BINOP_DIVIDE, 0, m, &cBinop_imeJJWE2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_5GsqLGbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BtpL7WIa, HV_BINOP_DIVIDE, 1, m, &cBinop_BtpL7WIa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_imeJJWE2, HV_BINOP_DIVIDE, 1, m, &cBinop_imeJJWE2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_QDqeRvE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_veAIlZtW, HV_BINOP_DIVIDE, 0, m, &cBinop_veAIlZtW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_fGhemrsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_veAIlZtW, HV_BINOP_DIVIDE, 1, m, &cBinop_veAIlZtW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JmNTLLip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GIGVDfP1, 0, m, &cVar_GIGVDfP1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2QbDVDGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5GsqLGbw, 0, m, &cVar_5GsqLGbw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OsOZyj77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BtpL7WIa, HV_BINOP_DIVIDE, 0, m, &cBinop_BtpL7WIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BtpL7WIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_QDqeRvE7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_imeJJWE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_fGhemrsC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_veAIlZtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_DsOfiHL7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_zbU2lxZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_G0ibmdps_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y2kzOYTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_w8qq112T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DsOfiHL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_y2kzOYTv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w8qq112T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_zbU2lxZX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G0ibmdps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xaqN94cF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DGkfuqjU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3hX6lDQo, 0, m, &cSlice_3hX6lDQo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3hX6lDQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gzzugrS0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gzzugrS0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_DQ77anMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gzzugrS0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gzzugrS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RQX1mdKP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_qAGUiZ17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_kPptPbuQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kPptPbuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_7HVtgbxJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7HVtgbxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_KR8lXXDb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KR8lXXDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E01bVfCa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kkKSFnN2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E01bVfCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jjeikI7h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kkKSFnN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kRgGZKQx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jjeikI7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JrwRGLut_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kRgGZKQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hjozJPc1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hjozJPc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Px3Uz3Mh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JrwRGLut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t8FwRM1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Px3Uz3Mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yEViiG0n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_t8FwRM1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bPnlXqcp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yEViiG0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CyXvA8Mx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_A6VIXy7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FnIZBq15_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CuD9QXU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RiDOam5F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EG6c0oLn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WpgskyqZ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u50f4T2u_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_refijmID_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AoBlPoDL_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MKPYjEN8_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f04j33KF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_WpgskyqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RV8Ko1DG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_u50f4T2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_59mocaXL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_refijmID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BJgHBCMi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_AoBlPoDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GGUhdIn7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_MKPYjEN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kGfodpHc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_f04j33KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7jjdvYIZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_tIqJSt9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_raQfXTtK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Sv0uxjuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2IAQ2oSr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_30wgvDbW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yWomjLeV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yWomjLeV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TS9ooPIE, 1, m, &cDelay_TS9ooPIE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i4E5akxM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TS9ooPIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TS9ooPIE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tIqJSt9T, 0, m, &cIf_tIqJSt9T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yWomjLeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TS9ooPIE, 0, m, &cDelay_TS9ooPIE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i4E5akxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TS9ooPIE, 0, m, &cDelay_TS9ooPIE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cLvi04YS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EKelhZ0T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LYSpsZMr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kIKpDHY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_60UftG0l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7pyhGnz6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_60UftG0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tIqJSt9T, 1, m, &cIf_tIqJSt9T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7pyhGnz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_30wgvDbW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EKelhZ0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sv0uxjuH, 1, m, &cIf_Sv0uxjuH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LYSpsZMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sv0uxjuH, 0, m, &cIf_Sv0uxjuH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2IAQ2oSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vNE3QZJH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_raQfXTtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vNE3QZJH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_MhrrSbPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tnRmXLhS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_d7iryq56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NLQYHdIF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TLj4hcis_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DoAlNKm6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DoAlNKm6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XzcIUM43, 1, m, &cDelay_XzcIUM43_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kst1YDS0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XzcIUM43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XzcIUM43, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MhrrSbPz, 0, m, &cIf_MhrrSbPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DoAlNKm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XzcIUM43, 0, m, &cDelay_XzcIUM43_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kst1YDS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XzcIUM43, 0, m, &cDelay_XzcIUM43_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rz5kwB9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vN7gQhXv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jMBqd9QP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QcBgj7NZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5jxzw2kH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eU6Lwthy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eU6Lwthy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TLj4hcis_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5jxzw2kH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MhrrSbPz, 1, m, &cIf_MhrrSbPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vN7gQhXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d7iryq56, 1, m, &cIf_d7iryq56_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jMBqd9QP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d7iryq56, 0, m, &cIf_d7iryq56_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NLQYHdIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aMON9LG3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tnRmXLhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aMON9LG3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VUGY4OTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ufNZOfvy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0pzOMtj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_T12gPbAZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XFYe1qbH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_k6rZsyMo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_k6rZsyMo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AxsUPu3R, 1, m, &cDelay_AxsUPu3R_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AOU7tsWR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AxsUPu3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AxsUPu3R, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VUGY4OTZ, 0, m, &cIf_VUGY4OTZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k6rZsyMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AxsUPu3R, 0, m, &cDelay_AxsUPu3R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AOU7tsWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AxsUPu3R, 0, m, &cDelay_AxsUPu3R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kDj4aslP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E3IwEPq5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Iiu7LDmT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QhESHFYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2LuyqD6A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bsnr6hYo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bsnr6hYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XFYe1qbH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2LuyqD6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VUGY4OTZ, 1, m, &cIf_VUGY4OTZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E3IwEPq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0pzOMtj9, 1, m, &cIf_0pzOMtj9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Iiu7LDmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0pzOMtj9, 0, m, &cIf_0pzOMtj9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T12gPbAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fs1AWxeO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ufNZOfvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fs1AWxeO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mu5wz8Yh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EGFhFTUi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Jyd8ccvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gb8RogQC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ydZhdhDT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_x72eYU7p_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_x72eYU7p_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4k9zupd5, 1, m, &cDelay_4k9zupd5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wSxaUYs2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4k9zupd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4k9zupd5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mu5wz8Yh, 0, m, &cIf_mu5wz8Yh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x72eYU7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4k9zupd5, 0, m, &cDelay_4k9zupd5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wSxaUYs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4k9zupd5, 0, m, &cDelay_4k9zupd5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nWwXu0Qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xL8xvlrh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MpHwt42D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PDvf4Uxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r7m6OJl3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xpYZERVC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xpYZERVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ydZhdhDT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_r7m6OJl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mu5wz8Yh, 1, m, &cIf_mu5wz8Yh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MpHwt42D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jyd8ccvY, 0, m, &cIf_Jyd8ccvY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xL8xvlrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jyd8ccvY, 1, m, &cIf_Jyd8ccvY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gb8RogQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_256qT47G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EGFhFTUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_256qT47G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_AFPyn1mT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HK35S4v1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DvNW5DWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6qWZ1s5V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_C3jajU2M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_02zjrSfT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_02zjrSfT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TMM9K1Ox, 1, m, &cDelay_TMM9K1Ox_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6l1yehuy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TMM9K1Ox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TMM9K1Ox, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AFPyn1mT, 0, m, &cIf_AFPyn1mT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_02zjrSfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TMM9K1Ox, 0, m, &cDelay_TMM9K1Ox_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6l1yehuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TMM9K1Ox, 0, m, &cDelay_TMM9K1Ox_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CGkgfhIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x1e2zlXd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hXHk4iye_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BNWAA7Ab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ijy7bAFr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xSBgtnsM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ijy7bAFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AFPyn1mT, 1, m, &cIf_AFPyn1mT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xSBgtnsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_C3jajU2M_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hXHk4iye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DvNW5DWA, 0, m, &cIf_DvNW5DWA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x1e2zlXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DvNW5DWA, 1, m, &cIf_DvNW5DWA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6qWZ1s5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YnoSVIam, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HK35S4v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YnoSVIam, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZkvcIxti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FjPnjwfE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dz0fCKYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aoxA8G4M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WBmN81aw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0tQXNZnX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0tQXNZnX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HM7aEVvG, 1, m, &cDelay_HM7aEVvG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VxBkW520_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HM7aEVvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HM7aEVvG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZkvcIxti, 0, m, &cIf_ZkvcIxti_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0tQXNZnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HM7aEVvG, 0, m, &cDelay_HM7aEVvG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VxBkW520_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HM7aEVvG, 0, m, &cDelay_HM7aEVvG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AaugMoG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NPdlwrtp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HrNGSRD8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1ICjhWEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6U45VJ5e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ue0Wh3yf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6U45VJ5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZkvcIxti, 1, m, &cIf_ZkvcIxti_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ue0Wh3yf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WBmN81aw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NPdlwrtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dz0fCKYw, 1, m, &cIf_dz0fCKYw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HrNGSRD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dz0fCKYw, 0, m, &cIf_dz0fCKYw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aoxA8G4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XmaoFNtT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FjPnjwfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XmaoFNtT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KlmGbYtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8i8QAGB4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qQgICDt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_58hSioh1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kGEcHh90_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Li1J1Dp9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Li1J1Dp9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JlcdpAGL, 1, m, &cDelay_JlcdpAGL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3tLQijEY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JlcdpAGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JlcdpAGL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KlmGbYtn, 0, m, &cIf_KlmGbYtn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Li1J1Dp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JlcdpAGL, 0, m, &cDelay_JlcdpAGL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3tLQijEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JlcdpAGL, 0, m, &cDelay_JlcdpAGL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EDl8F5MS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0IKbMgKC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wme0Ze8m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YjBCPPKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wLylI6DF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IxERlcjj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wLylI6DF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KlmGbYtn, 1, m, &cIf_KlmGbYtn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IxERlcjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kGEcHh90_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0IKbMgKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qQgICDt7, 1, m, &cIf_qQgICDt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wme0Ze8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qQgICDt7, 0, m, &cIf_qQgICDt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_58hSioh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2inoeW26, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8i8QAGB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2inoeW26, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_o07Aguon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Uw6oMU7s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bILyxhkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VTFFFttA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e0kP54C0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_iVZT0nai_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_iVZT0nai_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_T18qyOTi, 1, m, &cDelay_T18qyOTi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A2rLyJ7y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_T18qyOTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_T18qyOTi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_o07Aguon, 0, m, &cIf_o07Aguon_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iVZT0nai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_T18qyOTi, 0, m, &cDelay_T18qyOTi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A2rLyJ7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_T18qyOTi, 0, m, &cDelay_T18qyOTi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nG7BaNwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WX9z0Khl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xOvLfr8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mtAY8G4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mxeFjAjV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mSlJvvBp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mSlJvvBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_e0kP54C0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mxeFjAjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o07Aguon, 1, m, &cIf_o07Aguon_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WX9z0Khl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bILyxhkI, 1, m, &cIf_bILyxhkI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xOvLfr8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bILyxhkI, 0, m, &cIf_bILyxhkI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VTFFFttA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DUKoiewp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Uw6oMU7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DUKoiewp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PAscQM39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VJCqanlL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pde2iNBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_T877cl6N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_21ap39FA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qWmgyx4T_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qWmgyx4T_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zIz7pL0O, 1, m, &cDelay_zIz7pL0O_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9TWL1Gkz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zIz7pL0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zIz7pL0O, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PAscQM39, 0, m, &cIf_PAscQM39_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qWmgyx4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zIz7pL0O, 0, m, &cDelay_zIz7pL0O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9TWL1Gkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zIz7pL0O, 0, m, &cDelay_zIz7pL0O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a2A4Q18u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zhB8vebw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QuUtsZiG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KRZQHuTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8vXndBw2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SnOoHRYD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SnOoHRYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_21ap39FA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8vXndBw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PAscQM39, 1, m, &cIf_PAscQM39_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QuUtsZiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pde2iNBO, 0, m, &cIf_pde2iNBO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zhB8vebw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pde2iNBO, 1, m, &cIf_pde2iNBO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T877cl6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QzjP7cQW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VJCqanlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QzjP7cQW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lDR5cxpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_F6UMniw4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HNjhEgFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_klvqRqgv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yZgYEWBr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9vPB8FEr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9vPB8FEr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XYGbGd5j, 1, m, &cDelay_XYGbGd5j_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WxlF7xb7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XYGbGd5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XYGbGd5j, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lDR5cxpr, 0, m, &cIf_lDR5cxpr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9vPB8FEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XYGbGd5j, 0, m, &cDelay_XYGbGd5j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WxlF7xb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XYGbGd5j, 0, m, &cDelay_XYGbGd5j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vBdIcn37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wGjtKtQ9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bJbrLNHC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LSWrPfLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CZuLXzRA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DrGk1qgG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DrGk1qgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yZgYEWBr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CZuLXzRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lDR5cxpr, 1, m, &cIf_lDR5cxpr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bJbrLNHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HNjhEgFe, 0, m, &cIf_HNjhEgFe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wGjtKtQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HNjhEgFe, 1, m, &cIf_HNjhEgFe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_klvqRqgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6vfEETPE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_F6UMniw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6vfEETPE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Z8RrOj3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AYUzahYJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tnQdZ7Af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b8yyx7kJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_J3WMwmAZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_q0QpBfyN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_q0QpBfyN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tS55ZF91, 1, m, &cDelay_tS55ZF91_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yKRLQRaB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tS55ZF91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tS55ZF91, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Z8RrOj3s, 0, m, &cIf_Z8RrOj3s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_q0QpBfyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tS55ZF91, 0, m, &cDelay_tS55ZF91_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yKRLQRaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tS55ZF91, 0, m, &cDelay_tS55ZF91_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eHdaDVet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1FaHFGyQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sZRdHpTY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cuSHt2wY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WXE0V7hu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t91uxbdc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WXE0V7hu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z8RrOj3s, 1, m, &cIf_Z8RrOj3s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t91uxbdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_J3WMwmAZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1FaHFGyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tnQdZ7Af, 1, m, &cIf_tnQdZ7Af_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sZRdHpTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tnQdZ7Af, 0, m, &cIf_tnQdZ7Af_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b8yyx7kJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rw4mulnn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AYUzahYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rw4mulnn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_wKg9gpRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zeqorQCC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rDl7wccj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qG2YZLkS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_j6hSDMkP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lYufEiFL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lYufEiFL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nW28Qft7, 1, m, &cDelay_nW28Qft7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u2jIOvx1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nW28Qft7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nW28Qft7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wKg9gpRJ, 0, m, &cIf_wKg9gpRJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lYufEiFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nW28Qft7, 0, m, &cDelay_nW28Qft7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u2jIOvx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nW28Qft7, 0, m, &cDelay_nW28Qft7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PmNFi0NV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B0xlbmcH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tUSD6Fow_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WWp8IuKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ti9rMBQU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ozz4BunZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ozz4BunZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_j6hSDMkP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Ti9rMBQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wKg9gpRJ, 1, m, &cIf_wKg9gpRJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B0xlbmcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rDl7wccj, 1, m, &cIf_rDl7wccj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tUSD6Fow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rDl7wccj, 0, m, &cIf_rDl7wccj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qG2YZLkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GfXR4hIf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zeqorQCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GfXR4hIf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RV8Ko1DG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_FxHEfNHS_sendMessage(_c, 0, m);
  cMsg_mkgteDvP_sendMessage(_c, 0, m);
  cMsg_8SsJ2bm3_sendMessage(_c, 0, m);
  cMsg_Valeafe8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_59mocaXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_FxHEfNHS_sendMessage(_c, 0, m);
  cMsg_drjGDsTd_sendMessage(_c, 0, m);
  cMsg_9JXrwQ7e_sendMessage(_c, 0, m);
  cMsg_UMvx4lyD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BJgHBCMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_7IX8ZCZX_sendMessage(_c, 0, m);
  cMsg_drjGDsTd_sendMessage(_c, 0, m);
  cMsg_Valeafe8_sendMessage(_c, 0, m);
  cMsg_VvfamUqM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GGUhdIn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_7IX8ZCZX_sendMessage(_c, 0, m);
  cMsg_TVKqrW7I_sendMessage(_c, 0, m);
  cMsg_8SsJ2bm3_sendMessage(_c, 0, m);
  cMsg_CRV1hAr4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kGfodpHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_CHapzLOa_sendMessage(_c, 0, m);
  cMsg_UMvx4lyD_sendMessage(_c, 0, m);
  cMsg_pHsps8Mx_sendMessage(_c, 0, m);
  cMsg_8SsJ2bm3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7jjdvYIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_CHapzLOa_sendMessage(_c, 0, m);
  cMsg_CRV1hAr4_sendMessage(_c, 0, m);
  cMsg_drjGDsTd_sendMessage(_c, 0, m);
  cMsg_4stBZsOe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xyYFyQIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kIKpDHY7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cLvi04YS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bXbe1BbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kIKpDHY7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cLvi04YS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_914K2OOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QcBgj7NZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rz5kwB9r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xkG4c9Y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QcBgj7NZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rz5kwB9r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_D6NPnP0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QhESHFYs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kDj4aslP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OUK4DN5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QhESHFYs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kDj4aslP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FxHEfNHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_xyYFyQIf_sendMessage(_c, 0, m);
  cMsg_xkG4c9Y6_sendMessage(_c, 0, m);
  cMsg_OUK4DN5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7IX8ZCZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_bXbe1BbI_sendMessage(_c, 0, m);
  cMsg_914K2OOW_sendMessage(_c, 0, m);
  cMsg_OUK4DN5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CHapzLOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_bXbe1BbI_sendMessage(_c, 0, m);
  cMsg_xkG4c9Y6_sendMessage(_c, 0, m);
  cMsg_D6NPnP0I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FM0jfJk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PDvf4Uxc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nWwXu0Qb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kXU3b2X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PDvf4Uxc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nWwXu0Qb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nofE6EOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BNWAA7Ab_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CGkgfhIo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QkErQTNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BNWAA7Ab_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CGkgfhIo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7CBE1xCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1ICjhWEw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AaugMoG9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XFtwXkMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1ICjhWEw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AaugMoG9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_drjGDsTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_kXU3b2X2_sendMessage(_c, 0, m);
  cMsg_QkErQTNP_sendMessage(_c, 0, m);
  cMsg_XFtwXkMK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mkgteDvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_kXU3b2X2_sendMessage(_c, 0, m);
  cMsg_nofE6EOe_sendMessage(_c, 0, m);
  cMsg_7CBE1xCw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TVKqrW7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_FM0jfJk7_sendMessage(_c, 0, m);
  cMsg_QkErQTNP_sendMessage(_c, 0, m);
  cMsg_7CBE1xCw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Vq6t4OAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LSWrPfLK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vBdIcn37_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ErOB6t9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LSWrPfLK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vBdIcn37_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rGG039WC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cuSHt2wY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eHdaDVet_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dvhd63Jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cuSHt2wY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eHdaDVet_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9DxJBMcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WWp8IuKt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PmNFi0NV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zBobrczg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WWp8IuKt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PmNFi0NV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CRV1hAr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Vq6t4OAf_sendMessage(_c, 0, m);
  cMsg_dvhd63Jp_sendMessage(_c, 0, m);
  cMsg_zBobrczg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UMvx4lyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_ErOB6t9L_sendMessage(_c, 0, m);
  cMsg_rGG039WC_sendMessage(_c, 0, m);
  cMsg_zBobrczg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Valeafe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_ErOB6t9L_sendMessage(_c, 0, m);
  cMsg_dvhd63Jp_sendMessage(_c, 0, m);
  cMsg_9DxJBMcB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yXhuw4VM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YjBCPPKn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EDl8F5MS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LR44Nt1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YjBCPPKn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EDl8F5MS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MBTm1Hrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mtAY8G4C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nG7BaNwO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AlmBqe6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mtAY8G4C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nG7BaNwO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RBucnQXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KRZQHuTs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a2A4Q18u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qwGUGF06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KRZQHuTs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a2A4Q18u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8SsJ2bm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_LR44Nt1U_sendMessage(_c, 0, m);
  cMsg_AlmBqe6n_sendMessage(_c, 0, m);
  cMsg_qwGUGF06_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9JXrwQ7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_LR44Nt1U_sendMessage(_c, 0, m);
  cMsg_MBTm1Hrf_sendMessage(_c, 0, m);
  cMsg_RBucnQXK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4stBZsOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_yXhuw4VM_sendMessage(_c, 0, m);
  cMsg_MBTm1Hrf_sendMessage(_c, 0, m);
  cMsg_qwGUGF06_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pHsps8Mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_FM0jfJk7_sendMessage(_c, 0, m);
  cMsg_nofE6EOe_sendMessage(_c, 0, m);
  cMsg_XFtwXkMK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VvfamUqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_yXhuw4VM_sendMessage(_c, 0, m);
  cMsg_AlmBqe6n_sendMessage(_c, 0, m);
  cMsg_RBucnQXK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_HgS0IXPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QGvf6DPh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KWNtta5l_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bmxRCto5, 0, m, &cSlice_bmxRCto5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NqLJWzCU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bmxRCto5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Tl31XTvX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Tl31XTvX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_rYQRyUgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Tl31XTvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Tl31XTvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zXWuQM0l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7XSA9LOk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0c8eu0Go, 0, m, &cSlice_0c8eu0Go_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xWnEkiXY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0c8eu0Go_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_toSG3ePx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_toSG3ePx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_KlwjFCSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_toSG3ePx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_toSG3ePx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gnIwIrdI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xWnEkiXY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ulzU1Vd8, 0, m, &cSlice_ulzU1Vd8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KWNtta5l_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ulzU1Vd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BryEgVjz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BryEgVjz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_QSyVexH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BryEgVjz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BryEgVjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4aMGj1we_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NqLJWzCU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xBotLxRE, 0, m, &cSlice_xBotLxRE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Z91qhUer_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xBotLxRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mZyT5fzV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mZyT5fzV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_5s9mhcvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mZyT5fzV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mZyT5fzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WC4tU9wX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Z91qhUer_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5H1FAG7H, 0, m, &cSlice_5H1FAG7H_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NqLIhv0h_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5H1FAG7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LesS5yMu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LesS5yMu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_yEkP6gUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LesS5yMu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LesS5yMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UWVEI7Us_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zgumQ3Rt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Xk5LUTJo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Xk5LUTJo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yDV9W4Xl, 1, m, &cDelay_yDV9W4Xl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rzrO8PNf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yDV9W4Xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yDV9W4Xl, m);
  cMsg_86CTWAyP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Xk5LUTJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yDV9W4Xl, 0, m, &cDelay_yDV9W4Xl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rzrO8PNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yDV9W4Xl, 0, m, &cDelay_yDV9W4Xl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_qCox37tI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Tbst3OC, HV_BINOP_SUBTRACT, 0, m, &cBinop_2Tbst3OC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_T2IcEhkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_u9Xwcc5G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gHI23hND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_u9Xwcc5G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_fgWNHB81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qCox37tI, 0, m, &cVar_qCox37tI_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_WsuIkwS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DX3fb4Nr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4bYrWlI7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SxX7FroA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2Tbst3OC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z3Fz3iNL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_z3Fz3iNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5HSF7zhX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5HSF7zhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_UNyWr029_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M4R6tL0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hoGASnwY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v565sOGn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v565sOGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xIMyd6gQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_hoGASnwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2IcEhkF, 1, m, &cIf_T2IcEhkF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ae4jK4tx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gHI23hND, 1, m, &cIf_gHI23hND_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xIMyd6gQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_T2IcEhkF, 0, m, &cIf_T2IcEhkF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UNyWr029_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gHI23hND, 0, m, &cIf_gHI23hND_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4bYrWlI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Tbst3OC, HV_BINOP_SUBTRACT, 1, m, &cBinop_2Tbst3OC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DX3fb4Nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_SxX7FroA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qCox37tI, 0, m, &cVar_qCox37tI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u9Xwcc5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9s2tQg2Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NqLIhv0h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hc6xjqUT, 0, m, &cSlice_hc6xjqUT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_hc6xjqUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zOGxtBOs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zOGxtBOs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_WsgnR5XF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zOGxtBOs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zOGxtBOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_azWfKNU6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FnIZBq15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uS3zURof, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RiDOam5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tjLwAOIw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_5xOTMCdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CuD9QXU5, 0, m, &cVar_CuD9QXU5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QGvf6DPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hsx0uE8X, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vvZn1nP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zgumQ3Rt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JHwohLHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1oUDoxI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_86CTWAyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VxhE2ooY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1oUDoxI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VxhE2ooY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_r1xjRUnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_3wi66Yvd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3wi66Yvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MFldGaSw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MFldGaSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X5u1aQvI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_KPkA8TaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kZeLfPtI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ZTlWhS6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YMm8L6L9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Of184JUx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9YQq54fl_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YxpyIG0V_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y9uu7GLC_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8wmQCFng_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rcIQMBVA_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvDb4kIh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_9YQq54fl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k7nFSBBn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_YxpyIG0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aFoTRU6Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_y9uu7GLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RtsewW8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8wmQCFng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_prC4UuPl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rcIQMBVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6aPGAFG8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_hvDb4kIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PkHjnvdA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_KpnXZQgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TpdC0JkW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8qJXD1FN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Rb23finp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Xc1hrXHN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_b3f1Dmzw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_b3f1Dmzw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ToAfZIBC, 1, m, &cDelay_ToAfZIBC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9d68Uz1V_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ToAfZIBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ToAfZIBC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KpnXZQgN, 0, m, &cIf_KpnXZQgN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b3f1Dmzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ToAfZIBC, 0, m, &cDelay_ToAfZIBC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9d68Uz1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ToAfZIBC, 0, m, &cDelay_ToAfZIBC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zztSZQVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0CdePiiD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lNXYNuBN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u3pLed3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ntlhstmx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7fPr9VGf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7fPr9VGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Xc1hrXHN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ntlhstmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KpnXZQgN, 1, m, &cIf_KpnXZQgN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lNXYNuBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8qJXD1FN, 0, m, &cIf_8qJXD1FN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0CdePiiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8qJXD1FN, 1, m, &cIf_8qJXD1FN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Rb23finp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vtsE8tsm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TpdC0JkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vtsE8tsm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ItA0XDr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g6VGq08k_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_480cdCtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iOY2ABsa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IIyOBTuP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_P2YEcnlp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_P2YEcnlp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9jadWsK8, 1, m, &cDelay_9jadWsK8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u2L30yYc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9jadWsK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9jadWsK8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ItA0XDr8, 0, m, &cIf_ItA0XDr8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P2YEcnlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9jadWsK8, 0, m, &cDelay_9jadWsK8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u2L30yYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9jadWsK8, 0, m, &cDelay_9jadWsK8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tNFU1Xa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RfWr1ABf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3tnPuiey_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j0g7encW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jl7tFEww_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DemuxLuj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DemuxLuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IIyOBTuP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jl7tFEww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ItA0XDr8, 1, m, &cIf_ItA0XDr8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RfWr1ABf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_480cdCtx, 1, m, &cIf_480cdCtx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3tnPuiey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_480cdCtx, 0, m, &cIf_480cdCtx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iOY2ABsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_As54ef65, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g6VGq08k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_As54ef65, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7X5zGXOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_q9qjq0TT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fajfSFLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FyHfaeu0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bHUfonHs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Q5l2nn00_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Q5l2nn00_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_a2kIf8mA, 1, m, &cDelay_a2kIf8mA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vparj1ag_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_a2kIf8mA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a2kIf8mA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7X5zGXOS, 0, m, &cIf_7X5zGXOS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Q5l2nn00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_a2kIf8mA, 0, m, &cDelay_a2kIf8mA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Vparj1ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_a2kIf8mA, 0, m, &cDelay_a2kIf8mA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bqKEMpmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3k0mexop_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TxgP5UJN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vqqNZCsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZoCJw6z5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4dNetNKf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4dNetNKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bHUfonHs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZoCJw6z5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7X5zGXOS, 1, m, &cIf_7X5zGXOS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TxgP5UJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fajfSFLH, 0, m, &cIf_fajfSFLH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3k0mexop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fajfSFLH, 1, m, &cIf_fajfSFLH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FyHfaeu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3wrWAOTG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_q9qjq0TT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3wrWAOTG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7nKs1MGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gBHUoBKp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NUwkvgll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fIQxxBTx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AEImCbiU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VBD94eMj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VBD94eMj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FSJmH487, 1, m, &cDelay_FSJmH487_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CRBNLFHx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FSJmH487_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FSJmH487, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7nKs1MGN, 0, m, &cIf_7nKs1MGN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VBD94eMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FSJmH487, 0, m, &cDelay_FSJmH487_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CRBNLFHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FSJmH487, 0, m, &cDelay_FSJmH487_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9i11I0U4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jV2pEQba_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRqTJADF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ubH1YVdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AlwxqTkp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IQzhjwCS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IQzhjwCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AEImCbiU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AlwxqTkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7nKs1MGN, 1, m, &cIf_7nKs1MGN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fRqTJADF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NUwkvgll, 0, m, &cIf_NUwkvgll_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jV2pEQba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NUwkvgll, 1, m, &cIf_NUwkvgll_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fIQxxBTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CUI8eRb4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gBHUoBKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CUI8eRb4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8RMxhZMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5e2JBWkD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UMLjnP9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tdSvQ0f3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gKqWIMQL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_B39f8oFW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_B39f8oFW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wiOADaGl, 1, m, &cDelay_wiOADaGl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r0piGjB5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wiOADaGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wiOADaGl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8RMxhZMh, 0, m, &cIf_8RMxhZMh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_B39f8oFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wiOADaGl, 0, m, &cDelay_wiOADaGl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r0piGjB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wiOADaGl, 0, m, &cDelay_wiOADaGl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ar3HtwAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lJKk0vZA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AZXVMGLG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T4j3OzR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y2OhQeb0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eEVLLMuQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eEVLLMuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gKqWIMQL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Y2OhQeb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8RMxhZMh, 1, m, &cIf_8RMxhZMh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AZXVMGLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UMLjnP9B, 0, m, &cIf_UMLjnP9B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lJKk0vZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UMLjnP9B, 1, m, &cIf_UMLjnP9B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tdSvQ0f3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XuX0rN2r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5e2JBWkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XuX0rN2r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2fCYmsBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s5ll62bZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1apFu4TD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XlG4eTCE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LmKo781g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tE3jtA1v_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tE3jtA1v_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_m747xTDa, 1, m, &cDelay_m747xTDa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q5qGoXlB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_m747xTDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_m747xTDa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2fCYmsBX, 0, m, &cIf_2fCYmsBX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tE3jtA1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_m747xTDa, 0, m, &cDelay_m747xTDa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q5qGoXlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_m747xTDa, 0, m, &cDelay_m747xTDa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bJ1vLfHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YvsWw8El_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_chSvGxbn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UhNZRG0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lb5N8Lo1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OpbgIVdE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OpbgIVdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LmKo781g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Lb5N8Lo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2fCYmsBX, 1, m, &cIf_2fCYmsBX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_chSvGxbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1apFu4TD, 0, m, &cIf_1apFu4TD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YvsWw8El_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1apFu4TD, 1, m, &cIf_1apFu4TD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XlG4eTCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SKi6hEJ1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_s5ll62bZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SKi6hEJ1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZK34fOPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_khwIptlp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ficsVDaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xgh8Sjcz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rff5Swvz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nSX15mBH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nSX15mBH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4P4guGWo, 1, m, &cDelay_4P4guGWo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h2CW4LlW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4P4guGWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4P4guGWo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZK34fOPd, 0, m, &cIf_ZK34fOPd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nSX15mBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4P4guGWo, 0, m, &cDelay_4P4guGWo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h2CW4LlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4P4guGWo, 0, m, &cDelay_4P4guGWo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5yHKoBQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7BTbtbi7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xysj6lTL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GLkxoAhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WUOwetfv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jlEXMyfm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WUOwetfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZK34fOPd, 1, m, &cIf_ZK34fOPd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jlEXMyfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rff5Swvz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xysj6lTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ficsVDaz, 0, m, &cIf_ficsVDaz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7BTbtbi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ficsVDaz, 1, m, &cIf_ficsVDaz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xgh8Sjcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fOusu7GI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_khwIptlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fOusu7GI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_TaOempUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qP3bDmJl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FuiLB84a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9UIunqaJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HWHTOwti_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aLJnBpJZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aLJnBpJZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_isFAMPFI, 1, m, &cDelay_isFAMPFI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2zZts3lI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_isFAMPFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_isFAMPFI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TaOempUB, 0, m, &cIf_TaOempUB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aLJnBpJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_isFAMPFI, 0, m, &cDelay_isFAMPFI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2zZts3lI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_isFAMPFI, 0, m, &cDelay_isFAMPFI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wzLiCdnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pWMnHtdc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vIvVNDUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kvqWznCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mX17PVUo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NJOCPnIl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mX17PVUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TaOempUB, 1, m, &cIf_TaOempUB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NJOCPnIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HWHTOwti_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pWMnHtdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FuiLB84a, 1, m, &cIf_FuiLB84a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vIvVNDUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FuiLB84a, 0, m, &cIf_FuiLB84a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9UIunqaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2A6QYP2C, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qP3bDmJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2A6QYP2C, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_FIpUokJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XkMBpcGE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_S1ixs9j7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gNEhsULG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_a35YBxZG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gk0f4sgL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gk0f4sgL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BxgcxVwp, 1, m, &cDelay_BxgcxVwp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pmv7s6AM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BxgcxVwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BxgcxVwp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FIpUokJi, 0, m, &cIf_FIpUokJi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gk0f4sgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BxgcxVwp, 0, m, &cDelay_BxgcxVwp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pmv7s6AM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BxgcxVwp, 0, m, &cDelay_BxgcxVwp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UXug0MJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RxtyAlIp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BwFJrjqB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aXzeDnuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6yihiZY8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Elj5N2nx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6yihiZY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FIpUokJi, 1, m, &cIf_FIpUokJi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Elj5N2nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_a35YBxZG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RxtyAlIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S1ixs9j7, 1, m, &cIf_S1ixs9j7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BwFJrjqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S1ixs9j7, 0, m, &cIf_S1ixs9j7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gNEhsULG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vXqssMoo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XkMBpcGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vXqssMoo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_njPnhC9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RT9mSqjr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZCIyLLua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gobO3GHj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_u1BoM46b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qYFBlGHG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qYFBlGHG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xTRJKsd9, 1, m, &cDelay_xTRJKsd9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZZZvxMPg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xTRJKsd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xTRJKsd9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_njPnhC9m, 0, m, &cIf_njPnhC9m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qYFBlGHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xTRJKsd9, 0, m, &cDelay_xTRJKsd9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZZZvxMPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xTRJKsd9, 0, m, &cDelay_xTRJKsd9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tHeGlKKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sn1exBiL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JEtdCW7h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rxHzKStj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ponOmUv3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KxvQejuz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KxvQejuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_u1BoM46b_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ponOmUv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_njPnhC9m, 1, m, &cIf_njPnhC9m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JEtdCW7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZCIyLLua, 0, m, &cIf_ZCIyLLua_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sn1exBiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZCIyLLua, 1, m, &cIf_ZCIyLLua_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gobO3GHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gto6S6hS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RT9mSqjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gto6S6hS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_C9gb2LmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SRbvaZtV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sPORQSm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pRRPZQmq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WuSpeBix_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WuQFBCHQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WuQFBCHQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SlA0G9Bk, 1, m, &cDelay_SlA0G9Bk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hEoG7Hds_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SlA0G9Bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SlA0G9Bk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_C9gb2LmT, 0, m, &cIf_C9gb2LmT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WuQFBCHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SlA0G9Bk, 0, m, &cDelay_SlA0G9Bk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hEoG7Hds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SlA0G9Bk, 0, m, &cDelay_SlA0G9Bk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RPeOBHlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HHKcokQz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M7TECfz7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_p6QUo1m3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dfU2ZCVT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BusRGPCS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dfU2ZCVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_C9gb2LmT, 1, m, &cIf_C9gb2LmT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BusRGPCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WuSpeBix_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_M7TECfz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sPORQSm7, 0, m, &cIf_sPORQSm7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HHKcokQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sPORQSm7, 1, m, &cIf_sPORQSm7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pRRPZQmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k7RB61gw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SRbvaZtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k7RB61gw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Dn6dPVNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JPRN5p9v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Hy155ZPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jFAbilUk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BVOdhMtr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MmiLXZrm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MmiLXZrm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cfGoJXHw, 1, m, &cDelay_cfGoJXHw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QkXD90bf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cfGoJXHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cfGoJXHw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Dn6dPVNd, 0, m, &cIf_Dn6dPVNd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MmiLXZrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cfGoJXHw, 0, m, &cDelay_cfGoJXHw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QkXD90bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cfGoJXHw, 0, m, &cDelay_cfGoJXHw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PCA1DkKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FmFoxwEk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AADUqbb2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HDwC8wn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lyqzxPB9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rhSDiJQg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lyqzxPB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Dn6dPVNd, 1, m, &cIf_Dn6dPVNd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rhSDiJQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BVOdhMtr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FmFoxwEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hy155ZPb, 1, m, &cIf_Hy155ZPb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AADUqbb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hy155ZPb, 0, m, &cIf_Hy155ZPb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jFAbilUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BnNO98XY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JPRN5p9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BnNO98XY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_k7nFSBBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_0s11TUeI_sendMessage(_c, 0, m);
  cMsg_ukriBeQ7_sendMessage(_c, 0, m);
  cMsg_ln296jYt_sendMessage(_c, 0, m);
  cMsg_9dHxSnKL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aFoTRU6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_0s11TUeI_sendMessage(_c, 0, m);
  cMsg_kVMmNm0C_sendMessage(_c, 0, m);
  cMsg_1Xg6wu8V_sendMessage(_c, 0, m);
  cMsg_LDUPsLpw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RtsewW8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_ZaIy0SZs_sendMessage(_c, 0, m);
  cMsg_kVMmNm0C_sendMessage(_c, 0, m);
  cMsg_9dHxSnKL_sendMessage(_c, 0, m);
  cMsg_CJNoNVYN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_prC4UuPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_ZaIy0SZs_sendMessage(_c, 0, m);
  cMsg_EYW12dXL_sendMessage(_c, 0, m);
  cMsg_ln296jYt_sendMessage(_c, 0, m);
  cMsg_dKELqlSD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6aPGAFG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_M53RvHTT_sendMessage(_c, 0, m);
  cMsg_LDUPsLpw_sendMessage(_c, 0, m);
  cMsg_hsm8JeVR_sendMessage(_c, 0, m);
  cMsg_ln296jYt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PkHjnvdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_M53RvHTT_sendMessage(_c, 0, m);
  cMsg_dKELqlSD_sendMessage(_c, 0, m);
  cMsg_kVMmNm0C_sendMessage(_c, 0, m);
  cMsg_XGgRCrcy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HOcvRyq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u3pLed3p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zztSZQVs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QIQDK2xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u3pLed3p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zztSZQVs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_erz2mMEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j0g7encW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tNFU1Xa7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XIOJXpxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j0g7encW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tNFU1Xa7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wodTPeMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vqqNZCsm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bqKEMpmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OdAKpZRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vqqNZCsm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bqKEMpmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0s11TUeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_HOcvRyq1_sendMessage(_c, 0, m);
  cMsg_XIOJXpxF_sendMessage(_c, 0, m);
  cMsg_OdAKpZRY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZaIy0SZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_QIQDK2xd_sendMessage(_c, 0, m);
  cMsg_erz2mMEZ_sendMessage(_c, 0, m);
  cMsg_OdAKpZRY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_M53RvHTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_QIQDK2xd_sendMessage(_c, 0, m);
  cMsg_XIOJXpxF_sendMessage(_c, 0, m);
  cMsg_wodTPeMa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AJoxW4X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ubH1YVdM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9i11I0U4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xDf0MgBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ubH1YVdM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9i11I0U4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wPzU9lq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_T4j3OzR1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ar3HtwAb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PpwErIlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_T4j3OzR1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ar3HtwAb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d5oOnCWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UhNZRG0H_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bJ1vLfHw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CLMRPdcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UhNZRG0H_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bJ1vLfHw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kVMmNm0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_xDf0MgBl_sendMessage(_c, 0, m);
  cMsg_PpwErIlQ_sendMessage(_c, 0, m);
  cMsg_CLMRPdcn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ukriBeQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_xDf0MgBl_sendMessage(_c, 0, m);
  cMsg_wPzU9lq0_sendMessage(_c, 0, m);
  cMsg_d5oOnCWq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EYW12dXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_AJoxW4X2_sendMessage(_c, 0, m);
  cMsg_PpwErIlQ_sendMessage(_c, 0, m);
  cMsg_d5oOnCWq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KlK69osR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rxHzKStj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tHeGlKKX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gngJmo9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rxHzKStj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tHeGlKKX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5P5XbLtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_p6QUo1m3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RPeOBHlg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7bMfkEdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_p6QUo1m3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RPeOBHlg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eOp0rgT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HDwC8wn2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PCA1DkKb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zU1mkPu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HDwC8wn2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PCA1DkKb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dKELqlSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_KlK69osR_sendMessage(_c, 0, m);
  cMsg_7bMfkEdY_sendMessage(_c, 0, m);
  cMsg_zU1mkPu7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LDUPsLpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_gngJmo9J_sendMessage(_c, 0, m);
  cMsg_5P5XbLtL_sendMessage(_c, 0, m);
  cMsg_zU1mkPu7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9dHxSnKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_gngJmo9J_sendMessage(_c, 0, m);
  cMsg_7bMfkEdY_sendMessage(_c, 0, m);
  cMsg_eOp0rgT2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_53kuCaNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GLkxoAhz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5yHKoBQf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mQ3CLbvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GLkxoAhz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5yHKoBQf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DvllStaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kvqWznCY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wzLiCdnW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fkATUpCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kvqWznCY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wzLiCdnW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h5S7vsKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aXzeDnuq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UXug0MJh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ckEIR1j7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aXzeDnuq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UXug0MJh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ln296jYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_mQ3CLbvP_sendMessage(_c, 0, m);
  cMsg_fkATUpCk_sendMessage(_c, 0, m);
  cMsg_ckEIR1j7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1Xg6wu8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_mQ3CLbvP_sendMessage(_c, 0, m);
  cMsg_DvllStaX_sendMessage(_c, 0, m);
  cMsg_h5S7vsKI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XGgRCrcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_53kuCaNL_sendMessage(_c, 0, m);
  cMsg_DvllStaX_sendMessage(_c, 0, m);
  cMsg_ckEIR1j7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hsm8JeVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_AJoxW4X2_sendMessage(_c, 0, m);
  cMsg_wPzU9lq0_sendMessage(_c, 0, m);
  cMsg_CLMRPdcn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CJNoNVYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_53kuCaNL_sendMessage(_c, 0, m);
  cMsg_fkATUpCk_sendMessage(_c, 0, m);
  cMsg_h5S7vsKI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2tGwmuco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N6EyrpNB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GCIf41aO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eY3ANIEG, 0, m, &cSlice_eY3ANIEG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JB7FxP3w_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_eY3ANIEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aXq4frMS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aXq4frMS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YpYSVsit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aXq4frMS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aXq4frMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yU4mQBbK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cmpWW9aw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MbQMgkNU, 0, m, &cSlice_MbQMgkNU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mWJjSbXY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_MbQMgkNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PjyuK8IH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PjyuK8IH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Os69WWP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PjyuK8IH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_PjyuK8IH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WxBuzXuA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mWJjSbXY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ckbOdrut, 0, m, &cSlice_ckbOdrut_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GCIf41aO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ckbOdrut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_r65lx5gh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_r65lx5gh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_CwTjUmg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_r65lx5gh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_r65lx5gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DpM1m0Dn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JB7FxP3w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_S7zZS8EI, 0, m, &cSlice_S7zZS8EI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jC66OGmK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_S7zZS8EI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7CtKlHX2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7CtKlHX2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_fihYr1XF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7CtKlHX2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7CtKlHX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ujxxDbKm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jC66OGmK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_orYrkCEZ, 0, m, &cSlice_orYrkCEZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nfXy9kX8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_orYrkCEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hb1PwxbL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hb1PwxbL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Qwf1yA2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hb1PwxbL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hb1PwxbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1Pr5UXPo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_po8CIX8A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6KN1oaiz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6KN1oaiz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9BQJld2N, 1, m, &cDelay_9BQJld2N_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gzUUaGX8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9BQJld2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9BQJld2N, m);
  cMsg_srTnZ5Yl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6KN1oaiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9BQJld2N, 0, m, &cDelay_9BQJld2N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gzUUaGX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9BQJld2N, 0, m, &cDelay_9BQJld2N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_H9ow7ytc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5xUjTkyi, HV_BINOP_SUBTRACT, 0, m, &cBinop_5xUjTkyi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_0OnmJmQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0WtVAEi7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oPvTpXla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0WtVAEi7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_U66skpCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H9ow7ytc, 0, m, &cVar_H9ow7ytc_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_L63ZQJAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gafEHj16_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2MgKC0rp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V5jsTN2w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5xUjTkyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XOso9Xnp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XOso9Xnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5ByQvwCv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5ByQvwCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_RyQpjVmf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gtshyUjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u1pJVZvW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iVDoGsua_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u1pJVZvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0OnmJmQ1, 1, m, &cIf_0OnmJmQ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iVDoGsua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bwLjzIm8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Cf8Imgdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oPvTpXla, 1, m, &cIf_oPvTpXla_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bwLjzIm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0OnmJmQ1, 0, m, &cIf_0OnmJmQ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RyQpjVmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oPvTpXla, 0, m, &cIf_oPvTpXla_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gafEHj16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_V5jsTN2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H9ow7ytc, 0, m, &cVar_H9ow7ytc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2MgKC0rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5xUjTkyi, HV_BINOP_SUBTRACT, 1, m, &cBinop_5xUjTkyi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0WtVAEi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zkDeWrpp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nfXy9kX8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Rl3piSN5, 0, m, &cSlice_Rl3piSN5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Rl3piSN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_H5r6LeeD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_H5r6LeeD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PxrHZag2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_H5r6LeeD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_H5r6LeeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_toSbo5bm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kZeLfPtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oInOwpc3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YMm8L6L9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OWbLAUAP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_TiLNnw2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZTlWhS6g, 0, m, &cVar_ZTlWhS6g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N6EyrpNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JV9pTreA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XG0Aizdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t2rO0kje_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_C6PXUI9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_po8CIX8A_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_srTnZ5Yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lDIbYlSg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_t2rO0kje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lDIbYlSg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FupGMp8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_sJNtABwS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sJNtABwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vaU89kHG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vaU89kHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_18vswGyo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_Au8MHXRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eUW5rPpM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_YkiJiprp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O1nrpmxi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_b8RY6tIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ebNBzq22_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_YvsKdw8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R6e3YWYH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_R3j1exbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mdELN8YH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pRCGs2NA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i3dl8L56_sendMessage);
  cMsg_agDRsgbj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_i3dl8L56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pRCGs2NA, 1, m, &cVar_pRCGs2NA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a0PFhJ9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eTj6b4mn_sendMessage(_c, 0, m);
  cMsg_QCdRYuvl_sendMessage(_c, 0, m);
  cMsg_Zx4I92np_sendMessage(_c, 0, m);
  cMsg_tf801OCL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_un7KBkCO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h8a0dRd3, 0, m, &cSlice_h8a0dRd3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_h8a0dRd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tm4QtvOa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tm4QtvOa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_gIlFwekD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tm4QtvOa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_tm4QtvOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KfdvfLHn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xCm3911p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Z63ukQhW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z63ukQhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_6dTJBcnC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6dTJBcnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LkE8n8zn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LkE8n8zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YTHeuLgx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vkgs27vu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vkgs27vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0BOuBBpH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_YTHeuLgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ECuKqJIF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ECuKqJIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UlJ3CSoz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0BOuBBpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wNXchdF3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wNXchdF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ym3b3C9N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UlJ3CSoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Msoci3Bj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ym3b3C9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_85cMMNHg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Msoci3Bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UJoP6xVs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_85cMMNHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Kwy0iyFE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_7yLCYjgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UJhecAIH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_QzAjBMFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QTwZrqwC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Yqfj1L9I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tc9QGmGJ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EgpHfrrG_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oWiIJ2kU_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pjC0QesF_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5pmz1kkW_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZWdO5J9D_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_tc9QGmGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KSsQsbw5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_EgpHfrrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cq1dIRlg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_oWiIJ2kU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OJgyeMdG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_pjC0QesF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HD63SdCj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_5pmz1kkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wOGGtaGW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZWdO5J9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C4GXwMqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_9cV4O9DZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BZlki25Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_h6vlmpnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sBpbctxg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mcULuccL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XnVD2lyt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XnVD2lyt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1FyWZMfJ, 1, m, &cDelay_1FyWZMfJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6PE7WTu4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1FyWZMfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1FyWZMfJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9cV4O9DZ, 0, m, &cIf_9cV4O9DZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XnVD2lyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1FyWZMfJ, 0, m, &cDelay_1FyWZMfJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6PE7WTu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1FyWZMfJ, 0, m, &cDelay_1FyWZMfJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SvAJlAvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LvvMs9jN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KiuHmjR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y25oZ0uZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jfVYS6G9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iUA65gbE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iUA65gbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mcULuccL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jfVYS6G9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9cV4O9DZ, 1, m, &cIf_9cV4O9DZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KiuHmjR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h6vlmpnP, 0, m, &cIf_h6vlmpnP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LvvMs9jN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h6vlmpnP, 1, m, &cIf_h6vlmpnP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sBpbctxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZNAlzfhk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BZlki25Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZNAlzfhk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8vEkew8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6PKpw5iH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4PkoDPTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lT5OV32T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dxoy5Rom_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YJf0AnHv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YJf0AnHv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_G1XpZs8l, 1, m, &cDelay_G1XpZs8l_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zHKRSFq8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_G1XpZs8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_G1XpZs8l, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8vEkew8r, 0, m, &cIf_8vEkew8r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YJf0AnHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_G1XpZs8l, 0, m, &cDelay_G1XpZs8l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zHKRSFq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_G1XpZs8l, 0, m, &cDelay_G1XpZs8l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T177jkVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Mnug3nU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Id8g2RVp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7wdPdAtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kTOgCByO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EAsDGekN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EAsDGekN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dxoy5Rom_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kTOgCByO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8vEkew8r, 1, m, &cIf_8vEkew8r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Id8g2RVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4PkoDPTj, 0, m, &cIf_4PkoDPTj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6Mnug3nU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4PkoDPTj, 1, m, &cIf_4PkoDPTj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lT5OV32T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_11B5flyN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6PKpw5iH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_11B5flyN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ni5V7yTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TCOycbfW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3cFwTujv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_um31DrPz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZVo3VQIi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hSOOJx7H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hSOOJx7H_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dCNOa7Xq, 1, m, &cDelay_dCNOa7Xq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9HGQbNcy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dCNOa7Xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dCNOa7Xq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ni5V7yTa, 0, m, &cIf_ni5V7yTa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hSOOJx7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dCNOa7Xq, 0, m, &cDelay_dCNOa7Xq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9HGQbNcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dCNOa7Xq, 0, m, &cDelay_dCNOa7Xq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_laibJzza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FY8m6nLS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NBM1BA1l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yRzdbpVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q1KIRGZS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TTPVSMCz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TTPVSMCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZVo3VQIi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_q1KIRGZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ni5V7yTa, 1, m, &cIf_ni5V7yTa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NBM1BA1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3cFwTujv, 0, m, &cIf_3cFwTujv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FY8m6nLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3cFwTujv, 1, m, &cIf_3cFwTujv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_um31DrPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1CGMk273, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TCOycbfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1CGMk273, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_H7hIMWFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_l3BGJTP2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1pzsphbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3dn0ShDf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BQcWjL6I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CrCXFE16_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CrCXFE16_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KV9saawW, 1, m, &cDelay_KV9saawW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MSiR64uX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KV9saawW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KV9saawW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_H7hIMWFL, 0, m, &cIf_H7hIMWFL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CrCXFE16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KV9saawW, 0, m, &cDelay_KV9saawW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MSiR64uX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KV9saawW, 0, m, &cDelay_KV9saawW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iao8sIOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_naiGXXZG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FPqNf2gv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G7cdv3K2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cc4QhyCO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ysyzjP47_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Cc4QhyCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H7hIMWFL, 1, m, &cIf_H7hIMWFL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ysyzjP47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BQcWjL6I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FPqNf2gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1pzsphbs, 0, m, &cIf_1pzsphbs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_naiGXXZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1pzsphbs, 1, m, &cIf_1pzsphbs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3dn0ShDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k260QzrI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_l3BGJTP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k260QzrI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_QJp7wSYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fX3qON1K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_M55mtmdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3WDU9wqH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DpnDx13k_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jnga2DZ5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jnga2DZ5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lndL8nmK, 1, m, &cDelay_lndL8nmK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BRvitn3x_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lndL8nmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lndL8nmK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QJp7wSYo, 0, m, &cIf_QJp7wSYo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jnga2DZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lndL8nmK, 0, m, &cDelay_lndL8nmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BRvitn3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lndL8nmK, 0, m, &cDelay_lndL8nmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FP0j1uC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_isyBw6cE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vJkeRs38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_STKbXK5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qygqVML2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b0XFhjzP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qygqVML2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QJp7wSYo, 1, m, &cIf_QJp7wSYo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b0XFhjzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DpnDx13k_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vJkeRs38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M55mtmdF, 0, m, &cIf_M55mtmdF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_isyBw6cE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M55mtmdF, 1, m, &cIf_M55mtmdF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3WDU9wqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FI43mGGk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fX3qON1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FI43mGGk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mTTO3hWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5PluNuhj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pF68Ps9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NIp4DxIF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4BnxBvt7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JjSm4kl5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JjSm4kl5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kim1ebnw, 1, m, &cDelay_kim1ebnw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s9frnme7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kim1ebnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kim1ebnw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mTTO3hWc, 0, m, &cIf_mTTO3hWc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JjSm4kl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kim1ebnw, 0, m, &cDelay_kim1ebnw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s9frnme7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kim1ebnw, 0, m, &cDelay_kim1ebnw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c6tT2ZGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sBVsjX3s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6KHxDPFN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_llf83k9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QxcHYwsW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z6nsjxto_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z6nsjxto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4BnxBvt7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QxcHYwsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mTTO3hWc, 1, m, &cIf_mTTO3hWc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6KHxDPFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pF68Ps9i, 0, m, &cIf_pF68Ps9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sBVsjX3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pF68Ps9i, 1, m, &cIf_pF68Ps9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NIp4DxIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vx9ygqWT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5PluNuhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vx9ygqWT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_11hPWWaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RfqRY55w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_cAYSurrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HLE48T89_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tiUXjjGl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GZxm3Rlm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GZxm3Rlm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hyijO4Tn, 1, m, &cDelay_hyijO4Tn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3X5BTBOU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hyijO4Tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hyijO4Tn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_11hPWWaY, 0, m, &cIf_11hPWWaY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GZxm3Rlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hyijO4Tn, 0, m, &cDelay_hyijO4Tn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3X5BTBOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hyijO4Tn, 0, m, &cDelay_hyijO4Tn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ICNxSQAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yGyBQJ3L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r3ZrQvaY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RsMDScAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_01KEModq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_smR6m9V7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_smR6m9V7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tiUXjjGl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_01KEModq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_11hPWWaY, 1, m, &cIf_11hPWWaY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r3ZrQvaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cAYSurrh, 0, m, &cIf_cAYSurrh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yGyBQJ3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cAYSurrh, 1, m, &cIf_cAYSurrh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HLE48T89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LHNfNZf4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RfqRY55w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LHNfNZf4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8HknMyZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o7Gquvly_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Uu5jqDWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BVG8ZVNJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uf97GNVk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7cS7IPvr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7cS7IPvr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_51Mt8c74, 1, m, &cDelay_51Mt8c74_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jn1ASRfy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_51Mt8c74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_51Mt8c74, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8HknMyZo, 0, m, &cIf_8HknMyZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7cS7IPvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_51Mt8c74, 0, m, &cDelay_51Mt8c74_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jn1ASRfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_51Mt8c74, 0, m, &cDelay_51Mt8c74_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E8q0tzHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0hG9g3tO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hB6DaEf1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7otDCKhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qui6TTP8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fqo65IHC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qui6TTP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8HknMyZo, 1, m, &cIf_8HknMyZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Fqo65IHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uf97GNVk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hB6DaEf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Uu5jqDWN, 0, m, &cIf_Uu5jqDWN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0hG9g3tO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Uu5jqDWN, 1, m, &cIf_Uu5jqDWN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BVG8ZVNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yuk4zdRh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_o7Gquvly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yuk4zdRh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0rMyKIMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HR4ruRF3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RXeYkXpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wbyOEUzp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IOqqUpru_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Mq4ryroZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Mq4ryroZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WPKQv8rj, 1, m, &cDelay_WPKQv8rj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kKJXUZ9l_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WPKQv8rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WPKQv8rj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0rMyKIMI, 0, m, &cIf_0rMyKIMI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mq4ryroZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WPKQv8rj, 0, m, &cDelay_WPKQv8rj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kKJXUZ9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WPKQv8rj, 0, m, &cDelay_WPKQv8rj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QfyJfoM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DiFv9pap_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_60TE4UNv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xz8cf5fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bb8zu4bZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NfL7VDnp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bb8zu4bZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0rMyKIMI, 1, m, &cIf_0rMyKIMI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NfL7VDnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IOqqUpru_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_DiFv9pap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RXeYkXpJ, 1, m, &cIf_RXeYkXpJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_60TE4UNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RXeYkXpJ, 0, m, &cIf_RXeYkXpJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wbyOEUzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_asRQe9Q2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HR4ruRF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_asRQe9Q2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_nQyfsKKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_29t30LzL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pCDfFiXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gfyGCdD0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OlDRPd5f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Xe4CY6KF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Xe4CY6KF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7grlByP8, 1, m, &cDelay_7grlByP8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CCTbgAqz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7grlByP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7grlByP8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_nQyfsKKn, 0, m, &cIf_nQyfsKKn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Xe4CY6KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7grlByP8, 0, m, &cDelay_7grlByP8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CCTbgAqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7grlByP8, 0, m, &cDelay_7grlByP8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WeuDg2va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VMZ7xwPG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4BBVK4Ji_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Szqtx2Q6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rjeJySJu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICKXTX9c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rjeJySJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nQyfsKKn, 1, m, &cIf_nQyfsKKn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ICKXTX9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OlDRPd5f_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VMZ7xwPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pCDfFiXk, 1, m, &cIf_pCDfFiXk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4BBVK4Ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pCDfFiXk, 0, m, &cIf_pCDfFiXk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gfyGCdD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kR7cEzRL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_29t30LzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kR7cEzRL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8xccKKjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FUmyq5nj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Z6mJ8nsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PXbW72i4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vjYSwl16_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HUng0d4y_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HUng0d4y_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_A1CVnb3B, 1, m, &cDelay_A1CVnb3B_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7iFEYmg4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_A1CVnb3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_A1CVnb3B, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8xccKKjS, 0, m, &cIf_8xccKKjS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HUng0d4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_A1CVnb3B, 0, m, &cDelay_A1CVnb3B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7iFEYmg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_A1CVnb3B, 0, m, &cDelay_A1CVnb3B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bhOdO9Xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xNduL72Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HgnGP86q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PfyYN9tW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1cEDhhMF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ft9yO25w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ft9yO25w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vjYSwl16_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1cEDhhMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8xccKKjS, 1, m, &cIf_8xccKKjS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xNduL72Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z6mJ8nsi, 1, m, &cIf_Z6mJ8nsi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HgnGP86q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z6mJ8nsi, 0, m, &cIf_Z6mJ8nsi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PXbW72i4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tcl8ymhp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FUmyq5nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tcl8ymhp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qMS5cgEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PL8uDdvD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7qO8aCHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SvQhs2Un_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MZquq5uV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3EURE3iD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3EURE3iD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wyJxS8cJ, 1, m, &cDelay_wyJxS8cJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ps0nzOHg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wyJxS8cJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wyJxS8cJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qMS5cgEf, 0, m, &cIf_qMS5cgEf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3EURE3iD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wyJxS8cJ, 0, m, &cDelay_wyJxS8cJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ps0nzOHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wyJxS8cJ, 0, m, &cDelay_wyJxS8cJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2gDFqxt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g5i4bJwO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FM7Lk3CN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3PtPsQu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qleFGmxp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bbySt1bG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bbySt1bG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MZquq5uV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qleFGmxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qMS5cgEf, 1, m, &cIf_qMS5cgEf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FM7Lk3CN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7qO8aCHB, 0, m, &cIf_7qO8aCHB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g5i4bJwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7qO8aCHB, 1, m, &cIf_7qO8aCHB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SvQhs2Un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J2AyRPvT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PL8uDdvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J2AyRPvT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KSsQsbw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_Ltxjjyw2_sendMessage(_c, 0, m);
  cMsg_LXCrv5Yn_sendMessage(_c, 0, m);
  cMsg_gesGLh10_sendMessage(_c, 0, m);
  cMsg_3h5kFuxv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Cq1dIRlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_Ltxjjyw2_sendMessage(_c, 0, m);
  cMsg_zVlGpdpA_sendMessage(_c, 0, m);
  cMsg_f4XP57wl_sendMessage(_c, 0, m);
  cMsg_jnP3DDVO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OJgyeMdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_kcYskdzd_sendMessage(_c, 0, m);
  cMsg_zVlGpdpA_sendMessage(_c, 0, m);
  cMsg_3h5kFuxv_sendMessage(_c, 0, m);
  cMsg_F5y2Zeoy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HD63SdCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_kcYskdzd_sendMessage(_c, 0, m);
  cMsg_DxZ0oExy_sendMessage(_c, 0, m);
  cMsg_gesGLh10_sendMessage(_c, 0, m);
  cMsg_INGDvSJf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wOGGtaGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_rAB6IhXe_sendMessage(_c, 0, m);
  cMsg_jnP3DDVO_sendMessage(_c, 0, m);
  cMsg_IjIf0SHc_sendMessage(_c, 0, m);
  cMsg_gesGLh10_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_C4GXwMqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_rAB6IhXe_sendMessage(_c, 0, m);
  cMsg_INGDvSJf_sendMessage(_c, 0, m);
  cMsg_zVlGpdpA_sendMessage(_c, 0, m);
  cMsg_Ytqg9WXK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LEm4ZNCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y25oZ0uZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SvAJlAvH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hkoyrHYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y25oZ0uZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SvAJlAvH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IXux16rZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7wdPdAtP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T177jkVE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dsAgy7qH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7wdPdAtP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T177jkVE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yBDKSGg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yRzdbpVx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_laibJzza_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dcyI5mJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yRzdbpVx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_laibJzza_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ltxjjyw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_LEm4ZNCU_sendMessage(_c, 0, m);
  cMsg_dsAgy7qH_sendMessage(_c, 0, m);
  cMsg_dcyI5mJJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kcYskdzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_hkoyrHYO_sendMessage(_c, 0, m);
  cMsg_IXux16rZ_sendMessage(_c, 0, m);
  cMsg_dcyI5mJJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rAB6IhXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_hkoyrHYO_sendMessage(_c, 0, m);
  cMsg_dsAgy7qH_sendMessage(_c, 0, m);
  cMsg_yBDKSGg9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MI5Wimzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G7cdv3K2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iao8sIOL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ULTh8Lk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G7cdv3K2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iao8sIOL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kLOUWO4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_STKbXK5g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FP0j1uC8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZTMwpcS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_STKbXK5g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FP0j1uC8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_diFWapWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_llf83k9X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_c6tT2ZGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LWfL2h7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_llf83k9X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_c6tT2ZGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zVlGpdpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ULTh8Lk8_sendMessage(_c, 0, m);
  cMsg_ZTMwpcS6_sendMessage(_c, 0, m);
  cMsg_LWfL2h7d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LXCrv5Yn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ULTh8Lk8_sendMessage(_c, 0, m);
  cMsg_kLOUWO4a_sendMessage(_c, 0, m);
  cMsg_diFWapWd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DxZ0oExy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_MI5Wimzv_sendMessage(_c, 0, m);
  cMsg_ZTMwpcS6_sendMessage(_c, 0, m);
  cMsg_diFWapWd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6SsCoGSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Szqtx2Q6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WeuDg2va_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uRoc1fTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Szqtx2Q6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WeuDg2va_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b6HLvYTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PfyYN9tW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bhOdO9Xl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bqR9Y4zi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PfyYN9tW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bhOdO9Xl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5IqZDAct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3PtPsQu0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2gDFqxt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DyfUcaMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3PtPsQu0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2gDFqxt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_INGDvSJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_6SsCoGSj_sendMessage(_c, 0, m);
  cMsg_bqR9Y4zi_sendMessage(_c, 0, m);
  cMsg_DyfUcaMm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jnP3DDVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_uRoc1fTz_sendMessage(_c, 0, m);
  cMsg_b6HLvYTV_sendMessage(_c, 0, m);
  cMsg_DyfUcaMm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3h5kFuxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_uRoc1fTz_sendMessage(_c, 0, m);
  cMsg_bqR9Y4zi_sendMessage(_c, 0, m);
  cMsg_5IqZDAct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ogMeiQE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RsMDScAn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ICNxSQAJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uu4jfTgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RsMDScAn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ICNxSQAJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9WmD059V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7otDCKhN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E8q0tzHN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7Do5kpCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7otDCKhN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E8q0tzHN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LBuvZrgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xz8cf5fi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QfyJfoM0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1V6Yu0TL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xz8cf5fi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QfyJfoM0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gesGLh10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_uu4jfTgo_sendMessage(_c, 0, m);
  cMsg_7Do5kpCw_sendMessage(_c, 0, m);
  cMsg_1V6Yu0TL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_f4XP57wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_uu4jfTgo_sendMessage(_c, 0, m);
  cMsg_9WmD059V_sendMessage(_c, 0, m);
  cMsg_LBuvZrgI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ytqg9WXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_ogMeiQE5_sendMessage(_c, 0, m);
  cMsg_9WmD059V_sendMessage(_c, 0, m);
  cMsg_1V6Yu0TL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IjIf0SHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_MI5Wimzv_sendMessage(_c, 0, m);
  cMsg_kLOUWO4a_sendMessage(_c, 0, m);
  cMsg_LWfL2h7d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_F5y2Zeoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_ogMeiQE5_sendMessage(_c, 0, m);
  cMsg_7Do5kpCw_sendMessage(_c, 0, m);
  cMsg_LBuvZrgI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_zYk09tuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c4tgkg1q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TAoK8Yrv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bs9WUECD, 0, m, &cSlice_bs9WUECD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hQhstvSB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bs9WUECD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_21xKD4c2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_21xKD4c2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ny9yNo1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_21xKD4c2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_21xKD4c2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_flI0DG9u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_R9UI1Kqo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3Q189xTY, 0, m, &cSlice_3Q189xTY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IHOCPTw8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3Q189xTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GGLgR2Hl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GGLgR2Hl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_aWKOze0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GGLgR2Hl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GGLgR2Hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hxWWOb38_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IHOCPTw8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EVswSp87, 0, m, &cSlice_EVswSp87_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TAoK8Yrv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_EVswSp87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bC9TsnTg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bC9TsnTg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0wTYKZSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bC9TsnTg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_bC9TsnTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DW29e6Qt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hQhstvSB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yfhd6GUz, 0, m, &cSlice_yfhd6GUz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JF33h0RT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_yfhd6GUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yfJCbqnZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yfJCbqnZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_T2vwXTxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yfJCbqnZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yfJCbqnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_S2ZfbN2T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JF33h0RT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_v0wrAHz7, 0, m, &cSlice_v0wrAHz7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FrDo54W4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_v0wrAHz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ilmZckrV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ilmZckrV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Bp5lSYPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ilmZckrV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ilmZckrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6ef7uFFn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mmXOa6zC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yEDACL4j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yEDACL4j_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_eMznzQy1, 1, m, &cDelay_eMznzQy1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s9MeoHtr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_eMznzQy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eMznzQy1, m);
  cMsg_TWqFJF8w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yEDACL4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eMznzQy1, 0, m, &cDelay_eMznzQy1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s9MeoHtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eMznzQy1, 0, m, &cDelay_eMznzQy1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_YB47Jn9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DgTLCtLx, HV_BINOP_SUBTRACT, 0, m, &cBinop_DgTLCtLx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_cBcpyMMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WKm8BSKS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gk165h40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WKm8BSKS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_SjIBOi8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YB47Jn9e, 0, m, &cVar_YB47Jn9e_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_RSZCApoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q0IMpYWw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fPDGXM1b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1s5lf8sM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DgTLCtLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GjX2fNXA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GjX2fNXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_s8Lh1cKQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s8Lh1cKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Un7FaWF6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rE85hBvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VlBhcZK6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HneIEQeY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HneIEQeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bn58M4PC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VlBhcZK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cBcpyMMb, 1, m, &cIf_cBcpyMMb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vq1Y4DHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gk165h40, 1, m, &cIf_gk165h40_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bn58M4PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_cBcpyMMb, 0, m, &cIf_cBcpyMMb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Un7FaWF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gk165h40, 0, m, &cIf_gk165h40_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fPDGXM1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DgTLCtLx, HV_BINOP_SUBTRACT, 1, m, &cBinop_DgTLCtLx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q0IMpYWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_1s5lf8sM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YB47Jn9e, 0, m, &cVar_YB47Jn9e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WKm8BSKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s3cD0sXt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FrDo54W4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_58wW0zmC, 0, m, &cSlice_58wW0zmC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_58wW0zmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GrTrqVex_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GrTrqVex_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_oWHUvzwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GrTrqVex_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GrTrqVex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WlKbBxNe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UJhecAIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NfbWX0kJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QTwZrqwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oYdHT1Pm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_ElmkqpIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QzAjBMFA, 0, m, &cVar_QzAjBMFA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c4tgkg1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eBTa6ZvN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_PcD0Gi1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mmXOa6zC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MDemXK3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pDVV2dMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TWqFJF8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nm0MD97k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pDVV2dMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nm0MD97k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_m4x4kl8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_YYKDIfCg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YYKDIfCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y4tkLCwH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Y4tkLCwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qIxwRMKh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_qdKpXXVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ywuT8jXb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_k38NOFYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ntE8QpVJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QeUUPkzF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NJoHJTD1_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_09RaqG2P_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lDs3xf1m_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xIQ6Xhj8_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qxBWuydD_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hH0UgbX6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_NJoHJTD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nSdDXM28_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_09RaqG2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ziJd0PVN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lDs3xf1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bj2bscJC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_xIQ6Xhj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jJEgurDc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_qxBWuydD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OVEbYoNk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_hH0UgbX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3BKKRvx8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_FwU8u5Wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YaOy2viV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fzCSj2Nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JWR3OTA0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1XU0pJaC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7ifYHhYL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7ifYHhYL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_D0Aa7UeL, 1, m, &cDelay_D0Aa7UeL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MnMTh7kY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_D0Aa7UeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D0Aa7UeL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FwU8u5Wl, 0, m, &cIf_FwU8u5Wl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7ifYHhYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D0Aa7UeL, 0, m, &cDelay_D0Aa7UeL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MnMTh7kY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D0Aa7UeL, 0, m, &cDelay_D0Aa7UeL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QQs6Qen4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BHqHOf9H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_egaayERM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_97eUisZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AulfmvAF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jF7fLzY0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jF7fLzY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1XU0pJaC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AulfmvAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FwU8u5Wl, 1, m, &cIf_FwU8u5Wl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BHqHOf9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fzCSj2Nr, 1, m, &cIf_fzCSj2Nr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_egaayERM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fzCSj2Nr, 0, m, &cIf_fzCSj2Nr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JWR3OTA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LBy1YJne, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YaOy2viV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LBy1YJne, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Z219Xkma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kw32N0ny_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_cy145gPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1ZAlTLxO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YyC3V43g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Czoawzt7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Czoawzt7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yH0zZMb0, 1, m, &cDelay_yH0zZMb0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_usRdk3gW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yH0zZMb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yH0zZMb0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Z219Xkma, 0, m, &cIf_Z219Xkma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Czoawzt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yH0zZMb0, 0, m, &cDelay_yH0zZMb0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_usRdk3gW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yH0zZMb0, 0, m, &cDelay_yH0zZMb0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a0RzkdqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cAHHaB08_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tVCWf0we_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V9igo9RR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vaZBpH2R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UWvE07jt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UWvE07jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YyC3V43g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vaZBpH2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z219Xkma, 1, m, &cIf_Z219Xkma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tVCWf0we_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cy145gPV, 0, m, &cIf_cy145gPV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cAHHaB08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cy145gPV, 1, m, &cIf_cy145gPV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1ZAlTLxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mZcu5W0W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kw32N0ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mZcu5W0W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6pLP6WwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SdJern7B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hQYqfS47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dbkgBmQx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7B9lwfpY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YzAHyyS1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YzAHyyS1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5hHmKgXv, 1, m, &cDelay_5hHmKgXv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aGpLMumy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5hHmKgXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5hHmKgXv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6pLP6WwZ, 0, m, &cIf_6pLP6WwZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YzAHyyS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5hHmKgXv, 0, m, &cDelay_5hHmKgXv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aGpLMumy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5hHmKgXv, 0, m, &cDelay_5hHmKgXv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OCOBD3M0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4i5LwRik_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_28Cs0LhN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_te9r91ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_57Ftn9jo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v3C8dZzC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v3C8dZzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7B9lwfpY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_57Ftn9jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6pLP6WwZ, 1, m, &cIf_6pLP6WwZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_28Cs0LhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hQYqfS47, 0, m, &cIf_hQYqfS47_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4i5LwRik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hQYqfS47, 1, m, &cIf_hQYqfS47_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dbkgBmQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j8GtFFRj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SdJern7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j8GtFFRj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vWAlrQmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EfytQXk3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QQLUYEbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AbpVb89l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qnB9U2Iw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DUgrK1oM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DUgrK1oM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Vc0wELzk, 1, m, &cDelay_Vc0wELzk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EkN89kpq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Vc0wELzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Vc0wELzk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vWAlrQmU, 0, m, &cIf_vWAlrQmU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DUgrK1oM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vc0wELzk, 0, m, &cDelay_Vc0wELzk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EkN89kpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vc0wELzk, 0, m, &cDelay_Vc0wELzk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MZiSY2c9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5XsVUsHJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xmu4zvqv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RSx4NJIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cii21bAr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HGa4xzLB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cii21bAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vWAlrQmU, 1, m, &cIf_vWAlrQmU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HGa4xzLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qnB9U2Iw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5XsVUsHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QQLUYEbt, 1, m, &cIf_QQLUYEbt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xmu4zvqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QQLUYEbt, 0, m, &cIf_QQLUYEbt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AbpVb89l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cH1VQwhi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EfytQXk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cH1VQwhi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aGo25Mwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JbjCfe5m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_N63a2foj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yQE2EV71_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_u3000RhW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3MmBimjW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3MmBimjW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3QiQ7G04, 1, m, &cDelay_3QiQ7G04_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_81APLX9g_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_3QiQ7G04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3QiQ7G04, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aGo25Mwp, 0, m, &cIf_aGo25Mwp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3MmBimjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3QiQ7G04, 0, m, &cDelay_3QiQ7G04_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_81APLX9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3QiQ7G04, 0, m, &cDelay_3QiQ7G04_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m3oGlCQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XpbnzBkP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YOMXmYk2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vK489BAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ND3IIbAX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XUBb6mzR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XUBb6mzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_u3000RhW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ND3IIbAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aGo25Mwp, 1, m, &cIf_aGo25Mwp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XpbnzBkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N63a2foj, 1, m, &cIf_N63a2foj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YOMXmYk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N63a2foj, 0, m, &cIf_N63a2foj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yQE2EV71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0k24U2Vo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JbjCfe5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0k24U2Vo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GdyHn7Ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GykkOVKs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wgb9mMRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PQBaW2un_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eRufQTrw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_i0t8GZsl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_i0t8GZsl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_M4IuvHrz, 1, m, &cDelay_M4IuvHrz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OUloEgh0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_M4IuvHrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M4IuvHrz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GdyHn7Ur, 0, m, &cIf_GdyHn7Ur_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i0t8GZsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_M4IuvHrz, 0, m, &cDelay_M4IuvHrz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OUloEgh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M4IuvHrz, 0, m, &cDelay_M4IuvHrz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WHhv6aYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SVOZhRL9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WCpwidr6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JISF3Kge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z0Va84Wa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A9pB2uTH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A9pB2uTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eRufQTrw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_z0Va84Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GdyHn7Ur, 1, m, &cIf_GdyHn7Ur_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WCpwidr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wgb9mMRo, 0, m, &cIf_wgb9mMRo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SVOZhRL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wgb9mMRo, 1, m, &cIf_wgb9mMRo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PQBaW2un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oQeq7PRC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GykkOVKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oQeq7PRC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8fJFgJWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bpAmK80b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9u0QczOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BxgEWpu5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zURx6cch_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LIgOjtY9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LIgOjtY9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_577AWTv4, 1, m, &cDelay_577AWTv4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kVyhZq0b_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_577AWTv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_577AWTv4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8fJFgJWG, 0, m, &cIf_8fJFgJWG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LIgOjtY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_577AWTv4, 0, m, &cDelay_577AWTv4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kVyhZq0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_577AWTv4, 0, m, &cDelay_577AWTv4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nw90040W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O7wCvxZd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7lcrzs2n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zBuu2STI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uc9Ef6pr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_piV4BIKM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_piV4BIKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zURx6cch_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Uc9Ef6pr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8fJFgJWG, 1, m, &cIf_8fJFgJWG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7lcrzs2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9u0QczOw, 0, m, &cIf_9u0QczOw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O7wCvxZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9u0QczOw, 1, m, &cIf_9u0QczOw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BxgEWpu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0aHfvFtH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bpAmK80b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0aHfvFtH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ngUP2kWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EblR0dRZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_B1JNnVvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_S8mlms3S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QujzNINr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Tj4tBomC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Tj4tBomC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zS16b9UA, 1, m, &cDelay_zS16b9UA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B4xDMu8a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zS16b9UA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zS16b9UA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ngUP2kWl, 0, m, &cIf_ngUP2kWl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Tj4tBomC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zS16b9UA, 0, m, &cDelay_zS16b9UA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B4xDMu8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zS16b9UA, 0, m, &cDelay_zS16b9UA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nkGrNHu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kWCIyFJN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XS9i61CN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MqUGWqhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SoJiB6F6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tsyegHwv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tsyegHwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QujzNINr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SoJiB6F6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ngUP2kWl, 1, m, &cIf_ngUP2kWl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XS9i61CN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B1JNnVvs, 0, m, &cIf_B1JNnVvs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kWCIyFJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B1JNnVvs, 1, m, &cIf_B1JNnVvs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_S8mlms3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1R7IS8uU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EblR0dRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1R7IS8uU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_K6YpU0Se_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9A4TnRjf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EkOCfPJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_agPI9Nnw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AMiGUUTh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NCjWvt61_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NCjWvt61_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sWrvoA0T, 1, m, &cDelay_sWrvoA0T_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lb0PoiA1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sWrvoA0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sWrvoA0T, m);
  cIf_onMessage(_c, &Context(_c)->cIf_K6YpU0Se, 0, m, &cIf_K6YpU0Se_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NCjWvt61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sWrvoA0T, 0, m, &cDelay_sWrvoA0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Lb0PoiA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sWrvoA0T, 0, m, &cDelay_sWrvoA0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pr6Z9ymm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5rMMjn2w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YX0aLTU8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WwNHO0Ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8t37AHuv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_katozevb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_katozevb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AMiGUUTh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8t37AHuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K6YpU0Se, 1, m, &cIf_K6YpU0Se_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YX0aLTU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EkOCfPJM, 0, m, &cIf_EkOCfPJM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5rMMjn2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EkOCfPJM, 1, m, &cIf_EkOCfPJM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_agPI9Nnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yVhJqV7F, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9A4TnRjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yVhJqV7F, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7edLrPeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SDnAFkrj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ABuHpwvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ms1slbDn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5Ibpem6O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dXXTn5XC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dXXTn5XC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qwegke8d, 1, m, &cDelay_qwegke8d_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pumLcTRg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qwegke8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qwegke8d, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7edLrPeE, 0, m, &cIf_7edLrPeE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dXXTn5XC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qwegke8d, 0, m, &cDelay_qwegke8d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pumLcTRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qwegke8d, 0, m, &cDelay_qwegke8d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LvNBPaSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UlQaNEtV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mVTCNNu0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jkLRUNiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dA0MTwgP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mGumSYxE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dA0MTwgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7edLrPeE, 1, m, &cIf_7edLrPeE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mGumSYxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5Ibpem6O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mVTCNNu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ABuHpwvn, 0, m, &cIf_ABuHpwvn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UlQaNEtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ABuHpwvn, 1, m, &cIf_ABuHpwvn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ms1slbDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pL6OjPqA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SDnAFkrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pL6OjPqA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_DqWkpNIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Q6CBIT5Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bPtTdWFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yb8mqLkI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CX1EHjXv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oa1ummFg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oa1ummFg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nrg9U6BQ, 1, m, &cDelay_nrg9U6BQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LuYDIA6c_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nrg9U6BQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nrg9U6BQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_DqWkpNIQ, 0, m, &cIf_DqWkpNIQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oa1ummFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nrg9U6BQ, 0, m, &cDelay_nrg9U6BQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LuYDIA6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nrg9U6BQ, 0, m, &cDelay_nrg9U6BQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cYIynyf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bd0oyomx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pubAALz6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZiYTGIO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zgCCOUq6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cEHYFkWk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cEHYFkWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CX1EHjXv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zgCCOUq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DqWkpNIQ, 1, m, &cIf_DqWkpNIQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pubAALz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bPtTdWFW, 0, m, &cIf_bPtTdWFW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bd0oyomx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bPtTdWFW, 1, m, &cIf_bPtTdWFW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yb8mqLkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bHAZ78gt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Q6CBIT5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bHAZ78gt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_rZeQsZzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ha0ZljtJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_E69qujU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FhO6UPKC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2T0F4IYS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sCNa7mMD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sCNa7mMD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DLEGZ2qN, 1, m, &cDelay_DLEGZ2qN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1K3QObjO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_DLEGZ2qN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DLEGZ2qN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rZeQsZzd, 0, m, &cIf_rZeQsZzd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sCNa7mMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DLEGZ2qN, 0, m, &cDelay_DLEGZ2qN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1K3QObjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DLEGZ2qN, 0, m, &cDelay_DLEGZ2qN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LTruIDEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0oiyNYLw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b25Cl7YL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5WFyt5BU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OQXU9Qa0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZEO17hPF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZEO17hPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2T0F4IYS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OQXU9Qa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZeQsZzd, 1, m, &cIf_rZeQsZzd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b25Cl7YL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E69qujU7, 0, m, &cIf_E69qujU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0oiyNYLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E69qujU7, 1, m, &cIf_E69qujU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FhO6UPKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gZ5akssZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ha0ZljtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gZ5akssZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nSdDXM28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_AEQ6CZDm_sendMessage(_c, 0, m);
  cMsg_T5NtjOMN_sendMessage(_c, 0, m);
  cMsg_JHDkZRNg_sendMessage(_c, 0, m);
  cMsg_apBJaWlP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ziJd0PVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_AEQ6CZDm_sendMessage(_c, 0, m);
  cMsg_dz7dCXEX_sendMessage(_c, 0, m);
  cMsg_3asik3FK_sendMessage(_c, 0, m);
  cMsg_FDRyzKjM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Bj2bscJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_M8vZTg1o_sendMessage(_c, 0, m);
  cMsg_dz7dCXEX_sendMessage(_c, 0, m);
  cMsg_apBJaWlP_sendMessage(_c, 0, m);
  cMsg_9EYp3d4S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jJEgurDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_M8vZTg1o_sendMessage(_c, 0, m);
  cMsg_02rWPxXA_sendMessage(_c, 0, m);
  cMsg_JHDkZRNg_sendMessage(_c, 0, m);
  cMsg_14AD6ZXf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OVEbYoNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_k9E79jgS_sendMessage(_c, 0, m);
  cMsg_FDRyzKjM_sendMessage(_c, 0, m);
  cMsg_1rMePRO4_sendMessage(_c, 0, m);
  cMsg_JHDkZRNg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3BKKRvx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_k9E79jgS_sendMessage(_c, 0, m);
  cMsg_14AD6ZXf_sendMessage(_c, 0, m);
  cMsg_dz7dCXEX_sendMessage(_c, 0, m);
  cMsg_w3B14KlT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HcDllyqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_97eUisZv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QQs6Qen4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3hAVsHL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_97eUisZv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QQs6Qen4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ay2SoCLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V9igo9RR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a0RzkdqU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IXWMqZ2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V9igo9RR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a0RzkdqU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O4POpASz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_te9r91ar_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OCOBD3M0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wnk21Tmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_te9r91ar_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OCOBD3M0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AEQ6CZDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_HcDllyqV_sendMessage(_c, 0, m);
  cMsg_IXWMqZ2u_sendMessage(_c, 0, m);
  cMsg_wnk21Tmp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_M8vZTg1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_3hAVsHL3_sendMessage(_c, 0, m);
  cMsg_ay2SoCLG_sendMessage(_c, 0, m);
  cMsg_wnk21Tmp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_k9E79jgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_3hAVsHL3_sendMessage(_c, 0, m);
  cMsg_IXWMqZ2u_sendMessage(_c, 0, m);
  cMsg_O4POpASz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JChYNr1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RSx4NJIP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MZiSY2c9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YQiAMbf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RSx4NJIP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MZiSY2c9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2xMfkm5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vK489BAa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m3oGlCQR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vDKLe9gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vK489BAa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m3oGlCQR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MpljcOG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JISF3Kge_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WHhv6aYT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CygJoedL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JISF3Kge_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WHhv6aYT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dz7dCXEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_YQiAMbf8_sendMessage(_c, 0, m);
  cMsg_vDKLe9gi_sendMessage(_c, 0, m);
  cMsg_CygJoedL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_T5NtjOMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_YQiAMbf8_sendMessage(_c, 0, m);
  cMsg_2xMfkm5X_sendMessage(_c, 0, m);
  cMsg_MpljcOG0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_02rWPxXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_JChYNr1m_sendMessage(_c, 0, m);
  cMsg_vDKLe9gi_sendMessage(_c, 0, m);
  cMsg_MpljcOG0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AJGjZYs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jkLRUNiR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LvNBPaSK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DFjok4Sf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jkLRUNiR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LvNBPaSK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uHg0thtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZiYTGIO3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cYIynyf8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U8I8VL7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZiYTGIO3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cYIynyf8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HZx3xooc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5WFyt5BU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LTruIDEa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tMrmtErY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5WFyt5BU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LTruIDEa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_14AD6ZXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_AJGjZYs3_sendMessage(_c, 0, m);
  cMsg_U8I8VL7J_sendMessage(_c, 0, m);
  cMsg_tMrmtErY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FDRyzKjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_DFjok4Sf_sendMessage(_c, 0, m);
  cMsg_uHg0thtI_sendMessage(_c, 0, m);
  cMsg_tMrmtErY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_apBJaWlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_DFjok4Sf_sendMessage(_c, 0, m);
  cMsg_U8I8VL7J_sendMessage(_c, 0, m);
  cMsg_HZx3xooc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BNxlEl3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zBuu2STI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nw90040W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mfyDW4NP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zBuu2STI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nw90040W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u1nBLIaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MqUGWqhQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nkGrNHu5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wo6eNVAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MqUGWqhQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nkGrNHu5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5kZJ4gkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WwNHO0Ki_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pr6Z9ymm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_evw3KPZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WwNHO0Ki_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pr6Z9ymm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JHDkZRNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_mfyDW4NP_sendMessage(_c, 0, m);
  cMsg_wo6eNVAY_sendMessage(_c, 0, m);
  cMsg_evw3KPZz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3asik3FK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_mfyDW4NP_sendMessage(_c, 0, m);
  cMsg_u1nBLIaO_sendMessage(_c, 0, m);
  cMsg_5kZJ4gkm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_w3B14KlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_BNxlEl3C_sendMessage(_c, 0, m);
  cMsg_u1nBLIaO_sendMessage(_c, 0, m);
  cMsg_evw3KPZz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1rMePRO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_JChYNr1m_sendMessage(_c, 0, m);
  cMsg_2xMfkm5X_sendMessage(_c, 0, m);
  cMsg_CygJoedL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9EYp3d4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_BNxlEl3C_sendMessage(_c, 0, m);
  cMsg_wo6eNVAY_sendMessage(_c, 0, m);
  cMsg_5kZJ4gkm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_z5fEe2R9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dm3TxfCg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Q0Tt9rA3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_u7zIVlk3, 0, m, &cSlice_u7zIVlk3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gZ1jiFHb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_u7zIVlk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OcLr2xpt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OcLr2xpt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Dikkjcdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OcLr2xpt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OcLr2xpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gX7wAPzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HR3khAhx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VswVlnM9, 0, m, &cSlice_VswVlnM9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oUA6Rl3G_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VswVlnM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uYpcAJuZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uYpcAJuZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_mQ38xka7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uYpcAJuZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_uYpcAJuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Qw1qHZQn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oUA6Rl3G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ni9st1ev, 0, m, &cSlice_Ni9st1ev_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Q0Tt9rA3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Ni9st1ev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EZwAvFcY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EZwAvFcY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JvN0zXQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EZwAvFcY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EZwAvFcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wRVNtgC2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gZ1jiFHb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KOrMJsr1, 0, m, &cSlice_KOrMJsr1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KyTp4kty_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_KOrMJsr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XzamYlpl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XzamYlpl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_1YOuRCXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XzamYlpl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XzamYlpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ghoyjacp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KyTp4kty_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XKmMsgiS, 0, m, &cSlice_XKmMsgiS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_h5wGKCoq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XKmMsgiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_H9E7VWL3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_H9E7VWL3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_WhH5TsVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_H9E7VWL3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_H9E7VWL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nL7S2XAw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9YhWYz5u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yTARHWtr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yTARHWtr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vaba5I1Z, 1, m, &cDelay_vaba5I1Z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qMkOO68g_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vaba5I1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vaba5I1Z, m);
  cMsg_LM9sdX5c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yTARHWtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vaba5I1Z, 0, m, &cDelay_vaba5I1Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qMkOO68g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vaba5I1Z, 0, m, &cDelay_vaba5I1Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_PcUeqdUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQ693Exc, HV_BINOP_SUBTRACT, 0, m, &cBinop_GQ693Exc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_MRQOYbW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tV9qaPWp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZFnBO7uI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tV9qaPWp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_KdHzar7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PcUeqdUK, 0, m, &cVar_PcUeqdUK_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_qCcdMQme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2CHD4kKA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0w5WnDoi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gKsrFPm3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GQ693Exc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fbN2ZjUU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fbN2ZjUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LabDzQT6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LabDzQT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_iY2qyxMr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KUcKya0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8LHW0nC4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1fU5CQ1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8LHW0nC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MRQOYbW2, 1, m, &cIf_MRQOYbW2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1fU5CQ1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GvFTnKBc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_daAvpIGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZFnBO7uI, 1, m, &cIf_ZFnBO7uI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GvFTnKBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_MRQOYbW2, 0, m, &cIf_MRQOYbW2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iY2qyxMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZFnBO7uI, 0, m, &cIf_ZFnBO7uI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2CHD4kKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_gKsrFPm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PcUeqdUK, 0, m, &cVar_PcUeqdUK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0w5WnDoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQ693Exc, HV_BINOP_SUBTRACT, 1, m, &cBinop_GQ693Exc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tV9qaPWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NSPyJCkB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_h5wGKCoq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CCtkWSFS, 0, m, &cSlice_CCtkWSFS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_CCtkWSFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jFhUVmZp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jFhUVmZp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_m06lpDR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jFhUVmZp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jFhUVmZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mtN2W62Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ywuT8jXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zY6ZiOVM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ntE8QpVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uj7PpiI3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_ZgE7Pj5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_k38NOFYJ, 0, m, &cVar_k38NOFYJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dm3TxfCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T9P7hUFj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vJEpihWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6JvRpUCn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_PlpksxeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9YhWYz5u_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LM9sdX5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TYl9Dpe7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6JvRpUCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TYl9Dpe7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Bhq4JJey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_TWehnDJr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TWehnDJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nf1Z0TLQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Nf1Z0TLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wReHpmYT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_m4gDjc8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f6fMqo6b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_alSEInAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wniIjMcq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_P368oZOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9rNZt3Ke_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_T6UNdd3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_onvR9vhZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_wpGeyKr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3BIjikH4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Lle4C5ci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sGzP6yc4_sendMessage);
  cMsg_sSZEtHCK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sGzP6yc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Lle4C5ci, 1, m, &cVar_Lle4C5ci_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_15P5JIds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DLtf7MOE_sendMessage(_c, 0, m);
  cMsg_yZmRnO9l_sendMessage(_c, 0, m);
  cMsg_Cd7k6Nfw_sendMessage(_c, 0, m);
  cMsg_4ly5pXnS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WGRixjFy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w8B6DEQu, 0, m, &cSlice_w8B6DEQu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_w8B6DEQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WI73mB8S_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WI73mB8S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lwnbz5JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WI73mB8S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WI73mB8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3mxBpF6Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wh0rgV2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_f5nl2WIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f5nl2WIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_oJUSgP1r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oJUSgP1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qs1rvZKI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qs1rvZKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_epS3mKvR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vtBQO4QN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_epS3mKvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vArXbpVO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vtBQO4QN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DQG25gPA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vArXbpVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cIrZL2QT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DQG25gPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5F7WbUVa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5F7WbUVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yAbjuDyj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cIrZL2QT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7uCgH424_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_yAbjuDyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AUc0sgcD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7uCgH424_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SaxTBT3T, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AUc0sgcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2TemKAgS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_yHInAj9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EuuYhvd9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_fBWkcMe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1TuU8E4W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0FMrVPC3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5SfDNKLN_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l83JVuca_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OG5kbPnN_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8NzumTtj_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9J0Tb8Um_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S9iTlHsb_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_5SfDNKLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xwWzdHSV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_l83JVuca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zGKuM32y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_OG5kbPnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SFjOpPET_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8NzumTtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MK6XIT6Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9J0Tb8Um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fZR62Tk2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_S9iTlHsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FfNWQuKb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_5fZVY6hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DesrV6kp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LjsLIaV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uCEsZQzX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ozwOJyvH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kmNQRMso_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kmNQRMso_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4yajsfe6, 1, m, &cDelay_4yajsfe6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ff6lUGvM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4yajsfe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4yajsfe6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5fZVY6hv, 0, m, &cIf_5fZVY6hv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kmNQRMso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4yajsfe6, 0, m, &cDelay_4yajsfe6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ff6lUGvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4yajsfe6, 0, m, &cDelay_4yajsfe6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ts2H4Hyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HIZDHlFl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NGVgodj6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z1UO2cYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FiabNxXJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_duw4i3FU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FiabNxXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5fZVY6hv, 1, m, &cIf_5fZVY6hv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_duw4i3FU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ozwOJyvH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HIZDHlFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LjsLIaV9, 1, m, &cIf_LjsLIaV9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NGVgodj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LjsLIaV9, 0, m, &cIf_LjsLIaV9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uCEsZQzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LcMIiAzn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DesrV6kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LcMIiAzn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tDRqM5W3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZvvBRqta_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8vifUm9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4kEyxfU0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RbtkkBhY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xAtO4kJL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xAtO4kJL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AKWom8Gz, 1, m, &cDelay_AKWom8Gz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ECnLrp7s_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AKWom8Gz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AKWom8Gz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tDRqM5W3, 0, m, &cIf_tDRqM5W3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xAtO4kJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AKWom8Gz, 0, m, &cDelay_AKWom8Gz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ECnLrp7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AKWom8Gz, 0, m, &cDelay_AKWom8Gz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_67RH1EmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zgNdoTcB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4G8BSXo7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JFlma58W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ocB4iPRX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DcOcB5kT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DcOcB5kT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RbtkkBhY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ocB4iPRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tDRqM5W3, 1, m, &cIf_tDRqM5W3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zgNdoTcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8vifUm9m, 1, m, &cIf_8vifUm9m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4G8BSXo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8vifUm9m, 0, m, &cIf_8vifUm9m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4kEyxfU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gkChQB5s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZvvBRqta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gkChQB5s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5Uuku2cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_77h2Xxmb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XiDb33OO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cERJJmmZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Sj57aEhW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dNIMOZnB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dNIMOZnB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CMODb7c4, 1, m, &cDelay_CMODb7c4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YwNgoPUB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CMODb7c4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CMODb7c4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5Uuku2cu, 0, m, &cIf_5Uuku2cu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dNIMOZnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CMODb7c4, 0, m, &cDelay_CMODb7c4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YwNgoPUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CMODb7c4, 0, m, &cDelay_CMODb7c4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ncQV5azA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iWhP1nfl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iNfTLAJc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A2qw2gEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ak1sPLsY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_808EpBd2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_808EpBd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Sj57aEhW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ak1sPLsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5Uuku2cu, 1, m, &cIf_5Uuku2cu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iNfTLAJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XiDb33OO, 0, m, &cIf_XiDb33OO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iWhP1nfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XiDb33OO, 1, m, &cIf_XiDb33OO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cERJJmmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GasgLAlY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_77h2Xxmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GasgLAlY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2fT1JyyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tlTPqEuj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zaFdn6Hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jDUWTsSp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MgE8ypFn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_g4IzHbM5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_g4IzHbM5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yJVUuHBA, 1, m, &cDelay_yJVUuHBA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y263tBgO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yJVUuHBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yJVUuHBA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2fT1JyyR, 0, m, &cIf_2fT1JyyR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g4IzHbM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yJVUuHBA, 0, m, &cDelay_yJVUuHBA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y263tBgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yJVUuHBA, 0, m, &cDelay_yJVUuHBA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LcgFe7hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3RPqenzA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2DbT9Pnu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5eLoCYWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wEnO3Oom_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_msD4HobZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_msD4HobZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MgE8ypFn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_wEnO3Oom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2fT1JyyR, 1, m, &cIf_2fT1JyyR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2DbT9Pnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zaFdn6Hx, 0, m, &cIf_zaFdn6Hx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3RPqenzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zaFdn6Hx, 1, m, &cIf_zaFdn6Hx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jDUWTsSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mSBYEmw3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tlTPqEuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mSBYEmw3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jn3UsDR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UP9s4uxm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zzUXBITP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_clbHt8gO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tY0pvaUp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HAF1V4YH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HAF1V4YH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_drdeuEWE, 1, m, &cDelay_drdeuEWE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0G0HHBkp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_drdeuEWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_drdeuEWE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jn3UsDR6, 0, m, &cIf_jn3UsDR6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HAF1V4YH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_drdeuEWE, 0, m, &cDelay_drdeuEWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0G0HHBkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_drdeuEWE, 0, m, &cDelay_drdeuEWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LTiEipwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kMKhz4AJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d9Qi70W7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EXa99nga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nrAApWtD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VNA84oyR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VNA84oyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tY0pvaUp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nrAApWtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jn3UsDR6, 1, m, &cIf_jn3UsDR6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d9Qi70W7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zzUXBITP, 0, m, &cIf_zzUXBITP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kMKhz4AJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zzUXBITP, 1, m, &cIf_zzUXBITP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_clbHt8gO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0TgqFOs3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UP9s4uxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0TgqFOs3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jsFYIAFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LVlH0whV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BR852D4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_frWJaYtz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8rfFbhiw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7FtH78py_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7FtH78py_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_adT77Y8G, 1, m, &cDelay_adT77Y8G_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0GWhGii8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_adT77Y8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_adT77Y8G, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jsFYIAFA, 0, m, &cIf_jsFYIAFA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7FtH78py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_adT77Y8G, 0, m, &cDelay_adT77Y8G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0GWhGii8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_adT77Y8G, 0, m, &cDelay_adT77Y8G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wKxm1TUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5V0qHjui_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dA8reKEU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Hrzh0C1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mkSNM31I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7S5j3ZA5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7S5j3ZA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8rfFbhiw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mkSNM31I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jsFYIAFA, 1, m, &cIf_jsFYIAFA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5V0qHjui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BR852D4E, 1, m, &cIf_BR852D4E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dA8reKEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BR852D4E, 0, m, &cIf_BR852D4E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_frWJaYtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tSuCCcSw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LVlH0whV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tSuCCcSw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VoUsQXUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7HHBDJkR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mhhw3Of0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_R03DTq7Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nIeu61Om_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YLyhj0ef_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YLyhj0ef_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NOrmrMSH, 1, m, &cDelay_NOrmrMSH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_salXo8kE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NOrmrMSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NOrmrMSH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VoUsQXUT, 0, m, &cIf_VoUsQXUT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YLyhj0ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NOrmrMSH, 0, m, &cDelay_NOrmrMSH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_salXo8kE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NOrmrMSH, 0, m, &cDelay_NOrmrMSH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3CT9HPPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4jVgYvye_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KeoR8UbL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vbzzhMdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7FyO1kCN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KC2t9E5o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KC2t9E5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nIeu61Om_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7FyO1kCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VoUsQXUT, 1, m, &cIf_VoUsQXUT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KeoR8UbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mhhw3Of0, 0, m, &cIf_mhhw3Of0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4jVgYvye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mhhw3Of0, 1, m, &cIf_mhhw3Of0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R03DTq7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RtmdM5Nc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7HHBDJkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RtmdM5Nc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_V33Qd6HQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fjt1ELZV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3r4Tsk7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dke6YyLu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dIsOctcI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_o9aA61ke_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_o9aA61ke_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ttB9oDmr, 1, m, &cDelay_ttB9oDmr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YKB2OD1V_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ttB9oDmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ttB9oDmr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_V33Qd6HQ, 0, m, &cIf_V33Qd6HQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o9aA61ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ttB9oDmr, 0, m, &cDelay_ttB9oDmr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YKB2OD1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ttB9oDmr, 0, m, &cDelay_ttB9oDmr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gMZWDa7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PGtFemyH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FJ1QuncK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LDLSgo1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8E0AM4bN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WQblt7HZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WQblt7HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dIsOctcI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8E0AM4bN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V33Qd6HQ, 1, m, &cIf_V33Qd6HQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FJ1QuncK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3r4Tsk7x, 0, m, &cIf_3r4Tsk7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PGtFemyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3r4Tsk7x, 1, m, &cIf_3r4Tsk7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dke6YyLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JtpNIZUT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fjt1ELZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JtpNIZUT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mLVmk7gR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Cuf4afRE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ej1fZBxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QhljR2OX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AEAShexD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eYnKEm4C_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eYnKEm4C_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yVtvpAen, 1, m, &cDelay_yVtvpAen_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GIOVajSO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yVtvpAen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yVtvpAen, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mLVmk7gR, 0, m, &cIf_mLVmk7gR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eYnKEm4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yVtvpAen, 0, m, &cDelay_yVtvpAen_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GIOVajSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yVtvpAen, 0, m, &cDelay_yVtvpAen_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8NziZXAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pP9GAXIV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rokCfm0i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_owdKQAwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WrQVlhEW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XNGb47JA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XNGb47JA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AEAShexD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WrQVlhEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mLVmk7gR, 1, m, &cIf_mLVmk7gR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rokCfm0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ej1fZBxi, 0, m, &cIf_ej1fZBxi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pP9GAXIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ej1fZBxi, 1, m, &cIf_ej1fZBxi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QhljR2OX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zZZ6kyv9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Cuf4afRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zZZ6kyv9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CChWVnLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NNFmNjob_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_POdpPOcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KqUlc7tQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AodGnvae_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aAUvkBYA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aAUvkBYA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bbrOJP5T, 1, m, &cDelay_bbrOJP5T_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_58JiuhcZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bbrOJP5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bbrOJP5T, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CChWVnLb, 0, m, &cIf_CChWVnLb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aAUvkBYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bbrOJP5T, 0, m, &cDelay_bbrOJP5T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_58JiuhcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bbrOJP5T, 0, m, &cDelay_bbrOJP5T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vGPXBamw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SaDlVtOL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w6AEGW7L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9CHBhA1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iPR0cQA1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tqjkJ2of_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tqjkJ2of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AodGnvae_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_iPR0cQA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CChWVnLb, 1, m, &cIf_CChWVnLb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w6AEGW7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_POdpPOcx, 0, m, &cIf_POdpPOcx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SaDlVtOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_POdpPOcx, 1, m, &cIf_POdpPOcx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KqUlc7tQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Cts52OSJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NNFmNjob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Cts52OSJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2sModqoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_24HYMMee_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JXGIlN3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AGoMTgbi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wXFYCAk8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BGvupASQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BGvupASQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_voeEgMax, 1, m, &cDelay_voeEgMax_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_trLYFsex_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_voeEgMax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_voeEgMax, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2sModqoS, 0, m, &cIf_2sModqoS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BGvupASQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_voeEgMax, 0, m, &cDelay_voeEgMax_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_trLYFsex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_voeEgMax, 0, m, &cDelay_voeEgMax_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sEDn8uTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gLWRgy7G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xfRTCASm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZAMg1GbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g6OGCOoF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dCG2sCON_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g6OGCOoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2sModqoS, 1, m, &cIf_2sModqoS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dCG2sCON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wXFYCAk8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xfRTCASm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JXGIlN3j, 0, m, &cIf_JXGIlN3j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gLWRgy7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JXGIlN3j, 1, m, &cIf_JXGIlN3j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AGoMTgbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HePc5V1s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_24HYMMee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HePc5V1s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_J3dORVXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qeEVpq98_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_iRhUAFvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cgpYYyqM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Cq3uuXqX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ByVGcY60_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ByVGcY60_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QIgOuYTj, 1, m, &cDelay_QIgOuYTj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_83Vjxj7S_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_QIgOuYTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QIgOuYTj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_J3dORVXs, 0, m, &cIf_J3dORVXs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ByVGcY60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QIgOuYTj, 0, m, &cDelay_QIgOuYTj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_83Vjxj7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QIgOuYTj, 0, m, &cDelay_QIgOuYTj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XuC7fu0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ig3S9nw1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8TrejMNu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zMurN3YL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HzwmEKVS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PD5uessl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HzwmEKVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J3dORVXs, 1, m, &cIf_J3dORVXs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PD5uessl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Cq3uuXqX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Ig3S9nw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iRhUAFvi, 1, m, &cIf_iRhUAFvi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8TrejMNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iRhUAFvi, 0, m, &cIf_iRhUAFvi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cgpYYyqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HBpd95Qe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qeEVpq98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HBpd95Qe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xwWzdHSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_QR4coFlC_sendMessage(_c, 0, m);
  cMsg_0oMMgbOe_sendMessage(_c, 0, m);
  cMsg_oW1eI1lr_sendMessage(_c, 0, m);
  cMsg_J1k7OfDn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zGKuM32y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_QR4coFlC_sendMessage(_c, 0, m);
  cMsg_6xwQp3mk_sendMessage(_c, 0, m);
  cMsg_x1iLnGxy_sendMessage(_c, 0, m);
  cMsg_BKtHVTpB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SFjOpPET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_2HIOnnOC_sendMessage(_c, 0, m);
  cMsg_6xwQp3mk_sendMessage(_c, 0, m);
  cMsg_J1k7OfDn_sendMessage(_c, 0, m);
  cMsg_Rcll4JMc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MK6XIT6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_2HIOnnOC_sendMessage(_c, 0, m);
  cMsg_2MulB5ZJ_sendMessage(_c, 0, m);
  cMsg_oW1eI1lr_sendMessage(_c, 0, m);
  cMsg_s4ikjPGL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fZR62Tk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_8EQvwjBx_sendMessage(_c, 0, m);
  cMsg_BKtHVTpB_sendMessage(_c, 0, m);
  cMsg_N08Dn6gS_sendMessage(_c, 0, m);
  cMsg_oW1eI1lr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FfNWQuKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_8EQvwjBx_sendMessage(_c, 0, m);
  cMsg_s4ikjPGL_sendMessage(_c, 0, m);
  cMsg_6xwQp3mk_sendMessage(_c, 0, m);
  cMsg_oyDJ4Z9O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_e6dFqkCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Z1UO2cYG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ts2H4Hyp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dFBMaLbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Z1UO2cYG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ts2H4Hyp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_At1j0Mc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JFlma58W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_67RH1EmJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jJFL40qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JFlma58W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_67RH1EmJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AP6HlmP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_A2qw2gEp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ncQV5azA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p5BjoBWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_A2qw2gEp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ncQV5azA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QR4coFlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_e6dFqkCb_sendMessage(_c, 0, m);
  cMsg_jJFL40qa_sendMessage(_c, 0, m);
  cMsg_p5BjoBWm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2HIOnnOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_dFBMaLbK_sendMessage(_c, 0, m);
  cMsg_At1j0Mc1_sendMessage(_c, 0, m);
  cMsg_p5BjoBWm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8EQvwjBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_dFBMaLbK_sendMessage(_c, 0, m);
  cMsg_jJFL40qa_sendMessage(_c, 0, m);
  cMsg_AP6HlmP4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lT3QV0Hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5eLoCYWS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LcgFe7hb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iGpK6aBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5eLoCYWS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LcgFe7hb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4sTs1Ojp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EXa99nga_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LTiEipwA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5lh1GSRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EXa99nga_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LTiEipwA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R5qIwyrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Hrzh0C1S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wKxm1TUB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FrfrTwFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Hrzh0C1S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wKxm1TUB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6xwQp3mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_iGpK6aBd_sendMessage(_c, 0, m);
  cMsg_5lh1GSRw_sendMessage(_c, 0, m);
  cMsg_FrfrTwFC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0oMMgbOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_iGpK6aBd_sendMessage(_c, 0, m);
  cMsg_4sTs1Ojp_sendMessage(_c, 0, m);
  cMsg_R5qIwyrS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2MulB5ZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_lT3QV0Hv_sendMessage(_c, 0, m);
  cMsg_5lh1GSRw_sendMessage(_c, 0, m);
  cMsg_R5qIwyrS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JSClEaqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9CHBhA1q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vGPXBamw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kz5CgnaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9CHBhA1q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vGPXBamw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p1kyLzpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZAMg1GbI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sEDn8uTy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cZlAq5Wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZAMg1GbI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sEDn8uTy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wf7h3Rbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zMurN3YL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XuC7fu0O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_99kANu7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zMurN3YL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XuC7fu0O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_s4ikjPGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_JSClEaqN_sendMessage(_c, 0, m);
  cMsg_cZlAq5Wj_sendMessage(_c, 0, m);
  cMsg_99kANu7x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BKtHVTpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_kz5CgnaU_sendMessage(_c, 0, m);
  cMsg_p1kyLzpR_sendMessage(_c, 0, m);
  cMsg_99kANu7x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_J1k7OfDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_kz5CgnaU_sendMessage(_c, 0, m);
  cMsg_cZlAq5Wj_sendMessage(_c, 0, m);
  cMsg_Wf7h3Rbi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1FbXwOrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vbzzhMdH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3CT9HPPP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uXCGGkPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vbzzhMdH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3CT9HPPP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6KW6lwS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LDLSgo1V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gMZWDa7U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AJkmyR8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LDLSgo1V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gMZWDa7U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E20tvgdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_owdKQAwk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8NziZXAm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZYaOxEwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_owdKQAwk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8NziZXAm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oW1eI1lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_uXCGGkPj_sendMessage(_c, 0, m);
  cMsg_AJkmyR8U_sendMessage(_c, 0, m);
  cMsg_ZYaOxEwJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_x1iLnGxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_uXCGGkPj_sendMessage(_c, 0, m);
  cMsg_6KW6lwS2_sendMessage(_c, 0, m);
  cMsg_E20tvgdC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oyDJ4Z9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_1FbXwOrM_sendMessage(_c, 0, m);
  cMsg_6KW6lwS2_sendMessage(_c, 0, m);
  cMsg_ZYaOxEwJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_N08Dn6gS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_lT3QV0Hv_sendMessage(_c, 0, m);
  cMsg_4sTs1Ojp_sendMessage(_c, 0, m);
  cMsg_FrfrTwFC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Rcll4JMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_1FbXwOrM_sendMessage(_c, 0, m);
  cMsg_AJkmyR8U_sendMessage(_c, 0, m);
  cMsg_E20tvgdC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_aMCmrFPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MEFzSCIa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nwhsPLXz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Wb5yDn5h, 0, m, &cSlice_Wb5yDn5h_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eRQwOkaZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Wb5yDn5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_stIir97R_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_stIir97R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_OOmte1Sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_stIir97R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_stIir97R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yiXZeg8X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7LqmnDrm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4ejBVgnq, 0, m, &cSlice_4ejBVgnq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LBLHOGFK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_4ejBVgnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JtvCkuQq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JtvCkuQq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_mVNpyCh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JtvCkuQq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JtvCkuQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4CWd0u4e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LBLHOGFK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9e3aEqEE, 0, m, &cSlice_9e3aEqEE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nwhsPLXz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9e3aEqEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kFqPc9ot_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kFqPc9ot_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_wObed07w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kFqPc9ot_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_kFqPc9ot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GlexAEpq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eRQwOkaZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_a0Lnur2S, 0, m, &cSlice_a0Lnur2S_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Jtd0kJHQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_a0Lnur2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4H3my53v_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4H3my53v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Y4SzEYpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4H3my53v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_4H3my53v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CQ16QyOB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Jtd0kJHQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BsZgCCC3, 0, m, &cSlice_BsZgCCC3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MM74BZ5u_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BsZgCCC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2zY0k5ix_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2zY0k5ix_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MIMCZvOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2zY0k5ix_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_2zY0k5ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1WQI9Xwr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xlPaXgRs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GgnElpAC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GgnElpAC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p4X2hcK2, 1, m, &cDelay_p4X2hcK2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8cxMSP5B_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_p4X2hcK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p4X2hcK2, m);
  cMsg_MidGf7Rz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GgnElpAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p4X2hcK2, 0, m, &cDelay_p4X2hcK2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8cxMSP5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p4X2hcK2, 0, m, &cDelay_p4X2hcK2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Fobv1t6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5tD2wr7x, HV_BINOP_SUBTRACT, 0, m, &cBinop_5tD2wr7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_TMYSro8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QE2b76rK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QKESGZe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QE2b76rK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_vI5Kdkjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fobv1t6w, 0, m, &cVar_Fobv1t6w_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_g9hXzi6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l7WlcWo8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BM1OMdau_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HEq1qAuA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5tD2wr7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OnyoARhA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OnyoARhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tRjqTCi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tRjqTCi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_L2C9Dh86_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OgZx4r6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q5oo6r2Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NzYzFHcr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NzYzFHcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bYC5rELS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Q5oo6r2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TMYSro8g, 1, m, &cIf_TMYSro8g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rIo2tUqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QKESGZe6, 1, m, &cIf_QKESGZe6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bYC5rELS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_TMYSro8g, 0, m, &cIf_TMYSro8g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L2C9Dh86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QKESGZe6, 0, m, &cIf_QKESGZe6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HEq1qAuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fobv1t6w, 0, m, &cVar_Fobv1t6w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BM1OMdau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5tD2wr7x, HV_BINOP_SUBTRACT, 1, m, &cBinop_5tD2wr7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l7WlcWo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_QE2b76rK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kgxVtBhb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MM74BZ5u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wi9FFQj1, 0, m, &cSlice_wi9FFQj1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_wi9FFQj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yG3v7gAf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yG3v7gAf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Iv55f3Um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yG3v7gAf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yG3v7gAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lg40LJZ9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EuuYhvd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_91ad99HK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1TuU8E4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7wvrV4WA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_2FyZCgHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fBWkcMe0, 0, m, &cVar_fBWkcMe0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MEFzSCIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R72tx8r2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_IJ60CLtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kSLL6q82_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_UlO96Yec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xlPaXgRs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MidGf7Rz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v5azaCYI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kSLL6q82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v5azaCYI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_h8vKlTgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_r88nfSP3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r88nfSP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KZHd8m7h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KZHd8m7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EpAbRijP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_nOKFV5rW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SsQ9x4gG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_YznWcLwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3l8XUdTB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cIqDsKRF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8YL0TEKk_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cSc6K1dj_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZDdWn2I1_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aRy8A0xG_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kErSSmOF_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I3wj8oxd_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_8YL0TEKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F2rP4VWC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cSc6K1dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eNUMzeUr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZDdWn2I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TsN4BZAR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_aRy8A0xG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lkZlAnqe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_kErSSmOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gylKvHW2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_I3wj8oxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JlbvPtCI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_AllYOIbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HsxDR8GK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YYRowGRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_k02jm5fX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Vuy81GC6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dkpwsjs2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dkpwsjs2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jOOl8c7M, 1, m, &cDelay_jOOl8c7M_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bd4Q9Lsp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jOOl8c7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jOOl8c7M, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AllYOIbi, 0, m, &cIf_AllYOIbi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dkpwsjs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jOOl8c7M, 0, m, &cDelay_jOOl8c7M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bd4Q9Lsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jOOl8c7M, 0, m, &cDelay_jOOl8c7M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kYkhzePZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KqG2piQM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_50asA9NU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dcGGJURq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0lYPsfUp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sXpQfWUP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0lYPsfUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AllYOIbi, 1, m, &cIf_AllYOIbi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sXpQfWUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Vuy81GC6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_50asA9NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YYRowGRG, 0, m, &cIf_YYRowGRG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KqG2piQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YYRowGRG, 1, m, &cIf_YYRowGRG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k02jm5fX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mGQpREuF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HsxDR8GK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mGQpREuF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2PkCx5nA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RHCGDaUb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ge0cK5p2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cXhYtlnR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MXA0YjIM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jjtoqOmK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jjtoqOmK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sem9tAPi, 1, m, &cDelay_sem9tAPi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kjmN9zNf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sem9tAPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sem9tAPi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2PkCx5nA, 0, m, &cIf_2PkCx5nA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jjtoqOmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sem9tAPi, 0, m, &cDelay_sem9tAPi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kjmN9zNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sem9tAPi, 0, m, &cDelay_sem9tAPi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EzakkrOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W2BlmCJo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgavuvGk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r6bJ9ORH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5YVyj4KZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1z1K0fWe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5YVyj4KZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2PkCx5nA, 1, m, &cIf_2PkCx5nA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1z1K0fWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MXA0YjIM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_W2BlmCJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ge0cK5p2, 1, m, &cIf_ge0cK5p2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JgavuvGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ge0cK5p2, 0, m, &cIf_ge0cK5p2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cXhYtlnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ALuGIWKi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RHCGDaUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ALuGIWKi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_TMcZYvIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HniMmqDc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7v8u0Gz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZVj8Jc6V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WkP5t4wO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qp3EPJGK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qp3EPJGK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pt7Tq91P, 1, m, &cDelay_pt7Tq91P_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2V1HPWpO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_pt7Tq91P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pt7Tq91P, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TMcZYvIc, 0, m, &cIf_TMcZYvIc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qp3EPJGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pt7Tq91P, 0, m, &cDelay_pt7Tq91P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2V1HPWpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pt7Tq91P, 0, m, &cDelay_pt7Tq91P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XV4PdvBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YyVzPNiH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9uFvShxj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NcTQObbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s52Xa6zy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FQaBsA5x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s52Xa6zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TMcZYvIc, 1, m, &cIf_TMcZYvIc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FQaBsA5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WkP5t4wO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YyVzPNiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7v8u0Gz9, 1, m, &cIf_7v8u0Gz9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9uFvShxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7v8u0Gz9, 0, m, &cIf_7v8u0Gz9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZVj8Jc6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W25dSaM3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HniMmqDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W25dSaM3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5a0xqCbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QuC3hT93_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KUnllLfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_A0bYhB7J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RYxvYDuW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_o1U0jAM7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_o1U0jAM7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qiPxVNP9, 1, m, &cDelay_qiPxVNP9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ea4D8rXA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qiPxVNP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qiPxVNP9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5a0xqCbe, 0, m, &cIf_5a0xqCbe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o1U0jAM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qiPxVNP9, 0, m, &cDelay_qiPxVNP9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ea4D8rXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qiPxVNP9, 0, m, &cDelay_qiPxVNP9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E9ZSxLNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x43y03L9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D5Ak5PyR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_euRO1Hsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yKJKe0ze_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vILJDNXg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vILJDNXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RYxvYDuW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yKJKe0ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5a0xqCbe, 1, m, &cIf_5a0xqCbe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D5Ak5PyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KUnllLfX, 0, m, &cIf_KUnllLfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x43y03L9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KUnllLfX, 1, m, &cIf_KUnllLfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A0bYhB7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9z91Rey4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QuC3hT93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9z91Rey4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_hoHL3BK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4frWIcFf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_cBMz84B4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cvqMi3bA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GnrcxSaW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IlP1zyrs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IlP1zyrs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_P6bHZ0aU, 1, m, &cDelay_P6bHZ0aU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dSbcBIGl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_P6bHZ0aU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_P6bHZ0aU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_hoHL3BK9, 0, m, &cIf_hoHL3BK9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IlP1zyrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_P6bHZ0aU, 0, m, &cDelay_P6bHZ0aU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dSbcBIGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P6bHZ0aU, 0, m, &cDelay_P6bHZ0aU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XBLoASnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EHgLM1rx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ktj3jm9b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HOrcD8nO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8PgoJnor_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F9uoRksj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8PgoJnor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hoHL3BK9, 1, m, &cIf_hoHL3BK9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F9uoRksj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GnrcxSaW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ktj3jm9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cBMz84B4, 0, m, &cIf_cBMz84B4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EHgLM1rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cBMz84B4, 1, m, &cIf_cBMz84B4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cvqMi3bA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pVQfqxPH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4frWIcFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pVQfqxPH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_g3x3jvqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ySphBdbE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rqjRr7Ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_D4z3zGtA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ijB77bmG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_u1EGYXaJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_u1EGYXaJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VOFX6W3G, 1, m, &cDelay_VOFX6W3G_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IT8lX8fg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_VOFX6W3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VOFX6W3G, m);
  cIf_onMessage(_c, &Context(_c)->cIf_g3x3jvqv, 0, m, &cIf_g3x3jvqv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u1EGYXaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VOFX6W3G, 0, m, &cDelay_VOFX6W3G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IT8lX8fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VOFX6W3G, 0, m, &cDelay_VOFX6W3G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GtGvphIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HBoTEcKL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bypvdRgq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x2EWKYB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i9CMCAMx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x2BiKgXA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i9CMCAMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g3x3jvqv, 1, m, &cIf_g3x3jvqv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x2BiKgXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ijB77bmG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HBoTEcKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rqjRr7Ea, 1, m, &cIf_rqjRr7Ea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bypvdRgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rqjRr7Ea, 0, m, &cIf_rqjRr7Ea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_D4z3zGtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wnx5bKwX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ySphBdbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wnx5bKwX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Wx7aqvjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8R7SwFj8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jp3ORsjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_z8pzaI5O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uVC0s3Vf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tmoytawi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tmoytawi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VyyqS9Ey, 1, m, &cDelay_VyyqS9Ey_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qUyI2pr0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_VyyqS9Ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VyyqS9Ey, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Wx7aqvjD, 0, m, &cIf_Wx7aqvjD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tmoytawi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VyyqS9Ey, 0, m, &cDelay_VyyqS9Ey_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qUyI2pr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VyyqS9Ey, 0, m, &cDelay_VyyqS9Ey_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8b3uEHsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TR7bN2Um_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a1cnnhQQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3Ovxp6aF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c0REwqSp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jljyn5UZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c0REwqSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wx7aqvjD, 1, m, &cIf_Wx7aqvjD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jljyn5UZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uVC0s3Vf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TR7bN2Um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jp3ORsjP, 1, m, &cIf_jp3ORsjP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a1cnnhQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jp3ORsjP, 0, m, &cIf_jp3ORsjP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z8pzaI5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0wIJyN0t, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8R7SwFj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0wIJyN0t, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6cyd9Nuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EuAyYybL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KyohM2bQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Y7WuGzxt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PSNCLeI9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_z4lAsEng_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_z4lAsEng_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Lg3KZr2w, 1, m, &cDelay_Lg3KZr2w_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xn2dmrPW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Lg3KZr2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Lg3KZr2w, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6cyd9Nuy, 0, m, &cIf_6cyd9Nuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z4lAsEng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Lg3KZr2w, 0, m, &cDelay_Lg3KZr2w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xn2dmrPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Lg3KZr2w, 0, m, &cDelay_Lg3KZr2w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_phBnxv7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eLTVBVR3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MYEGclTw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qFXSGrHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0LHbLCAF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ZABqItp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0ZABqItp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PSNCLeI9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0LHbLCAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6cyd9Nuy, 1, m, &cIf_6cyd9Nuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eLTVBVR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KyohM2bQ, 1, m, &cIf_KyohM2bQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MYEGclTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KyohM2bQ, 0, m, &cIf_KyohM2bQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y7WuGzxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fXneVWm5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EuAyYybL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fXneVWm5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BwAXWfXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ROvf0U2b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9tcANQ8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NqOfsG2A_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RXSdlGNM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DF9YFIaP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DF9YFIaP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cxnJlgfy, 1, m, &cDelay_cxnJlgfy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sDQ9fWoL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cxnJlgfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cxnJlgfy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BwAXWfXb, 0, m, &cIf_BwAXWfXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DF9YFIaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cxnJlgfy, 0, m, &cDelay_cxnJlgfy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sDQ9fWoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cxnJlgfy, 0, m, &cDelay_cxnJlgfy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GSqccLWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pwoRQIEs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rCjg042k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HGZU82OY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hYikbSMs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ILYoDvzz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ILYoDvzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RXSdlGNM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hYikbSMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BwAXWfXb, 1, m, &cIf_BwAXWfXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rCjg042k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9tcANQ8V, 0, m, &cIf_9tcANQ8V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pwoRQIEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9tcANQ8V, 1, m, &cIf_9tcANQ8V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NqOfsG2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dAwdQ3yN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ROvf0U2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dAwdQ3yN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_np9ODuXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DFBmeVbL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QoH1w0mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EOhlOzoq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vjowgOAS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cweWlsrG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cweWlsrG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FdW48FWz, 1, m, &cDelay_FdW48FWz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jrYzVzK5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FdW48FWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FdW48FWz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_np9ODuXe, 0, m, &cIf_np9ODuXe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cweWlsrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FdW48FWz, 0, m, &cDelay_FdW48FWz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jrYzVzK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FdW48FWz, 0, m, &cDelay_FdW48FWz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2fqhGXFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s4s5NqAA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cILgWzyc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5XVxCHh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t4Cy3ZVf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8J7Dll8D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8J7Dll8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vjowgOAS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_t4Cy3ZVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_np9ODuXe, 1, m, &cIf_np9ODuXe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cILgWzyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QoH1w0mx, 0, m, &cIf_QoH1w0mx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s4s5NqAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QoH1w0mx, 1, m, &cIf_QoH1w0mx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EOhlOzoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SFJfChUo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DFBmeVbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SFJfChUo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_zLfn8f0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_V7SJPTqh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2VBdsOvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i06se2yO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ojqplvrJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PCsHgwd5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PCsHgwd5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1N14Ddav, 1, m, &cDelay_1N14Ddav_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZdjjRlxA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1N14Ddav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1N14Ddav, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zLfn8f0W, 0, m, &cIf_zLfn8f0W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PCsHgwd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1N14Ddav, 0, m, &cDelay_1N14Ddav_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZdjjRlxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1N14Ddav, 0, m, &cDelay_1N14Ddav_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iuHbPuEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ozgFpe9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4fIfdUwC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OrvTJYnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RSw4flAB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nqfvs5L1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RSw4flAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zLfn8f0W, 1, m, &cIf_zLfn8f0W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nqfvs5L1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ojqplvrJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4ozgFpe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2VBdsOvk, 1, m, &cIf_2VBdsOvk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4fIfdUwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2VBdsOvk, 0, m, &cIf_2VBdsOvk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i06se2yO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9yGVvmAa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_V7SJPTqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9yGVvmAa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ERj0MIQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Cl2jSUMa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fshJE2Bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0HHLMRL0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Iq3Wegby_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0fZtsesH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0fZtsesH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0RIvZI8E, 1, m, &cDelay_0RIvZI8E_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wz9gZ5yL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0RIvZI8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0RIvZI8E, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ERj0MIQA, 0, m, &cIf_ERj0MIQA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0fZtsesH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0RIvZI8E, 0, m, &cDelay_0RIvZI8E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wz9gZ5yL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0RIvZI8E, 0, m, &cDelay_0RIvZI8E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xjPcxnVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gX1iIf7z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IyQrNAO4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XYzEhNq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q3Bd5frq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dHjoui6D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dHjoui6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Iq3Wegby_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Q3Bd5frq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ERj0MIQA, 1, m, &cIf_ERj0MIQA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gX1iIf7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fshJE2Bf, 1, m, &cIf_fshJE2Bf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IyQrNAO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fshJE2Bf, 0, m, &cIf_fshJE2Bf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0HHLMRL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cRrwW713, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Cl2jSUMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cRrwW713, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_F2rP4VWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_vBKXYwfJ_sendMessage(_c, 0, m);
  cMsg_xUcSfe8x_sendMessage(_c, 0, m);
  cMsg_jIfuOFej_sendMessage(_c, 0, m);
  cMsg_64znn4tA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eNUMzeUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_vBKXYwfJ_sendMessage(_c, 0, m);
  cMsg_Uy0aHvUA_sendMessage(_c, 0, m);
  cMsg_xIS2bDDh_sendMessage(_c, 0, m);
  cMsg_las8NcEo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TsN4BZAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_6HEpxVpe_sendMessage(_c, 0, m);
  cMsg_Uy0aHvUA_sendMessage(_c, 0, m);
  cMsg_64znn4tA_sendMessage(_c, 0, m);
  cMsg_LOjfC5rx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lkZlAnqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_6HEpxVpe_sendMessage(_c, 0, m);
  cMsg_jKDpl1c2_sendMessage(_c, 0, m);
  cMsg_jIfuOFej_sendMessage(_c, 0, m);
  cMsg_F2idz7Cx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gylKvHW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_nQqHHQYV_sendMessage(_c, 0, m);
  cMsg_las8NcEo_sendMessage(_c, 0, m);
  cMsg_8zwiL2fP_sendMessage(_c, 0, m);
  cMsg_jIfuOFej_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JlbvPtCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_nQqHHQYV_sendMessage(_c, 0, m);
  cMsg_F2idz7Cx_sendMessage(_c, 0, m);
  cMsg_Uy0aHvUA_sendMessage(_c, 0, m);
  cMsg_0DNjgivo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YodT59Fv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dcGGJURq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kYkhzePZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PsEKTzUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dcGGJURq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kYkhzePZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H7lxE7Kr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_r6bJ9ORH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EzakkrOF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qX6Fvhwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_r6bJ9ORH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EzakkrOF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WqKEjzW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NcTQObbG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XV4PdvBU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zbLtuSHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NcTQObbG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XV4PdvBU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vBKXYwfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_YodT59Fv_sendMessage(_c, 0, m);
  cMsg_qX6Fvhwl_sendMessage(_c, 0, m);
  cMsg_zbLtuSHV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6HEpxVpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_PsEKTzUo_sendMessage(_c, 0, m);
  cMsg_H7lxE7Kr_sendMessage(_c, 0, m);
  cMsg_zbLtuSHV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nQqHHQYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_PsEKTzUo_sendMessage(_c, 0, m);
  cMsg_qX6Fvhwl_sendMessage(_c, 0, m);
  cMsg_WqKEjzW0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cmTxJrWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_euRO1Hsa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E9ZSxLNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zFMJvTaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_euRO1Hsa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E9ZSxLNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LaieHL0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HOrcD8nO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XBLoASnS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EUGEwSbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HOrcD8nO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XBLoASnS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Spiyhh7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_x2EWKYB8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GtGvphIJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k5NFJbE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_x2EWKYB8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GtGvphIJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Uy0aHvUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_zFMJvTaI_sendMessage(_c, 0, m);
  cMsg_EUGEwSbz_sendMessage(_c, 0, m);
  cMsg_k5NFJbE5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xUcSfe8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_zFMJvTaI_sendMessage(_c, 0, m);
  cMsg_LaieHL0L_sendMessage(_c, 0, m);
  cMsg_Spiyhh7Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jKDpl1c2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_cmTxJrWV_sendMessage(_c, 0, m);
  cMsg_EUGEwSbz_sendMessage(_c, 0, m);
  cMsg_Spiyhh7Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_s517wshG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5XVxCHh9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2fqhGXFA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nzijLMl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5XVxCHh9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2fqhGXFA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GRDjTKaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OrvTJYnV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iuHbPuEY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EOdupL85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OrvTJYnV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iuHbPuEY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KGgYHkR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XYzEhNq0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xjPcxnVN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yx7BCjIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XYzEhNq0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xjPcxnVN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_F2idz7Cx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_s517wshG_sendMessage(_c, 0, m);
  cMsg_EOdupL85_sendMessage(_c, 0, m);
  cMsg_yx7BCjIx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_las8NcEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_nzijLMl5_sendMessage(_c, 0, m);
  cMsg_GRDjTKaN_sendMessage(_c, 0, m);
  cMsg_yx7BCjIx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_64znn4tA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_nzijLMl5_sendMessage(_c, 0, m);
  cMsg_EOdupL85_sendMessage(_c, 0, m);
  cMsg_KGgYHkR9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WzhEgL13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3Ovxp6aF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8b3uEHsH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sYXSxF68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3Ovxp6aF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8b3uEHsH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h0RYK2J0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qFXSGrHd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_phBnxv7Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wgvORH6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qFXSGrHd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_phBnxv7Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UxyAh7Kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HGZU82OY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GSqccLWX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_D1hmoz8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HGZU82OY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GSqccLWX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jIfuOFej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_sYXSxF68_sendMessage(_c, 0, m);
  cMsg_wgvORH6e_sendMessage(_c, 0, m);
  cMsg_D1hmoz8i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xIS2bDDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_sYXSxF68_sendMessage(_c, 0, m);
  cMsg_h0RYK2J0_sendMessage(_c, 0, m);
  cMsg_UxyAh7Kh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0DNjgivo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_WzhEgL13_sendMessage(_c, 0, m);
  cMsg_h0RYK2J0_sendMessage(_c, 0, m);
  cMsg_D1hmoz8i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8zwiL2fP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_cmTxJrWV_sendMessage(_c, 0, m);
  cMsg_LaieHL0L_sendMessage(_c, 0, m);
  cMsg_k5NFJbE5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LOjfC5rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_WzhEgL13_sendMessage(_c, 0, m);
  cMsg_wgvORH6e_sendMessage(_c, 0, m);
  cMsg_UxyAh7Kh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_TraQQT8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hrcoFyX0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YhEoQo51_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_49vs4t6Z, 0, m, &cSlice_49vs4t6Z_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jSzJ4Xz2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_49vs4t6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xHnmzD87_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xHnmzD87_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jcVHKXZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xHnmzD87_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xHnmzD87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MJQvTOri_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_A3oqlksG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aBkt3StK, 0, m, &cSlice_aBkt3StK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rzxZUVKp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_aBkt3StK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ULVJdlom_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ULVJdlom_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_tvSaYIkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ULVJdlom_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ULVJdlom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lIG3enqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rzxZUVKp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tGmBjUlc, 0, m, &cSlice_tGmBjUlc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YhEoQo51_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_tGmBjUlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9xvfn0jr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9xvfn0jr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ZqD2XQYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9xvfn0jr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9xvfn0jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_V2b2sYyC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jSzJ4Xz2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HhmQy4CG, 0, m, &cSlice_HhmQy4CG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RKEEoPbS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_HhmQy4CG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TvIcJmp8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TvIcJmp8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Ii8fY64H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TvIcJmp8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_TvIcJmp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2m2eYW5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RKEEoPbS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5YONkeIp, 0, m, &cSlice_5YONkeIp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_j8vCVfIC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5YONkeIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0kASDVsx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0kASDVsx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_cilivHIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0kASDVsx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0kASDVsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fO9DnkbI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8BVw207i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jk4865ah_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jk4865ah_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kmgxwr82, 1, m, &cDelay_kmgxwr82_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wIT7AK7x_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kmgxwr82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kmgxwr82, m);
  cMsg_4fGpRSpp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jk4865ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kmgxwr82, 0, m, &cDelay_kmgxwr82_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wIT7AK7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kmgxwr82, 0, m, &cDelay_kmgxwr82_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_1bSMipm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yf6sMYSH, HV_BINOP_SUBTRACT, 0, m, &cBinop_yf6sMYSH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_kBRH4qv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W6c9DuxA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zehosmPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W6c9DuxA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_KYwy1NVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1bSMipm4, 0, m, &cVar_1bSMipm4_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_VORzBCkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aZhuObaP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cU79KQ2h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ydUlbeOW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yf6sMYSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fdM8Je7E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fdM8Je7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cixGsZKB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cixGsZKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_pBicCM1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w8oXTzfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eB2LoVFL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OiLoUL6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OiLoUL6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1R1nr1Uf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_eB2LoVFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kBRH4qv1, 1, m, &cIf_kBRH4qv1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vv2CQ3lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zehosmPY, 1, m, &cIf_zehosmPY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1R1nr1Uf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_kBRH4qv1, 0, m, &cIf_kBRH4qv1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pBicCM1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zehosmPY, 0, m, &cIf_zehosmPY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cU79KQ2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yf6sMYSH, HV_BINOP_SUBTRACT, 1, m, &cBinop_yf6sMYSH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aZhuObaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_ydUlbeOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1bSMipm4, 0, m, &cVar_1bSMipm4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W6c9DuxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HPNi69Um, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_j8vCVfIC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uEqzJEWl, 0, m, &cSlice_uEqzJEWl_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_uEqzJEWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_s8FQ0V9V_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_s8FQ0V9V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_5QPgUGsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s8FQ0V9V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_s8FQ0V9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HkvrjzzF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SsQ9x4gG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cABiJb3o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3l8XUdTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OjzrcFGv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_FfqRMZlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YznWcLwF, 0, m, &cVar_YznWcLwF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hrcoFyX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_suR05BAf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_o6cZyNnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8BVw207i_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MVxDXMNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qlX8dMTt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4fGpRSpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pNpC8UZ6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qlX8dMTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pNpC8UZ6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tPqLSq5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_REI3ox3o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_REI3ox3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6OXiVXes_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6OXiVXes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jXolqGRd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_esqtsJjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T4dlgVrk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_s5CRKoTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_enM4ZkfA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_v9dAYkf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_97LPPLUt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rGUYXdPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DGkfuqjU_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7XSA9LOk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cmpWW9aw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Q8FoONg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DGkfuqjU_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7XSA9LOk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cmpWW9aw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_ge5eSumv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3Vnt0YXJ, 0, m, &cVar_3Vnt0YXJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fN6uyVYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DGkfuqjU_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7XSA9LOk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cmpWW9aw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qgRr1NVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DGkfuqjU_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7XSA9LOk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cmpWW9aw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dmjoxPzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DGkfuqjU_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7XSA9LOk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cmpWW9aw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_y0yuC5Sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_bxoMx4Ea, 0, m, &cVar_bxoMx4Ea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_otbupuKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_nUZEePEt, 0, m, &cVar_nUZEePEt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GgMJeAYt, 0, m, &cVar_GgMJeAYt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6rncuoHc, 0, m, &cVar_6rncuoHc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rL8voJya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ge5eSumv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XLkE40zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zOkyc0Fm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aVuTKByx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hMVCuVii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zOkyc0Fm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aVuTKByx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hWMrQ8oM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zOkyc0Fm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aVuTKByx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rFp7pqyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zOkyc0Fm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aVuTKByx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xaqN94cF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zOkyc0Fm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aVuTKByx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Q1aJnGns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_9v4oL3mx, 0, m, &cVar_9v4oL3mx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bTAU5v3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_9SjHdA7p, 0, m, &cVar_9SjHdA7p_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KsPrAKUj, 0, m, &cVar_KsPrAKUj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7xSZlgMd, 0, m, &cVar_7xSZlgMd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_F5RhBnM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DGkfuqjU_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7XSA9LOk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cmpWW9aw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eUW5rPpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_un7KBkCO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R9UI1Kqo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HR3khAhx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_R6e3YWYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_un7KBkCO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R9UI1Kqo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HR3khAhx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_6MvvLp7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YkiJiprp, 0, m, &cVar_YkiJiprp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ebNBzq22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_un7KBkCO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R9UI1Kqo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HR3khAhx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mdELN8YH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_un7KBkCO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R9UI1Kqo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HR3khAhx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_agDRsgbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_un7KBkCO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R9UI1Kqo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HR3khAhx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eTj6b4mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_YvsKdw8T, 0, m, &cVar_YvsKdw8T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QCdRYuvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_b8RY6tIV, 0, m, &cVar_b8RY6tIV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R3j1exbR, 0, m, &cVar_R3j1exbR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pRCGs2NA, 0, m, &cVar_pRCGs2NA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Zx4I92np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_6MvvLp7C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O1nrpmxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_un7KBkCO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R9UI1Kqo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HR3khAhx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f6fMqo6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WGRixjFy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7LqmnDrm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_A3oqlksG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_onvR9vhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WGRixjFy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7LqmnDrm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_A3oqlksG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_CtfNucVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_alSEInAs, 0, m, &cVar_alSEInAs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9rNZt3Ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WGRixjFy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7LqmnDrm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_A3oqlksG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3BIjikH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WGRixjFy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7LqmnDrm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_A3oqlksG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sSZEtHCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WGRixjFy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7LqmnDrm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_A3oqlksG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DLtf7MOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_T6UNdd3k, 0, m, &cVar_T6UNdd3k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yZmRnO9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_P368oZOy, 0, m, &cVar_P368oZOy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wpGeyKr2, 0, m, &cVar_wpGeyKr2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Lle4C5ci, 0, m, &cVar_Lle4C5ci_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Cd7k6Nfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_CtfNucVB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wniIjMcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WGRixjFy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7LqmnDrm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_A3oqlksG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4YLFe0nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_esqtsJjA, 0, m, &cVar_esqtsJjA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T4dlgVrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DGkfuqjU_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7XSA9LOk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cmpWW9aw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tf801OCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_s5CRKoTg, 0, m, &cVar_s5CRKoTg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_enM4ZkfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_un7KBkCO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R9UI1Kqo_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HR3khAhx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4ly5pXnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_v9dAYkf6, 0, m, &cVar_v9dAYkf6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_97LPPLUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WGRixjFy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7LqmnDrm_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_A3oqlksG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_wzCJNLHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yAhRbdPf_sendMessage(_c, 0, m);
  cMsg_t99Z0z8G_sendMessage(_c, 0, m);
  cMsg_bfm03vzg_sendMessage(_c, 0, m);
  cMsg_0LotlYFw_sendMessage(_c, 0, m);
  cMsg_x1XYyXeN_sendMessage(_c, 0, m);
  cMsg_ba3BE3NW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_F3m46Eek, 0, m, &cVar_F3m46Eek_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9bAxG93b, 0, m, &cVar_9bAxG93b_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Pp5qqHEx, 0, m, &cVar_Pp5qqHEx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_z8jzKTRE, 0, m, &cVar_z8jzKTRE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KceWzcgz, 0, m, &cVar_KceWzcgz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vZhNy5sh, 0, m, &cVar_vZhNy5sh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rsXocbM1, 0, m, &cVar_rsXocbM1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RjqlEO9D, 0, m, &cVar_RjqlEO9D_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ut8DoDQ2, 0, m, &cVar_ut8DoDQ2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vCfPpDMI, 0, m, &cVar_vCfPpDMI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YZioZjYU, 0, m, &cVar_YZioZjYU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9gIO857E, 0, m, &cVar_9gIO857E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OlVuuVD7, 0, m, &cVar_OlVuuVD7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TENoGe3Q, 0, m, &cVar_TENoGe3Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sRSOQQJi, 0, m, &cVar_sRSOQQJi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S2Dea1NV, 0, m, &cVar_S2Dea1NV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ivqaJ7P9, 0, m, &cVar_ivqaJ7P9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RFh6itNZ, 0, m, &cVar_RFh6itNZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8oEldjf2, 0, m, &cVar_8oEldjf2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_71grRNZR, 0, m, &cVar_71grRNZR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dacxVYmO, 0, m, &cVar_dacxVYmO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7VBZxqeH, 0, m, &cVar_7VBZxqeH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rYQRyUgn, 0, m, &cVar_rYQRyUgn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KlwjFCSS, 0, m, &cVar_KlwjFCSS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QSyVexH4, 0, m, &cVar_QSyVexH4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5s9mhcvO, 0, m, &cVar_5s9mhcvO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yEkP6gUz, 0, m, &cVar_yEkP6gUz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WsgnR5XF, 0, m, &cVar_WsgnR5XF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YpYSVsit, 0, m, &cVar_YpYSVsit_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Os69WWP5, 0, m, &cVar_Os69WWP5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CwTjUmg4, 0, m, &cVar_CwTjUmg4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fihYr1XF, 0, m, &cVar_fihYr1XF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Qwf1yA2F, 0, m, &cVar_Qwf1yA2F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PxrHZag2, 0, m, &cVar_PxrHZag2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ny9yNo1D, 0, m, &cVar_ny9yNo1D_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aWKOze0U, 0, m, &cVar_aWKOze0U_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0wTYKZSF, 0, m, &cVar_0wTYKZSF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_T2vwXTxw, 0, m, &cVar_T2vwXTxw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Bp5lSYPb, 0, m, &cVar_Bp5lSYPb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oWHUvzwx, 0, m, &cVar_oWHUvzwx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Dikkjcdl, 0, m, &cVar_Dikkjcdl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mQ38xka7, 0, m, &cVar_mQ38xka7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JvN0zXQZ, 0, m, &cVar_JvN0zXQZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1YOuRCXe, 0, m, &cVar_1YOuRCXe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WhH5TsVL, 0, m, &cVar_WhH5TsVL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m06lpDR3, 0, m, &cVar_m06lpDR3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OOmte1Sp, 0, m, &cVar_OOmte1Sp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mVNpyCh8, 0, m, &cVar_mVNpyCh8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wObed07w, 0, m, &cVar_wObed07w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y4SzEYpl, 0, m, &cVar_Y4SzEYpl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MIMCZvOZ, 0, m, &cVar_MIMCZvOZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Iv55f3Um, 0, m, &cVar_Iv55f3Um_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jcVHKXZd, 0, m, &cVar_jcVHKXZd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tvSaYIkI, 0, m, &cVar_tvSaYIkI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZqD2XQYh, 0, m, &cVar_ZqD2XQYh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ii8fY64H, 0, m, &cVar_Ii8fY64H_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cilivHIt, 0, m, &cVar_cilivHIt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5QPgUGsk, 0, m, &cVar_5QPgUGsk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DQ77anMM, 0, m, &cVar_DQ77anMM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gIlFwekD, 0, m, &cVar_gIlFwekD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lwnbz5JK, 0, m, &cVar_lwnbz5JK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PG9uVuBi_sendMessage);
  cMsg_bTAU5v3L_sendMessage(_c, 0, m);
  cMsg_Q1aJnGns_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a0PFhJ9n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_15P5JIds_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_iQ7XyQAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9SjHdA7p, 0, m, &cVar_9SjHdA7p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eGBowazG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KsPrAKUj, 0, m, &cVar_KsPrAKUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eIYFfoHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7xSZlgMd, 0, m, &cVar_7xSZlgMd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rSXBnNZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9bAxG93b, 0, m, &cVar_9bAxG93b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ViJmIDoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aDUIG21V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mKbsO7Df_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lk2A7xhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8C6nCjmr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ASlZqXbo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aT82hVMF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bILGdZdo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_p4RSFlgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H3chIFDR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5mQ7IhlG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xvGhIwCn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HpcSMH2h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bEu72nyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BFn4P0bJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I27QHvO5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_scpeh0IA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7qQ5a7Er_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4UCsTNL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pe0vxtaK, HV_BINOP_MULTIPLY, 0, m, &cBinop_Pe0vxtaK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5SL2OMfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nIoabAG4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xgzzDbKJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_I0hPCWoV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_IbUsh9VK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cM9HXeoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VRl00IoC_sendMessage);
  cMsg_QfohpCFC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_HWDqHQxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o4jzlu8y, HV_BINOP_MULTIPLY, 0, m, &cBinop_o4jzlu8y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MbsdF5mT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_7RYCSkXn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bv8j2EP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9q7W6Zce, HV_BINOP_MULTIPLY, 1, m, &cBinop_9q7W6Zce_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uARNc7fo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IhPTQymv_sendMessage);
  cMsg_myOFXg0g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_LdF1VQ00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hz5koRqe, HV_BINOP_MULTIPLY, 0, m, &cBinop_hz5koRqe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1H4CA4ku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lIST7BzJ_sendMessage(_c, 0, m);
  cMsg_8LRFqNO4_sendMessage(_c, 0, m);
  cMsg_iwWhCWrh_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0COfom0d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NgDF83Uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_griRHRgd_sendMessage);
  cMsg_7DzioeB7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_ZgVdZrcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KceWzcgz, 0, m, &cVar_KceWzcgz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZNAMyH8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ESYO0Wtr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ZaRFoWb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XUty40Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t808Zwqe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0QoYAfIY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZY40slxg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edhB4T1G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZM7Glcmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mn3TZALG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M3YHZJw3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nrfk6CBN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N15fyp0w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_N7YWfdVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9q4WBDtB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3RswZ3GX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XcGSMvEI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4TN86go4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cx4ol518_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7tfNDEKO, HV_BINOP_MULTIPLY, 0, m, &cBinop_7tfNDEKO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_G75U7li2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sQuoQAyk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_v5xpAoph_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gUoh5JNq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_mIzT8dTM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_oPHk4544_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0hzVyRZz_sendMessage);
  cMsg_5bc1LcZx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_ZCA7oyPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YkBIKE9D, HV_BINOP_MULTIPLY, 0, m, &cBinop_YkBIKE9D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Cxdwfc2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0j08Z7lh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YfZ8jAty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_knhBFpXJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_knhBFpXJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_M1DvFW3b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SFqGaSRz_sendMessage);
  cMsg_2MIZXb6H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_uHtqInYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yOJmY5PD, HV_BINOP_MULTIPLY, 0, m, &cBinop_yOJmY5PD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_89agFZJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MZ06ErBv_sendMessage(_c, 0, m);
  cMsg_oiQ3LUaP_sendMessage(_c, 0, m);
  cMsg_MUdUZUEp_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_s1VQnZbd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XCMqiWRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_hOJmUuaj_sendMessage);
  cMsg_p6x7mJhc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_ZhOS1DLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9v4oL3mx, 0, m, &cVar_9v4oL3mx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_x49M55fL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A3DpyPSp, 0, m, &cVar_A3DpyPSp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rpnPAduh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bxoMx4Ea, 0, m, &cVar_bxoMx4Ea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5bGH6sZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nUZEePEt, 0, m, &cVar_nUZEePEt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8RlWC8uA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GgMJeAYt, 0, m, &cVar_GgMJeAYt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZPCTP7BB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6rncuoHc, 0, m, &cVar_6rncuoHc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BSq83PSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ge5eSumv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RQX1mdKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qAGUiZ17_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zXWuQM0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A6VIXy7X, 0, m, &cVar_A6VIXy7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WC4tU9wX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HgS0IXPy, 0, m, &cVar_HgS0IXPy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4aMGj1we_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_5xOTMCdo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gnIwIrdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EG6c0oLn_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JHwohLHV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vvZn1nP5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UWVEI7Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_M4R6tL0a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ae4jK4tx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_azWfKNU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r1xjRUnb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_yU4mQBbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KPkA8TaT, 0, m, &cVar_KPkA8TaT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ujxxDbKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2tGwmuco, 0, m, &cVar_2tGwmuco_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DpM1m0Dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_TiLNnw2W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WxBuzXuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Of184JUx_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XG0Aizdh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C6PXUI9t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1Pr5UXPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gtshyUjg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Cf8Imgdj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_toSbo5bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FupGMp8G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_KfdvfLHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xCm3911p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_flI0DG9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7yLCYjgD, 0, m, &cVar_7yLCYjgD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_S2ZfbN2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zYk09tuk, 0, m, &cVar_zYk09tuk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DW29e6Qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_ElmkqpIs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hxWWOb38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Yqfj1L9I_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MDemXK3J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PcD0Gi1y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6ef7uFFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rE85hBvh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vq1Y4DHa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WlKbBxNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m4x4kl8a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_gX7wAPzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qdKpXXVf, 0, m, &cVar_qdKpXXVf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Ghoyjacp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z5fEe2R9, 0, m, &cVar_z5fEe2R9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_wRVNtgC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_ZgE7Pj5w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Qw1qHZQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QeUUPkzF_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vJEpihWR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PlpksxeD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nL7S2XAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KUcKya0u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_daAvpIGA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_mtN2W62Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bhq4JJey_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_AgRCvhtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Au8MHXRx, 0, m, &cVar_Au8MHXRx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_p1F8DLTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YvsKdw8T, 0, m, &cVar_YvsKdw8T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BKTrDj9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_b8RY6tIV, 0, m, &cVar_b8RY6tIV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DUYE45B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R3j1exbR, 0, m, &cVar_R3j1exbR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5FlUyDxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pRCGs2NA, 0, m, &cVar_pRCGs2NA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_IwEl6lLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_6MvvLp7C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3mxBpF6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_wh0rgV2Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yiXZeg8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yHInAj9F, 0, m, &cVar_yHInAj9F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CQ16QyOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aMCmrFPN, 0, m, &cVar_aMCmrFPN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GlexAEpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_2FyZCgHz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4CWd0u4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0FMrVPC3_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IJ60CLtY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UlO96Yec_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1WQI9Xwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OgZx4r6O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rIo2tUqL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lg40LJZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h8vKlTgE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_MJQvTOri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nOKFV5rW, 0, m, &cVar_nOKFV5rW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2m2eYW5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TraQQT8l, 0, m, &cVar_TraQQT8l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_V2b2sYyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_FfqRMZlp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lIG3enqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cIqDsKRF_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MVxDXMNj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o6cZyNnQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fO9DnkbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w8oXTzfu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vv2CQ3lv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HkvrjzzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tPqLSq5Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_QaJCB7GS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m4gDjc8w, 0, m, &cVar_m4gDjc8w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_IgnqgPkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T6UNdd3k, 0, m, &cVar_T6UNdd3k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0WZhwv3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P368oZOy, 0, m, &cVar_P368oZOy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WMvSt9gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wpGeyKr2, 0, m, &cVar_wpGeyKr2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AnfCl9Gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Lle4C5ci, 0, m, &cVar_Lle4C5ci_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aMkqupqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_CtfNucVB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1KPWJHtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_esqtsJjA, 0, m, &cVar_esqtsJjA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GECtYA5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s5CRKoTg, 0, m, &cVar_s5CRKoTg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4xPnlNkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v9dAYkf6, 0, m, &cVar_v9dAYkf6_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_ls3zVMaZ, VOf(Bf0));
    __hv_line_f(&sLine_tyPOY8jl, VOf(Bf1));
    __hv_line_f(&sLine_B6TjHgV2, VOf(Bf2));
    __hv_line_f(&sLine_i4uXFHFW, VOf(Bf3));
    __hv_line_f(&sLine_Lcv5nsDe, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_HdPr8Cpg, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_y6l8UlfR, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_6BWcx5SW, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_Sfc8rYUU, VOf(Bf1));
    __hv_line_f(&sLine_hFtZtHmg, VOf(Bf0));
    __hv_line_f(&sLine_h75433Zi, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_22kFkspQ, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_N1HEYoZg, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_PcpMyUme, VOf(Bf5));
    __hv_line_f(&sLine_Y5VkiSj2, VOf(Bf1));
    __hv_line_f(&sLine_j5Z0amXb, VOf(Bf2));
    __hv_line_f(&sLine_6dlpI8ph, VOf(Bf4));
    __hv_line_f(&sLine_mwumiwFa, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_qHsXqxp4, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_txsD6EeR, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_4rLK7XGJ, VOf(Bf6));
    __hv_line_f(&sLine_yrG5ktlC, VOf(Bf2));
    __hv_line_f(&sLine_iSPeRxCP, VOf(Bf1));
    __hv_line_f(&sLine_EN2iN87h, VOf(Bf5));
    __hv_line_f(&sLine_9AAS3iXz, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_ydtM7Cgu, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_PUOFB1vg, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_MaXv4SxD, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_VVK0HmYH, VOf(Bf2));
    __hv_line_f(&sLine_8sCC2hRv, VOf(Bf6));
    __hv_line_f(&sLine_YfE5aBfe, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_MnTCpGmD, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_DaHgsqsj, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_xRiNz62G, VOf(Bf8));
    __hv_line_f(&sLine_GZKU3kID, VOf(Bf2));
    __hv_line_f(&sLine_JuLQM7KX, VOf(Bf1));
    __hv_line_f(&sLine_KMsCG2LC, VOf(Bf7));
    __hv_line_f(&sLine_8DpWbtvh, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_9tWeP6QM, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_qQim1IUF, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_TmPb2GLC, VIf(Bf0));
    __hv_varwrite_f(&sVarf_BsPnnL0H, VIf(Bf6));
    __hv_varwrite_f(&sVarf_XZaGhNv5, VIf(Bf4));
    __hv_varwrite_f(&sVarf_acDxGGvT, VIf(Bf7));
    __hv_varread_f(&sVarf_QoPQ4NkK, VOf(Bf7));
    __hv_varread_f(&sVarf_kHGAQH1R, VOf(Bf4));
    __hv_varread_f(&sVarf_gOwEEs7F, VOf(Bf6));
    __hv_varread_f(&sVarf_HV8g3EmD, VOf(Bf0));
    __hv_varread_f(&sVarf_E4yaGoaK, VOf(Bf9));
    __hv_varread_f(&sVarf_SLIHomht, VOf(Bf1));
    __hv_line_f(&sLine_CyXvA8Mx, VOf(Bf2));
    __hv_line_f(&sLine_bPnlXqcp, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_gOwEEs7F, VIf(Bf7));
    __hv_varwrite_f(&sVarf_E4yaGoaK, VIf(Bf4));
    __hv_varread_f(&sVarf_NRAQ1Uxn, VOf(Bf2));
    __hv_varread_f(&sVarf_RhgeYgkQ, VOf(Bf9));
    __hv_varread_f(&sVarf_XZEsniA3, VOf(Bf1));
    __hv_varread_f(&sVarf_ePZHKStk, VOf(Bf6));
    __hv_varread_f(&sVarf_lJinVpqY, VOf(Bf10));
    __hv_varread_f(&sVarf_ehnVyYNP, VOf(Bf11));
    __hv_varread_f(&sVarf_eJmK9hNu, VOf(Bf12));
    __hv_varwrite_f(&sVarf_zviOCAXP, VIf(Bf7));
    __hv_varread_f(&sVarf_ASZwqgAq, VOf(Bf13));
    __hv_line_f(&sLine_6vfEETPE, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_OTiY6Oer, VOf(Bf15));
    __hv_line_f(&sLine_Rw4mulnn, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_pnkF4y0z, VOf(Bf14));
    __hv_line_f(&sLine_GfXR4hIf, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_ePZHKStk, VIf(Bf17));
    __hv_varread_f(&sVarf_zviOCAXP, VOf(Bf17));
    __hv_line_f(&sLine_vNE3QZJH, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_256qT47G, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_2inoeW26, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_lJinVpqY, VIf(Bf16));
    __hv_line_f(&sLine_aMON9LG3, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_YnoSVIam, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_DUKoiewp, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_ehnVyYNP, VIf(Bf16));
    __hv_line_f(&sLine_Fs1AWxeO, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_XmaoFNtT, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_QzjP7cQW, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_eJmK9hNu, VIf(Bf16));
    __hv_varwrite_f(&sVarf_ASZwqgAq, VIf(Bf2));
    __hv_varwrite_f(&sVarf_OTiY6Oer, VIf(Bf9));
    __hv_varwrite_f(&sVarf_pnkF4y0z, VIf(Bf1));
    sEnv_process(this, &sEnv_fgWNHB81, VIf(Bf6), &sEnv_fgWNHB81_sendMessage);
    sEnv_process(this, &sEnv_WsuIkwS7, VIf(Bf7), &sEnv_WsuIkwS7_sendMessage);
    __hv_line_f(&sLine_9s2tQg2Y, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_VxhE2ooY, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_X5u1aQvI, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_asM2lVwM, VOf(Bf6));
    __hv_line_f(&sLine_tjLwAOIw, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_NRAQ1Uxn, VIf(Bf9));
    __hv_varwrite_f(&sVarf_asM2lVwM, VIf(Bf10));
    __hv_varwrite_f(&sVarf_uV3D1fz6, VIf(Bf11));
    __hv_varwrite_f(&sVarf_CVqNIwmV, VIf(Bf12));
    __hv_varread_f(&sVarf_CVqNIwmV, VOf(Bf12));
    __hv_line_f(&sLine_hsx0uE8X, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_XZEsniA3, VIf(Bf10));
    __hv_varread_f(&sVarf_uV3D1fz6, VOf(Bf10));
    __hv_line_f(&sLine_uS3zURof, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_RhgeYgkQ, VIf(Bf10));
    __hv_varwrite_f(&sVarf_HV8g3EmD, VIf(Bf7));
    __hv_varread_f(&sVarf_UjlcsNJo, VOf(Bf7));
    __hv_varread_f(&sVarf_3dvShwE0, VOf(Bf10));
    __hv_varread_f(&sVarf_mBDDwFQj, VOf(Bf9));
    __hv_varread_f(&sVarf_Bk2mwFPZ, VOf(Bf11));
    __hv_varread_f(&sVarf_65L5aKas, VOf(Bf6));
    __hv_varread_f(&sVarf_Acr3h0lG, VOf(Bf12));
    __hv_varread_f(&sVarf_BgGA4ByB, VOf(Bf1));
    __hv_varwrite_f(&sVarf_7hO7fyrK, VIf(Bf4));
    __hv_varread_f(&sVarf_805tU1aJ, VOf(Bf2));
    __hv_line_f(&sLine_gto6S6hS, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_PT3O9GSG, VOf(Bf17));
    __hv_line_f(&sLine_k7RB61gw, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_0srJicmv, VOf(Bf16));
    __hv_line_f(&sLine_BnNO98XY, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_Bk2mwFPZ, VIf(Bf15));
    __hv_varread_f(&sVarf_7hO7fyrK, VOf(Bf15));
    __hv_line_f(&sLine_vtsE8tsm, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_CUI8eRb4, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_fOusu7GI, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_65L5aKas, VIf(Bf13));
    __hv_line_f(&sLine_As54ef65, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_XuX0rN2r, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_2A6QYP2C, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_Acr3h0lG, VIf(Bf13));
    __hv_line_f(&sLine_3wrWAOTG, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_SKi6hEJ1, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_vXqssMoo, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_BgGA4ByB, VIf(Bf13));
    __hv_varwrite_f(&sVarf_805tU1aJ, VIf(Bf7));
    __hv_varwrite_f(&sVarf_PT3O9GSG, VIf(Bf10));
    __hv_varwrite_f(&sVarf_0srJicmv, VIf(Bf9));
    sEnv_process(this, &sEnv_U66skpCM, VIf(Bf11), &sEnv_U66skpCM_sendMessage);
    sEnv_process(this, &sEnv_L63ZQJAj, VIf(Bf4), &sEnv_L63ZQJAj_sendMessage);
    __hv_line_f(&sLine_zkDeWrpp, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_lDIbYlSg, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_18vswGyo, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_rmLHSFIK, VOf(Bf11));
    __hv_line_f(&sLine_OWbLAUAP, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_UjlcsNJo, VIf(Bf10));
    __hv_varwrite_f(&sVarf_rmLHSFIK, VIf(Bf6));
    __hv_varwrite_f(&sVarf_nkdg5DvM, VIf(Bf12));
    __hv_varwrite_f(&sVarf_ND7GlQQY, VIf(Bf1));
    __hv_varread_f(&sVarf_ND7GlQQY, VOf(Bf1));
    __hv_line_f(&sLine_JV9pTreA, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_mBDDwFQj, VIf(Bf6));
    __hv_varread_f(&sVarf_nkdg5DvM, VOf(Bf6));
    __hv_line_f(&sLine_oInOwpc3, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_3dvShwE0, VIf(Bf6));
    __hv_varwrite_f(&sVarf_SLIHomht, VIf(Bf4));
    __hv_varwrite_f(&sVarf_RIq0KECv, VIf(Bf0));
    __hv_varread_f(&sVarf_TmPb2GLC, VOf(Bf0));
    __hv_varread_f(&sVarf_BsPnnL0H, VOf(Bf4));
    __hv_varread_f(&sVarf_X5RwLAuJ, VOf(Bf6));
    __hv_varread_f(&sVarf_TUD0eONN, VOf(Bf10));
    __hv_varread_f(&sVarf_U5461xlu, VOf(Bf12));
    __hv_varread_f(&sVarf_g09XqrKF, VOf(Bf11));
    __hv_line_f(&sLine_Kwy0iyFE, VOf(Bf1));
    __hv_line_f(&sLine_UJoP6xVs, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_X5RwLAuJ, VIf(Bf0));
    __hv_varwrite_f(&sVarf_U5461xlu, VIf(Bf4));
    __hv_varread_f(&sVarf_llirQcZx, VOf(Bf1));
    __hv_varread_f(&sVarf_89sTGpOR, VOf(Bf12));
    __hv_varread_f(&sVarf_eQtx37x2, VOf(Bf11));
    __hv_varread_f(&sVarf_bPCBbIg0, VOf(Bf6));
    __hv_varread_f(&sVarf_X1zIoxmy, VOf(Bf7));
    __hv_varread_f(&sVarf_I7EIHINC, VOf(Bf13));
    __hv_varread_f(&sVarf_4FWm9vXX, VOf(Bf15));
    __hv_varwrite_f(&sVarf_vM4aNVHz, VIf(Bf0));
    __hv_varread_f(&sVarf_eu3oxkpb, VOf(Bf2));
    __hv_line_f(&sLine_kR7cEzRL, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_PZgImJ15, VOf(Bf18));
    __hv_line_f(&sLine_tcl8ymhp, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_SD1FNwy6, VOf(Bf17));
    __hv_line_f(&sLine_J2AyRPvT, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_bPCBbIg0, VIf(Bf14));
    __hv_varread_f(&sVarf_vM4aNVHz, VOf(Bf14));
    __hv_line_f(&sLine_ZNAlzfhk, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_k260QzrI, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_LHNfNZf4, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_X1zIoxmy, VIf(Bf16));
    __hv_line_f(&sLine_11B5flyN, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_FI43mGGk, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_yuk4zdRh, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_I7EIHINC, VIf(Bf16));
    __hv_line_f(&sLine_1CGMk273, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_Vx9ygqWT, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_asRQe9Q2, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_4FWm9vXX, VIf(Bf16));
    __hv_varwrite_f(&sVarf_eu3oxkpb, VIf(Bf1));
    __hv_varwrite_f(&sVarf_PZgImJ15, VIf(Bf12));
    __hv_varwrite_f(&sVarf_SD1FNwy6, VIf(Bf11));
    sEnv_process(this, &sEnv_SjIBOi8Q, VIf(Bf6), &sEnv_SjIBOi8Q_sendMessage);
    sEnv_process(this, &sEnv_RSZCApoZ, VIf(Bf0), &sEnv_RSZCApoZ_sendMessage);
    __hv_line_f(&sLine_s3cD0sXt, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_nm0MD97k, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_qIxwRMKh, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_9u9opGp5, VOf(Bf6));
    __hv_line_f(&sLine_oYdHT1Pm, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_llirQcZx, VIf(Bf12));
    __hv_varwrite_f(&sVarf_9u9opGp5, VIf(Bf7));
    __hv_varwrite_f(&sVarf_uE1RyC2q, VIf(Bf13));
    __hv_varwrite_f(&sVarf_Ca2pHbyZ, VIf(Bf15));
    __hv_varread_f(&sVarf_Ca2pHbyZ, VOf(Bf15));
    __hv_line_f(&sLine_eBTa6ZvN, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_eQtx37x2, VIf(Bf7));
    __hv_varread_f(&sVarf_uE1RyC2q, VOf(Bf7));
    __hv_line_f(&sLine_NfbWX0kJ, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_89sTGpOR, VIf(Bf7));
    __hv_varwrite_f(&sVarf_TUD0eONN, VIf(Bf0));
    __hv_varread_f(&sVarf_vi5Fctct, VOf(Bf0));
    __hv_varread_f(&sVarf_ze8tr5Kk, VOf(Bf7));
    __hv_varread_f(&sVarf_uLkZCd77, VOf(Bf12));
    __hv_varread_f(&sVarf_0geJCC9I, VOf(Bf13));
    __hv_varread_f(&sVarf_SN0LZCnV, VOf(Bf6));
    __hv_varread_f(&sVarf_ndeaqwL7, VOf(Bf15));
    __hv_varread_f(&sVarf_J3usvRQQ, VOf(Bf11));
    __hv_varwrite_f(&sVarf_DIpCegVV, VIf(Bf4));
    __hv_varread_f(&sVarf_q6tlJwFR, VOf(Bf1));
    __hv_line_f(&sLine_pL6OjPqA, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_JjKV1lnw, VOf(Bf14));
    __hv_line_f(&sLine_bHAZ78gt, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Gt8PsT21, VOf(Bf16));
    __hv_line_f(&sLine_gZ5akssZ, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_0geJCC9I, VIf(Bf18));
    __hv_varread_f(&sVarf_DIpCegVV, VOf(Bf18));
    __hv_line_f(&sLine_LBy1YJne, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_cH1VQwhi, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_0aHfvFtH, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_SN0LZCnV, VIf(Bf2));
    __hv_line_f(&sLine_mZcu5W0W, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_0k24U2Vo, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_1R7IS8uU, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_ndeaqwL7, VIf(Bf2));
    __hv_line_f(&sLine_j8GtFFRj, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_oQeq7PRC, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_yVhJqV7F, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_J3usvRQQ, VIf(Bf2));
    __hv_varwrite_f(&sVarf_q6tlJwFR, VIf(Bf0));
    __hv_varwrite_f(&sVarf_JjKV1lnw, VIf(Bf7));
    __hv_varwrite_f(&sVarf_Gt8PsT21, VIf(Bf12));
    sEnv_process(this, &sEnv_KdHzar7f, VIf(Bf13), &sEnv_KdHzar7f_sendMessage);
    sEnv_process(this, &sEnv_qCcdMQme, VIf(Bf4), &sEnv_qCcdMQme_sendMessage);
    __hv_line_f(&sLine_NSPyJCkB, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_TYl9Dpe7, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_wReHpmYT, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_SoYWy63a, VOf(Bf13));
    __hv_line_f(&sLine_uj7PpiI3, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_vi5Fctct, VIf(Bf7));
    __hv_varwrite_f(&sVarf_SoYWy63a, VIf(Bf6));
    __hv_varwrite_f(&sVarf_Q0PYeMvH, VIf(Bf15));
    __hv_varwrite_f(&sVarf_IvEWsdX3, VIf(Bf11));
    __hv_varread_f(&sVarf_IvEWsdX3, VOf(Bf11));
    __hv_line_f(&sLine_T9P7hUFj, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_uLkZCd77, VIf(Bf6));
    __hv_varread_f(&sVarf_Q0PYeMvH, VOf(Bf6));
    __hv_line_f(&sLine_zY6ZiOVM, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_ze8tr5Kk, VIf(Bf6));
    __hv_varwrite_f(&sVarf_g09XqrKF, VIf(Bf4));
    __hv_varwrite_f(&sVarf_nNSoAJ7V, VIf(Bf10));
    __hv_varread_f(&sVarf_XZaGhNv5, VOf(Bf10));
    __hv_varread_f(&sVarf_acDxGGvT, VOf(Bf4));
    __hv_varread_f(&sVarf_ZUhvqdXk, VOf(Bf6));
    __hv_varread_f(&sVarf_QrDFe6ja, VOf(Bf7));
    __hv_varread_f(&sVarf_JSXuxxM0, VOf(Bf15));
    __hv_varread_f(&sVarf_3xVTWxpG, VOf(Bf13));
    __hv_line_f(&sLine_2TemKAgS, VOf(Bf11));
    __hv_line_f(&sLine_SaxTBT3T, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_ZUhvqdXk, VIf(Bf10));
    __hv_varwrite_f(&sVarf_JSXuxxM0, VIf(Bf4));
    __hv_varread_f(&sVarf_9lPR4iXT, VOf(Bf11));
    __hv_varread_f(&sVarf_VorGpghf, VOf(Bf15));
    __hv_varread_f(&sVarf_yHE0Onv8, VOf(Bf13));
    __hv_varread_f(&sVarf_iqDXH6C9, VOf(Bf6));
    __hv_varread_f(&sVarf_NlULym3z, VOf(Bf0));
    __hv_varread_f(&sVarf_idNOlVDM, VOf(Bf2));
    __hv_varread_f(&sVarf_xM0aVr8F, VOf(Bf18));
    __hv_varwrite_f(&sVarf_oIZcFqL7, VIf(Bf10));
    __hv_varread_f(&sVarf_F6ro09Uh, VOf(Bf1));
    __hv_line_f(&sLine_Cts52OSJ, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_zQJAyqlG, VOf(Bf19));
    __hv_line_f(&sLine_HePc5V1s, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_evynaAQE, VOf(Bf14));
    __hv_line_f(&sLine_HBpd95Qe, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_iqDXH6C9, VIf(Bf17));
    __hv_varread_f(&sVarf_oIZcFqL7, VOf(Bf17));
    __hv_line_f(&sLine_LcMIiAzn, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_mSBYEmw3, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_RtmdM5Nc, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_NlULym3z, VIf(Bf16));
    __hv_line_f(&sLine_gkChQB5s, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_0TgqFOs3, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_JtpNIZUT, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_idNOlVDM, VIf(Bf16));
    __hv_line_f(&sLine_GasgLAlY, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_tSuCCcSw, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_zZZ6kyv9, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_xM0aVr8F, VIf(Bf16));
    __hv_varwrite_f(&sVarf_F6ro09Uh, VIf(Bf11));
    __hv_varwrite_f(&sVarf_zQJAyqlG, VIf(Bf15));
    __hv_varwrite_f(&sVarf_evynaAQE, VIf(Bf13));
    sEnv_process(this, &sEnv_vI5Kdkjy, VIf(Bf6), &sEnv_vI5Kdkjy_sendMessage);
    sEnv_process(this, &sEnv_g9hXzi6C, VIf(Bf10), &sEnv_g9hXzi6C_sendMessage);
    __hv_line_f(&sLine_kgxVtBhb, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_v5azaCYI, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_EpAbRijP, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_yII62lxL, VOf(Bf6));
    __hv_line_f(&sLine_7wvrV4WA, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_9lPR4iXT, VIf(Bf15));
    __hv_varwrite_f(&sVarf_yII62lxL, VIf(Bf0));
    __hv_varwrite_f(&sVarf_cyL0YuGJ, VIf(Bf2));
    __hv_varwrite_f(&sVarf_LUu7bTD1, VIf(Bf18));
    __hv_varread_f(&sVarf_LUu7bTD1, VOf(Bf18));
    __hv_line_f(&sLine_R72tx8r2, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_yHE0Onv8, VIf(Bf0));
    __hv_varread_f(&sVarf_cyL0YuGJ, VOf(Bf0));
    __hv_line_f(&sLine_91ad99HK, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_VorGpghf, VIf(Bf0));
    __hv_varwrite_f(&sVarf_QrDFe6ja, VIf(Bf10));
    __hv_varread_f(&sVarf_QP23FpoF, VOf(Bf10));
    __hv_varread_f(&sVarf_wC6pWcyl, VOf(Bf0));
    __hv_varread_f(&sVarf_d1cMZSmW, VOf(Bf15));
    __hv_varread_f(&sVarf_e5KvUU7o, VOf(Bf2));
    __hv_varread_f(&sVarf_kDt5ETqJ, VOf(Bf6));
    __hv_varread_f(&sVarf_Zu107Sgh, VOf(Bf18));
    __hv_varread_f(&sVarf_jO6tOgOF, VOf(Bf13));
    __hv_varwrite_f(&sVarf_jgwrvExx, VIf(Bf4));
    __hv_varread_f(&sVarf_ZwEsvpfI, VOf(Bf11));
    __hv_line_f(&sLine_SFJfChUo, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_oQwjKOVU, VOf(Bf17));
    __hv_line_f(&sLine_9yGVvmAa, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_5nTjk5Ji, VOf(Bf16));
    __hv_line_f(&sLine_cRrwW713, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_e5KvUU7o, VIf(Bf19));
    __hv_varread_f(&sVarf_jgwrvExx, VOf(Bf19));
    __hv_line_f(&sLine_mGQpREuF, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_9z91Rey4, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_0wIJyN0t, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_kDt5ETqJ, VIf(Bf1));
    __hv_line_f(&sLine_ALuGIWKi, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_pVQfqxPH, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_fXneVWm5, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_Zu107Sgh, VIf(Bf1));
    __hv_line_f(&sLine_W25dSaM3, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_Wnx5bKwX, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_dAwdQ3yN, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_jO6tOgOF, VIf(Bf1));
    __hv_varwrite_f(&sVarf_ZwEsvpfI, VIf(Bf10));
    __hv_varwrite_f(&sVarf_oQwjKOVU, VIf(Bf0));
    __hv_varwrite_f(&sVarf_5nTjk5Ji, VIf(Bf15));
    sEnv_process(this, &sEnv_KYwy1NVO, VIf(Bf2), &sEnv_KYwy1NVO_sendMessage);
    sEnv_process(this, &sEnv_VORzBCkF, VIf(Bf4), &sEnv_VORzBCkF_sendMessage);
    __hv_line_f(&sLine_HPNi69Um, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_pNpC8UZ6, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_jXolqGRd, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_aNt8XBr2, VOf(Bf2));
    __hv_line_f(&sLine_OjzrcFGv, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_QP23FpoF, VIf(Bf0));
    __hv_varwrite_f(&sVarf_aNt8XBr2, VIf(Bf6));
    __hv_varwrite_f(&sVarf_WRsmfVLw, VIf(Bf18));
    __hv_varwrite_f(&sVarf_89aMo4eO, VIf(Bf13));
    __hv_varread_f(&sVarf_89aMo4eO, VOf(Bf13));
    __hv_line_f(&sLine_suR05BAf, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_d1cMZSmW, VIf(Bf6));
    __hv_varread_f(&sVarf_WRsmfVLw, VOf(Bf6));
    __hv_line_f(&sLine_cABiJb3o, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_wC6pWcyl, VIf(Bf6));
    __hv_varwrite_f(&sVarf_3xVTWxpG, VIf(Bf4));
    __hv_varwrite_f(&sVarf_rewwnkEO, VIf(Bf7));
    __hv_varwrite_f(&sVarf_FEAATwXH, VIf(Bf8));
    __hv_varwrite_f(&sVarf_qt0S1JKK, VIf(Bf9));
    __hv_varwrite_f(&sVarf_JjMWaUzb, VIf(Bf12));
    __hv_varwrite_f(&sVarf_QoPQ4NkK, VIf(Bf3));
    __hv_varwrite_f(&sVarf_kHGAQH1R, VIf(Bf5));
    __hv_varread_f(&sVarf_FEAATwXH, VOf(Bf5));
    __hv_varread_f(&sVarf_qt0S1JKK, VOf(Bf3));
    __hv_varread_f(&sVarf_JjMWaUzb, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_RIq0KECv, VOf(Bf12));
    __hv_varread_f(&sVarf_nNSoAJ7V, VOf(Bf5));
    __hv_varread_f(&sVarf_rewwnkEO, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
